import * as i0 from '@angular/core';
import { InjectionToken, EventEmitter, forwardRef, ViewChild, Output, HostBinding, Input, Attribute, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import * as i1 from '@fundamental-ngx/core/content-density';
import { ContentDensityModule, contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import * as i2 from '@angular/cdk/portal';
import { DomPortal, PortalModule, CdkPortalOutlet } from '@angular/cdk/portal';
import { NgClass } from '@angular/common';
import { FormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import { registerFormItemControl } from '@fundamental-ngx/core/form';
import equal from 'fast-deep-equal';
import { Subscription } from 'rxjs';

const FD_CHECKBOX_COMPONENT = new InjectionToken('FdCheckboxComponent');

const FD_CHECKBOX_VALUES_DEFAULT = {
    trueValue: true,
    falseValue: false,
    thirdStateValue: null
};

let checkboxUniqueId = 0;
class CheckboxComponent {
    /** Current selection state of the checkbox component */
    set value(value) {
        this.writeValue(value);
    }
    get value() {
        return this.checkboxValue;
    }
    /** Sets values returned by control. */
    set values(checkboxValues) {
        this._values = { ...FD_CHECKBOX_VALUES_DEFAULT, ...(checkboxValues ?? {}) };
    }
    get values() {
        return this._values;
    }
    /** @hidden Used to define if control is in 'indeterminate' state.*/
    get isIndeterminate() {
        return this.checkboxState === 'indeterminate';
    }
    /** @hidden Used to define if control is in 'checked' / 'unchecked' state. */
    get isChecked() {
        return this.checkboxState === 'checked' || this.checkboxState === 'force-checked';
    }
    /** @hidden */
    constructor(elementRef, tabIndexValue = 0, _changeDetectorRef, renderer, _contentDensityObserver) {
        this.elementRef = elementRef;
        this.tabIndexValue = tabIndexValue;
        this._changeDetectorRef = _changeDetectorRef;
        this.renderer = renderer;
        this._contentDensityObserver = _contentDensityObserver;
        /** Vertical position of the label compared to the checkbox box */
        this.valignLabel = 'middle';
        /**
         * Sets the `role` attribute to the element.
         * Default: checkbox
         */
        this.role = 'checkbox';
        /** Sets [id] property of input, binds input with input label using [for] property. */
        this.inputId = `fd-checkbox-${checkboxUniqueId++}`;
        /** Enables controls third state. */
        this.tristate = false;
        /** Allows to prevent user from manually selecting controls third state. */
        this.tristateSelectable = false;
        /** If it is mandatory field */
        this.required = false;
        /** Whether the checkbox should be rendered in display-only mode. */
        this.displayOnly = false;
        /** Whether checkbox should be rendered standalone (without any text). */
        this.standalone = false;
        /** @hidden */
        this.position = 'relative';
        /** @hidden */
        this.outline = 'none';
        /** Emits event on focus change */
        this.focusChange = new EventEmitter();
        /** @hidden */
        this._projectedContent = false;
        /** @hidden */
        this._subscriptions = new Subscription();
        /** @hidden values returned by control. */
        this._values = { ...FD_CHECKBOX_VALUES_DEFAULT };
        /** @hidden Reference to callback provided by FormControl.*/
        this.onTouched = () => { };
        /** @hidden Reference to callback provided by FormControl.*/
        this.onValueChange = () => { };
        this.tabIndexValue = tabIndexValue;
    }
    /** @hidden */
    ngAfterViewInit() {
        this._contentDensityObserver.consume({
            elementRef: this.inputElement
        }, {
            elementRef: this.labelElement
        });
        this._domPortal = new DomPortal(this._domPortalContent);
        this._projectedContent = !!this._domPortal.element.innerHTML.trim();
        this._changeDetectorRef.detectChanges();
        this._portalOutlet?.attach(this._domPortal);
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
    }
    /**
     * @hidden ControlValueAccessor interface
     * - sets new control value
     * - updates control state
     */
    writeValue(value) {
        this.checkboxValue = value;
        this._setState();
        this._detectChanges();
    }
    /** @hidden ControlValueAccessor interface method - sets onValueChange callback.*/
    registerOnChange(fn) {
        this.onValueChange = fn;
    }
    /** @hidden ControlValueAccessor interface method - sets onTouched callback.*/
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /** @hidden Called by FormControl - used to disable / enable control.*/
    setDisabledState(disabled) {
        this.disabled = disabled;
        this._detectChanges();
    }
    /** @hidden Called by FormControl - used to disable editablity.*/
    setReadOnlyState(readonly) {
        this.readonly = readonly;
        this._detectChanges();
    }
    /** @hidden */
    setStyleState(state) {
        this.state = state;
        this._detectChanges();
    }
    /**
     * @hidden
     * Based on current control state:
     * - sets next control value
     * - emits new control value
     * - updates control state based on new control value
     * */
    nextValue(previousValue) {
        switch (previousValue || this.checkboxState) {
            case 'checked':
                this.checkboxValue = this.values.falseValue;
                break;
            case 'unchecked':
                this.checkboxValue =
                    this.tristate && this.tristateSelectable ? this.values.thirdStateValue : this.values.trueValue;
                break;
            case 'indeterminate':
            case 'force-checked':
                this.checkboxValue = this.values.trueValue;
                this.renderer.setProperty(this.inputElement.nativeElement, 'checked', 'true');
                break;
            default:
                this.checkboxValue =
                    this.tristate && this.tristateSelectable ? this.values.thirdStateValue : this.values.trueValue;
                break;
        }
        this._setState();
        this.onValueChange(this.checkboxValue);
        this._detectChanges();
    }
    /** @hidden handles blur event */
    _onBlur() {
        if (typeof this.onTouched === 'function') {
            this.onTouched();
        }
        this.focusChange.emit(false);
    }
    /** @hidden handles focus event */
    _onFocus() {
        this.focusChange.emit(true);
    }
    /** @hidden handles click on the label associated with native checkbox input */
    _onLabelClick(event) {
        // We have to stop propagation for click events on the input label.
        // By default, when a user clicks on a label element, a generated click event will be
        // dispatched on the associated input element. This will lead to duplicated "click" event dispatched from the component
        event.stopPropagation();
        // If we have display-only mode, stop any possible actions by label click event.
        this._handleDisplayAndReadOnly(event);
    }
    /**
     * @hidden
     * Event handler for cases when checkbox was toggled with the help of keyboard.
     * @param event
     */
    _onLabelKeydown(event) {
        // If we have display-only mode, stop any possible actions by label click event.
        this._handleDisplayAndReadOnly(event);
    }
    /** @hidden handles click on the native checkbox input */
    _onInputClick(event) {
        // When there's a click event dispatched from the input, we have to catch it, process and then re-dispatch it further.
        // This is needed in order to set the value to the component before any external listeners will receive it.
        // Otherwise checkbox might be out of sync.
        event.stopPropagation();
        if (this.displayOnly || this.readonly) {
            return;
        }
        this.nextValue();
        this.elementRef.nativeElement.dispatchEvent(new MouseEvent(event.type, event));
    }
    /** @hidden */
    _handleDisplayAndReadOnly(event) {
        if (!this.displayOnly && !this.readonly) {
            return;
        }
        event.preventDefault();
        event.stopImmediatePropagation();
        if (this.readonly) {
            this.inputElement.nativeElement.focus();
        }
    }
    /** @hidden Based on current control value sets new control state. */
    _setState() {
        if (equal(this.checkboxValue, this.values.trueValue)) {
            this.checkboxState = 'checked';
        }
        else if (equal(this.checkboxValue, this.values.falseValue)) {
            this.checkboxState = 'unchecked';
        }
        else if (this.tristate && equal(this.checkboxValue, this.values.thirdStateValue)) {
            this.checkboxState = 'indeterminate';
        }
        else if (!this.checkboxValue) {
            this.checkboxState = 'unchecked';
        }
    }
    /** Method to trigger change detection in component */
    _detectChanges() {
        if (!this._changeDetectorRef['destroyed']) {
            this._changeDetectorRef.detectChanges();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CheckboxComponent, deps: [{ token: i0.ElementRef }, { token: 'tabIndexValue', attribute: true }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: i1.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CheckboxComponent, isStandalone: true, selector: "fd-checkbox", inputs: { wrapLabel: "wrapLabel", valignLabel: "valignLabel", ariaLabel: "ariaLabel", role: "role", value: "value", ariaLabelledBy: "ariaLabelledBy", ariaDescribedBy: "ariaDescribedBy", title: "title", inputId: "inputId", state: "state", name: "name", label: "label", disabled: "disabled", readonly: "readonly", tristate: "tristate", tristateSelectable: "tristateSelectable", labelClass: "labelClass", required: "required", displayOnly: "displayOnly", values: "values", standalone: "standalone" }, outputs: { focusChange: "focusChange" }, host: { properties: { "attr.tabindex": "-1", "class.fd-checkbox--standalone": "this.standalone", "style.position": "this.position", "style.outline": "this.outline" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => CheckboxComponent),
                multi: true
            },
            {
                provide: FD_CHECKBOX_COMPONENT,
                useExisting: CheckboxComponent
            },
            registerFormItemControl(CheckboxComponent),
            contentDensityObserverProviders()
        ], viewQueries: [{ propertyName: "inputElement", first: true, predicate: ["inputElement"], descendants: true }, { propertyName: "labelElement", first: true, predicate: ["labelElement"], descendants: true }, { propertyName: "_domPortalContent", first: true, predicate: ["domPortal"], descendants: true }, { propertyName: "_portalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true }], ngImport: i0, template: "<input\n    #inputElement\n    type=\"checkbox\"\n    class=\"fd-checkbox\"\n    [id]=\"inputId\"\n    [name]=\"name\"\n    [disabled]=\"disabled || displayOnly\"\n    [readonly]=\"readonly\"\n    [indeterminate]=\"isIndeterminate\"\n    [checked]=\"isChecked\"\n    [attr.tabindex]=\"tabIndexValue\"\n    [attr.role]=\"role\"\n    [attr.aria-checked]=\"isChecked ? 'true' : isIndeterminate ? 'mixed' : 'false'\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledBy\"\n    [attr.aria-describedby]=\"ariaDescribedBy\"\n    [attr.aria-disabled]=\"disabled\"\n    [attr.aria-readonly]=\"readonly\"\n    [attr.aria-required]=\"required\"\n    [ngClass]=\"[displayOnly ? 'is-display' : disabled ? 'is-disabled' : '', state ? 'is-' + state : '']\"\n    (click)=\"_onInputClick($event)\"\n    (blur)=\"_onBlur()\"\n    (focus)=\"_onFocus()\"\n    (keyup.enter)=\"_onLabelKeydown($event)\"\n    (keyup.space)=\"_onLabelKeydown($event)\"\n/>\n<label\n    class=\"fd-checkbox__label\"\n    #labelElement\n    [for]=\"inputId\"\n    [class]=\"labelClass\"\n    [attr.title]=\"title\"\n    [class.fd-checkbox__label--required]=\"required\"\n    [class.fd-checkbox__label--wrap]=\"wrapLabel && valignLabel === 'middle'\"\n    [class.fd-checkbox__label--wrap-top-aligned]=\"wrapLabel && valignLabel === 'top'\"\n    (keyup.enter)=\"_onLabelKeydown($event)\"\n    (keyup.space)=\"_onLabelKeydown($event)\"\n    (click)=\"_onLabelClick($event)\"\n>\n    <span class=\"fd-checkbox__checkmark\" aria-hidden=\"true\"></span>\n    @if (label || _projectedContent) {\n        <div class=\"fd-checkbox__label-container\">\n            @if (label) {\n                <span class=\"fd-checkbox__text\">\n                    {{ label }}\n                </span>\n            } @else {\n                <span class=\"fd-checkbox__text\">\n                    <ng-template cdkPortalOutlet></ng-template>\n                </span>\n            }\n        </div>\n    }\n</label>\n<span [attr.hidden]=\"!_projectedContent ? true : null\" #domPortal>\n    <ng-content></ng-content>\n</span>\n", styles: [".fd-checkbox{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--sapField_Background);border:0;border-color:var(--sapField_BorderColor);border-radius:var(--sapField_BorderCornerRadius);border-style:solid;border-width:var(--sapField_BorderWidth);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapField_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;opacity:.0001;outline:none;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;white-space:nowrap}.fd-checkbox:after,.fd-checkbox:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox::-webkit-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::-moz-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox:-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::-moz-selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-checkbox::selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-checkbox.is-success{background:var(--sapField_SuccessBackgroundStyle);background-color:var(--sapField_SuccessBackground);border:var(--sapField_SuccessColor) var(--sapField_SuccessBorderWidth) var(--sapField_SuccessBorderStyle);-webkit-box-shadow:var(--sapField_SuccessShadow);box-shadow:var(--sapField_SuccessShadow)}.fd-checkbox.is-success.is-hover,.fd-checkbox.is-success:hover{background-color:var(--fdInput_Success_Background_Color_Hover);border-color:var(--sapField_SuccessColor);-webkit-box-shadow:var(--fdInput_Success_Box_Shadow_Hover);box-shadow:var(--fdInput_Success_Box_Shadow_Hover)}.fd-checkbox.is-success.is-focus,.fd-checkbox.is-success:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Success_Outline_Color);z-index:5}.fd-checkbox.is-success.is-focus.is-hover,.fd-checkbox.is-success.is-focus:hover,.fd-checkbox.is-success:focus.is-hover,.fd-checkbox.is-success:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-success.is-expanded,.fd-checkbox.is-success[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Success_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-error{background:var(--sapField_InvalidBackgroundStyle);background-color:var(--sapField_InvalidBackground);border:var(--sapField_InvalidColor) var(--sapField_InvalidBorderWidth) var(--sapField_InvalidBorderStyle);-webkit-box-shadow:var(--sapField_InvalidShadow);box-shadow:var(--sapField_InvalidShadow)}.fd-checkbox.is-error.is-hover,.fd-checkbox.is-error:hover{background-color:var(--fdInput_Error_Background_Color_Hover);border-color:var(--sapField_InvalidColor);-webkit-box-shadow:var(--fdInput_Error_Box_Shadow_Hover);box-shadow:var(--fdInput_Error_Box_Shadow_Hover)}.fd-checkbox.is-error.is-focus,.fd-checkbox.is-error:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Error_Outline_Color);z-index:5}.fd-checkbox.is-error.is-focus.is-hover,.fd-checkbox.is-error.is-focus:hover,.fd-checkbox.is-error:focus.is-hover,.fd-checkbox.is-error:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-error.is-expanded,.fd-checkbox.is-error[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Error_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-warning{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle);-webkit-box-shadow:var(--sapField_WarningShadow);box-shadow:var(--sapField_WarningShadow)}.fd-checkbox.is-warning.is-hover,.fd-checkbox.is-warning:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-checkbox.is-warning.is-focus,.fd-checkbox.is-warning:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-checkbox.is-warning.is-focus.is-hover,.fd-checkbox.is-warning.is-focus:hover,.fd-checkbox.is-warning:focus.is-hover,.fd-checkbox.is-warning:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-warning.is-expanded,.fd-checkbox.is-warning[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-alert{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle)}.fd-checkbox.is-alert.is-hover,.fd-checkbox.is-alert:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-checkbox.is-alert.is-focus,.fd-checkbox.is-alert:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-checkbox.is-alert.is-focus.is-hover,.fd-checkbox.is-alert.is-focus:hover,.fd-checkbox.is-alert:focus.is-hover,.fd-checkbox.is-alert:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-alert.is-expanded,.fd-checkbox.is-alert[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-information{background:var(--sapField_InformationBackgroundStyle);background-color:var(--sapField_InformationBackground);border:var(--sapField_InformationColor) var(--sapField_InformationBorderWidth) var(--sapField_InformationBorderStyle);-webkit-box-shadow:var(--sapField_InformationShadow);box-shadow:var(--sapField_InformationShadow)}.fd-checkbox.is-information.is-hover,.fd-checkbox.is-information:hover{background-color:var(--fdInput_Information_Background_Color_Hover);border-color:var(--sapField_InformationColor);-webkit-box-shadow:var(--fdInput_Information_Box_Shadow_Hover);box-shadow:var(--fdInput_Information_Box_Shadow_Hover)}.fd-checkbox.is-information.is-focus,.fd-checkbox.is-information:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Information_Outline_Color);z-index:5}.fd-checkbox.is-information.is-focus.is-hover,.fd-checkbox.is-information.is-focus:hover,.fd-checkbox.is-information:focus.is-hover,.fd-checkbox.is-information:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-information.is-expanded,.fd-checkbox.is-information[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Information_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-alert.is-focus,.fd-checkbox.is-alert:focus,.fd-checkbox.is-error.is-focus,.fd-checkbox.is-error:focus,.fd-checkbox.is-information.is-focus,.fd-checkbox.is-information:focus,.fd-checkbox.is-warning.is-focus,.fd-checkbox.is-warning:focus{outline-offset:var(--fdInput_Outline_Offset_States);z-index:5}.fd-checkbox.is-disabled,.fd-checkbox:disabled,.fd-checkbox[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-checkbox.is-readonly,.fd-checkbox.is-readonly.is-focus,.fd-checkbox.is-readonly.is-hover,.fd-checkbox.is-readonly:focus,.fd-checkbox.is-readonly:hover,.fd-checkbox[aria-readonly=true],.fd-checkbox[aria-readonly=true].is-focus,.fd-checkbox[aria-readonly=true].is-hover,.fd-checkbox[aria-readonly=true]:focus,.fd-checkbox[aria-readonly=true]:hover,.fd-checkbox[readonly],.fd-checkbox[readonly].is-focus,.fd-checkbox[readonly].is-hover,.fd-checkbox[readonly]:focus,.fd-checkbox[readonly]:hover{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-readonly.is-focus,.fd-checkbox.is-readonly:focus,.fd-checkbox[aria-readonly=true].is-focus,.fd-checkbox[aria-readonly=true]:focus,.fd-checkbox[readonly].is-focus,.fd-checkbox[readonly]:focus{z-index:5}.fd-checkbox,.fd-checkbox.is-error,.fd-checkbox.is-information,.fd-checkbox.is-success,.fd-checkbox.is-warning{border-style:initial}.fd-checkbox__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;white-space:nowrap;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;-webkit-margin-end:.5rem;cursor:text;margin-inline-end:.5rem;-ms-flex-item-align:start;align-self:flex-start;cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:var(--fdCheckbox_Padding);line-height:1rem;margin-block:0;margin-inline:0;padding-block:var(--fdCheckbox_Padding);padding-inline:var(--fdCheckbox_Padding)}.fd-checkbox__label:after,.fd-checkbox__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__label.is-hover .fd-checkbox__checkmark,.fd-checkbox__label:hover .fd-checkbox__checkmark{background-color:var(--fdCheckbox_Hover_Background_Color);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Default_Hover);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Default_Hover);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Default_Hover);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Default_Hover);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Default_Hover)}.fd-checkbox__label:focus{outline:none}.fd-checkbox__label--required .fd-checkbox__text,.fd-checkbox__label[aria-required=true] .fd-checkbox__text{-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-checkbox__label--required .fd-checkbox__text:after,.fd-checkbox__label[aria-required=true] .fd-checkbox__text:after{color:var(--sapField_RequiredColor);content:\"*\"/\"\";font-size:var(--sapFontSize);font-weight:700;position:absolute;-webkit-padding-start:.125rem;padding-inline-start:.125rem}.fd-checkbox__label--wrap .fd-checkbox__label-container{height:auto;white-space:normal}.fd-checkbox__label--wrap .fd-checkbox__text{white-space:normal}.fd-checkbox__label--wrap-top-aligned{-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-checkbox__label--wrap-top-aligned .fd-checkbox__label-container{height:auto;white-space:normal}.fd-checkbox__label--wrap-top-aligned .fd-checkbox__text{white-space:normal}.fd-checkbox__label-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:1rem;max-width:inherit;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-checkbox__label-container:after,.fd-checkbox__label-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:inherit;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-checkbox__text:after,.fd-checkbox__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__checkmark{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--fdCheckbox_Background_Color);border:var(--fdCheckbox_Inner_Border_Width) var(--fdCheckbox_Inner_Border_Style) var(--fdCheckbox_Inner_Border_Color);border-radius:var(--sapField_BorderCornerRadius);color:var(--fdCheckbox_Check_Mark_Color);font-family:SAP-icons;height:var(--fdCheckbox_Dimensions);min-width:var(--fdCheckbox_Dimensions);width:var(--fdCheckbox_Dimensions)}.fd-checkbox__checkmark:after,.fd-checkbox__checkmark:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__checkmark:before{content:\"\"}.fd-checkbox:checked+.fd-checkbox__label .fd-checkbox__checkmark:before{content:\"\\e05b\"}.fd-checkbox:indeterminate+.fd-checkbox__label .fd-checkbox__checkmark:after{background-color:var(--fdCheckbox_Check_Mark_Color);content:\"\";height:var(--fdCheckbox_Tristate_Size);position:absolute;width:var(--fdCheckbox_Tristate_Size)}.fd-checkbox.is-alert+.fd-checkbox__label .fd-checkbox__checkmark,.fd-checkbox.is-warning+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Warning);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Warning);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Warning);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Warning);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Warning);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Warning_Hover)}.fd-checkbox.is-error+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Error);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Error);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Error);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Error);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Error);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Error_Hover)}.fd-checkbox.is-success+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Success);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Success);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Success);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Success);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Success);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Success_Hover)}.fd-checkbox.is-information+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Information);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Information);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Information);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Information);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Information);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Information_Hover)}.fd-checkbox.is-readonly+.fd-checkbox__label .fd-checkbox__checkmark,.fd-checkbox[readonly]+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_ReadOnly);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_ReadOnly);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_ReadOnly);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_ReadOnly);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_ReadOnly);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_ReadOnly)}.fd-checkbox.is-display+.fd-checkbox__label{--fdCheckbox_Check_Mark_Color:var(--sapTextColor);gap:.5rem}.fd-checkbox.is-display+.fd-checkbox__label.is-hover .fd-checkbox__checkmark,.fd-checkbox.is-display+.fd-checkbox__label:hover .fd-checkbox__checkmark{--fdCheckbox_Check_Mark_Color:var(--sapTextColor);--fdCheckbox_Hover_Background_Color:transparent}.fd-checkbox.is-display+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:transparent;--fdCheckbox_Dimensions:1rem;border:none}.fd-checkbox.is-display+.fd-checkbox__label .fd-checkbox__checkmark:before{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;content:\"\\e19a\";font-size:1rem;height:1rem;max-height:1rem;max-width:1rem;min-height:1rem;min-width:1rem;width:1rem}.fd-checkbox.is-display:checked+.fd-checkbox__label .fd-checkbox__checkmark:before{content:\"\\e03f\";font-size:1rem}.fd-checkbox.is-display:indeterminate+.fd-checkbox__label .fd-checkbox__checkmark:before{content:\"\\e295\";font-size:1rem}.fd-checkbox.is-display:indeterminate+.fd-checkbox__label .fd-checkbox__checkmark:after{content:\"\";height:0;width:0}.fd-checkbox.is-focus,.fd-checkbox:focus{z-index:5}.fd-checkbox.is-focus+.fd-checkbox__label,.fd-checkbox:focus+.fd-checkbox__label{border-radius:var(--fdCheckbox_Outline_Border_Radius);outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:calc(var(--fdCheckbox_Focus_Outline_Offset) - var(--fdCheckbox_Padding))}.fd-checkbox.is-disabled,.fd-checkbox:disabled,.fd-checkbox[aria-disabled=true]{opacity:.0001}.fd-checkbox.is-disabled+.fd-checkbox__label,.fd-checkbox:disabled+.fd-checkbox__label,.fd-checkbox[aria-disabled=true]+.fd-checkbox__label{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-checkbox[class*=-compact]+.fd-checkbox__label,.fd-checkbox[class*=-condensed]+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy])+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy])+.fd-checkbox__label{--fdCheckbox_Dimensions:var(--fdCheckbox_Compact_Dimensions);--fdCheckbox_Padding:var(--fdCheckbox_Compact_Padding)}.fd-checkbox[class*=-compact]:indeterminate+.fd-checkbox__label,.fd-checkbox[class*=-condensed]:indeterminate+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy]):indeterminate+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy]):indeterminate+.fd-checkbox__label{--fdCheckbox_Tristate_Size:var(--fdCheckbox_Tristate_Compact_Size);--fdCheckbox_Tristate_Offset:var(--fdCheckbox_Tristate_Compact_Offset)}.fd-checkbox[class*=-compact].is-focus,.fd-checkbox[class*=-compact]:focus,.fd-checkbox[class*=-condensed].is-focus,.fd-checkbox[class*=-condensed]:focus,[class*=-compact] .fd-checkbox:not([class*=-cozy]).is-focus,[class*=-compact] .fd-checkbox:not([class*=-cozy]):focus,[class*=-condensed] .fd-checkbox:not([class*=-cozy]).is-focus,[class*=-condensed] .fd-checkbox:not([class*=-cozy]):focus{z-index:5}.fd-checkbox[class*=-compact].is-focus+.fd-checkbox__label,.fd-checkbox[class*=-compact]:focus+.fd-checkbox__label,.fd-checkbox[class*=-condensed].is-focus+.fd-checkbox__label,.fd-checkbox[class*=-condensed]:focus+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy]).is-focus+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy]):focus+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy]).is-focus+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy]):focus+.fd-checkbox__label{--fdCheckbox_Outline_Border_Radius:var(--fdCheckbox_Compact_Outline_Border_Radius)}fd-checkbox .fd-checkbox__text:empty{margin:0}fd-checkbox .fd-checkbox__label{-webkit-user-select:none;user-select:none}fd-checkbox .fd-checkbox__label-container{pointer-events:auto}fd-checkbox .fd-checkbox.is-disabled+.fd-checkbox__label .fd-checkbox__label-container,fd-checkbox .fd-checkbox.is-readonly+.fd-checkbox__label .fd-checkbox__label-container{pointer-events:none!important}fd-checkbox.fd-checkbox--standalone .fd-checkbox__label{margin:0}fd-checkbox .fd-checkbox.is-display:disabled+.fd-checkbox__label{opacity:1}fd-checkbox .fd-checkbox.is-readonly+.fd-checkbox__label{opacity:1;pointer-events:none;cursor:pointer}fd-checkbox .fd-checkbox.is-readonly:focus,fd-checkbox .fd-checkbox.is-readonly:hover{cursor:pointer}\n/*! Bundled license information:\n\nfundamental-styles/dist/checkbox.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: ContentDensityModule }, { kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i2.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CheckboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-checkbox', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => CheckboxComponent),
                            multi: true
                        },
                        {
                            provide: FD_CHECKBOX_COMPONENT,
                            useExisting: CheckboxComponent
                        },
                        registerFormItemControl(CheckboxComponent),
                        contentDensityObserverProviders()
                    ], host: { '[attr.tabindex]': '-1' }, imports: [FormsModule, NgClass, ContentDensityModule, PortalModule], template: "<input\n    #inputElement\n    type=\"checkbox\"\n    class=\"fd-checkbox\"\n    [id]=\"inputId\"\n    [name]=\"name\"\n    [disabled]=\"disabled || displayOnly\"\n    [readonly]=\"readonly\"\n    [indeterminate]=\"isIndeterminate\"\n    [checked]=\"isChecked\"\n    [attr.tabindex]=\"tabIndexValue\"\n    [attr.role]=\"role\"\n    [attr.aria-checked]=\"isChecked ? 'true' : isIndeterminate ? 'mixed' : 'false'\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledBy\"\n    [attr.aria-describedby]=\"ariaDescribedBy\"\n    [attr.aria-disabled]=\"disabled\"\n    [attr.aria-readonly]=\"readonly\"\n    [attr.aria-required]=\"required\"\n    [ngClass]=\"[displayOnly ? 'is-display' : disabled ? 'is-disabled' : '', state ? 'is-' + state : '']\"\n    (click)=\"_onInputClick($event)\"\n    (blur)=\"_onBlur()\"\n    (focus)=\"_onFocus()\"\n    (keyup.enter)=\"_onLabelKeydown($event)\"\n    (keyup.space)=\"_onLabelKeydown($event)\"\n/>\n<label\n    class=\"fd-checkbox__label\"\n    #labelElement\n    [for]=\"inputId\"\n    [class]=\"labelClass\"\n    [attr.title]=\"title\"\n    [class.fd-checkbox__label--required]=\"required\"\n    [class.fd-checkbox__label--wrap]=\"wrapLabel && valignLabel === 'middle'\"\n    [class.fd-checkbox__label--wrap-top-aligned]=\"wrapLabel && valignLabel === 'top'\"\n    (keyup.enter)=\"_onLabelKeydown($event)\"\n    (keyup.space)=\"_onLabelKeydown($event)\"\n    (click)=\"_onLabelClick($event)\"\n>\n    <span class=\"fd-checkbox__checkmark\" aria-hidden=\"true\"></span>\n    @if (label || _projectedContent) {\n        <div class=\"fd-checkbox__label-container\">\n            @if (label) {\n                <span class=\"fd-checkbox__text\">\n                    {{ label }}\n                </span>\n            } @else {\n                <span class=\"fd-checkbox__text\">\n                    <ng-template cdkPortalOutlet></ng-template>\n                </span>\n            }\n        </div>\n    }\n</label>\n<span [attr.hidden]=\"!_projectedContent ? true : null\" #domPortal>\n    <ng-content></ng-content>\n</span>\n", styles: [".fd-checkbox{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--sapField_Background);border:0;border-color:var(--sapField_BorderColor);border-radius:var(--sapField_BorderCornerRadius);border-style:solid;border-width:var(--sapField_BorderWidth);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapField_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;opacity:.0001;outline:none;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;white-space:nowrap}.fd-checkbox:after,.fd-checkbox:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox::-webkit-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::-moz-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox:-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-checkbox::-moz-selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-checkbox::selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-checkbox.is-success{background:var(--sapField_SuccessBackgroundStyle);background-color:var(--sapField_SuccessBackground);border:var(--sapField_SuccessColor) var(--sapField_SuccessBorderWidth) var(--sapField_SuccessBorderStyle);-webkit-box-shadow:var(--sapField_SuccessShadow);box-shadow:var(--sapField_SuccessShadow)}.fd-checkbox.is-success.is-hover,.fd-checkbox.is-success:hover{background-color:var(--fdInput_Success_Background_Color_Hover);border-color:var(--sapField_SuccessColor);-webkit-box-shadow:var(--fdInput_Success_Box_Shadow_Hover);box-shadow:var(--fdInput_Success_Box_Shadow_Hover)}.fd-checkbox.is-success.is-focus,.fd-checkbox.is-success:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Success_Outline_Color);z-index:5}.fd-checkbox.is-success.is-focus.is-hover,.fd-checkbox.is-success.is-focus:hover,.fd-checkbox.is-success:focus.is-hover,.fd-checkbox.is-success:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-success.is-expanded,.fd-checkbox.is-success[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Success_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-error{background:var(--sapField_InvalidBackgroundStyle);background-color:var(--sapField_InvalidBackground);border:var(--sapField_InvalidColor) var(--sapField_InvalidBorderWidth) var(--sapField_InvalidBorderStyle);-webkit-box-shadow:var(--sapField_InvalidShadow);box-shadow:var(--sapField_InvalidShadow)}.fd-checkbox.is-error.is-hover,.fd-checkbox.is-error:hover{background-color:var(--fdInput_Error_Background_Color_Hover);border-color:var(--sapField_InvalidColor);-webkit-box-shadow:var(--fdInput_Error_Box_Shadow_Hover);box-shadow:var(--fdInput_Error_Box_Shadow_Hover)}.fd-checkbox.is-error.is-focus,.fd-checkbox.is-error:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Error_Outline_Color);z-index:5}.fd-checkbox.is-error.is-focus.is-hover,.fd-checkbox.is-error.is-focus:hover,.fd-checkbox.is-error:focus.is-hover,.fd-checkbox.is-error:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-error.is-expanded,.fd-checkbox.is-error[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Error_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-warning{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle);-webkit-box-shadow:var(--sapField_WarningShadow);box-shadow:var(--sapField_WarningShadow)}.fd-checkbox.is-warning.is-hover,.fd-checkbox.is-warning:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-checkbox.is-warning.is-focus,.fd-checkbox.is-warning:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-checkbox.is-warning.is-focus.is-hover,.fd-checkbox.is-warning.is-focus:hover,.fd-checkbox.is-warning:focus.is-hover,.fd-checkbox.is-warning:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-warning.is-expanded,.fd-checkbox.is-warning[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-alert{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle)}.fd-checkbox.is-alert.is-hover,.fd-checkbox.is-alert:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-checkbox.is-alert.is-focus,.fd-checkbox.is-alert:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-checkbox.is-alert.is-focus.is-hover,.fd-checkbox.is-alert.is-focus:hover,.fd-checkbox.is-alert:focus.is-hover,.fd-checkbox.is-alert:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-alert.is-expanded,.fd-checkbox.is-alert[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-information{background:var(--sapField_InformationBackgroundStyle);background-color:var(--sapField_InformationBackground);border:var(--sapField_InformationColor) var(--sapField_InformationBorderWidth) var(--sapField_InformationBorderStyle);-webkit-box-shadow:var(--sapField_InformationShadow);box-shadow:var(--sapField_InformationShadow)}.fd-checkbox.is-information.is-hover,.fd-checkbox.is-information:hover{background-color:var(--fdInput_Information_Background_Color_Hover);border-color:var(--sapField_InformationColor);-webkit-box-shadow:var(--fdInput_Information_Box_Shadow_Hover);box-shadow:var(--fdInput_Information_Box_Shadow_Hover)}.fd-checkbox.is-information.is-focus,.fd-checkbox.is-information:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Information_Outline_Color);z-index:5}.fd-checkbox.is-information.is-focus.is-hover,.fd-checkbox.is-information.is-focus:hover,.fd-checkbox.is-information:focus.is-hover,.fd-checkbox.is-information:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-information.is-expanded,.fd-checkbox.is-information[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Information_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-checkbox.is-alert.is-focus,.fd-checkbox.is-alert:focus,.fd-checkbox.is-error.is-focus,.fd-checkbox.is-error:focus,.fd-checkbox.is-information.is-focus,.fd-checkbox.is-information:focus,.fd-checkbox.is-warning.is-focus,.fd-checkbox.is-warning:focus{outline-offset:var(--fdInput_Outline_Offset_States);z-index:5}.fd-checkbox.is-disabled,.fd-checkbox:disabled,.fd-checkbox[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-checkbox.is-readonly,.fd-checkbox.is-readonly.is-focus,.fd-checkbox.is-readonly.is-hover,.fd-checkbox.is-readonly:focus,.fd-checkbox.is-readonly:hover,.fd-checkbox[aria-readonly=true],.fd-checkbox[aria-readonly=true].is-focus,.fd-checkbox[aria-readonly=true].is-hover,.fd-checkbox[aria-readonly=true]:focus,.fd-checkbox[aria-readonly=true]:hover,.fd-checkbox[readonly],.fd-checkbox[readonly].is-focus,.fd-checkbox[readonly].is-hover,.fd-checkbox[readonly]:focus,.fd-checkbox[readonly]:hover{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-checkbox.is-readonly.is-focus,.fd-checkbox.is-readonly:focus,.fd-checkbox[aria-readonly=true].is-focus,.fd-checkbox[aria-readonly=true]:focus,.fd-checkbox[readonly].is-focus,.fd-checkbox[readonly]:focus{z-index:5}.fd-checkbox,.fd-checkbox.is-error,.fd-checkbox.is-information,.fd-checkbox.is-success,.fd-checkbox.is-warning{border-style:initial}.fd-checkbox__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;white-space:nowrap;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;-webkit-margin-end:.5rem;cursor:text;margin-inline-end:.5rem;-ms-flex-item-align:start;align-self:flex-start;cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:var(--fdCheckbox_Padding);line-height:1rem;margin-block:0;margin-inline:0;padding-block:var(--fdCheckbox_Padding);padding-inline:var(--fdCheckbox_Padding)}.fd-checkbox__label:after,.fd-checkbox__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__label.is-hover .fd-checkbox__checkmark,.fd-checkbox__label:hover .fd-checkbox__checkmark{background-color:var(--fdCheckbox_Hover_Background_Color);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Default_Hover);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Default_Hover);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Default_Hover);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Default_Hover);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Default_Hover)}.fd-checkbox__label:focus{outline:none}.fd-checkbox__label--required .fd-checkbox__text,.fd-checkbox__label[aria-required=true] .fd-checkbox__text{-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-checkbox__label--required .fd-checkbox__text:after,.fd-checkbox__label[aria-required=true] .fd-checkbox__text:after{color:var(--sapField_RequiredColor);content:\"*\"/\"\";font-size:var(--sapFontSize);font-weight:700;position:absolute;-webkit-padding-start:.125rem;padding-inline-start:.125rem}.fd-checkbox__label--wrap .fd-checkbox__label-container{height:auto;white-space:normal}.fd-checkbox__label--wrap .fd-checkbox__text{white-space:normal}.fd-checkbox__label--wrap-top-aligned{-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-checkbox__label--wrap-top-aligned .fd-checkbox__label-container{height:auto;white-space:normal}.fd-checkbox__label--wrap-top-aligned .fd-checkbox__text{white-space:normal}.fd-checkbox__label-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:1rem;max-width:inherit;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-checkbox__label-container:after,.fd-checkbox__label-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:inherit;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-checkbox__text:after,.fd-checkbox__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__checkmark{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--fdCheckbox_Background_Color);border:var(--fdCheckbox_Inner_Border_Width) var(--fdCheckbox_Inner_Border_Style) var(--fdCheckbox_Inner_Border_Color);border-radius:var(--sapField_BorderCornerRadius);color:var(--fdCheckbox_Check_Mark_Color);font-family:SAP-icons;height:var(--fdCheckbox_Dimensions);min-width:var(--fdCheckbox_Dimensions);width:var(--fdCheckbox_Dimensions)}.fd-checkbox__checkmark:after,.fd-checkbox__checkmark:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-checkbox__checkmark:before{content:\"\"}.fd-checkbox:checked+.fd-checkbox__label .fd-checkbox__checkmark:before{content:\"\\e05b\"}.fd-checkbox:indeterminate+.fd-checkbox__label .fd-checkbox__checkmark:after{background-color:var(--fdCheckbox_Check_Mark_Color);content:\"\";height:var(--fdCheckbox_Tristate_Size);position:absolute;width:var(--fdCheckbox_Tristate_Size)}.fd-checkbox.is-alert+.fd-checkbox__label .fd-checkbox__checkmark,.fd-checkbox.is-warning+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Warning);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Warning);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Warning);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Warning);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Warning);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Warning_Hover)}.fd-checkbox.is-error+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Error);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Error);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Error);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Error);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Error);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Error_Hover)}.fd-checkbox.is-success+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Success);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Success);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Success);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Success);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Success);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Success_Hover)}.fd-checkbox.is-information+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_Information);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_Information);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_Information);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_Information);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_Information);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_Information_Hover)}.fd-checkbox.is-readonly+.fd-checkbox__label .fd-checkbox__checkmark,.fd-checkbox[readonly]+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:var(--fdCheckbox_Background_Color_ReadOnly);--fdCheckbox_Inner_Border_Width:var(--fdCheckbox_Inner_Border_Width_ReadOnly);--fdCheckbox_Inner_Border_Style:var(--fdCheckbox_Inner_Border_Style_ReadOnly);--fdCheckbox_Inner_Border_Color:var(--fdCheckbox_Inner_Border_Color_ReadOnly);--fdCheckbox_Check_Mark_Color:var(--fdCheckbox_Check_Mark_Color_ReadOnly);--fdCheckbox_Hover_Background_Color:var(--fdCheckbox_Background_Color_ReadOnly)}.fd-checkbox.is-display+.fd-checkbox__label{--fdCheckbox_Check_Mark_Color:var(--sapTextColor);gap:.5rem}.fd-checkbox.is-display+.fd-checkbox__label.is-hover .fd-checkbox__checkmark,.fd-checkbox.is-display+.fd-checkbox__label:hover .fd-checkbox__checkmark{--fdCheckbox_Check_Mark_Color:var(--sapTextColor);--fdCheckbox_Hover_Background_Color:transparent}.fd-checkbox.is-display+.fd-checkbox__label .fd-checkbox__checkmark{--fdCheckbox_Background_Color:transparent;--fdCheckbox_Dimensions:1rem;border:none}.fd-checkbox.is-display+.fd-checkbox__label .fd-checkbox__checkmark:before{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;content:\"\\e19a\";font-size:1rem;height:1rem;max-height:1rem;max-width:1rem;min-height:1rem;min-width:1rem;width:1rem}.fd-checkbox.is-display:checked+.fd-checkbox__label .fd-checkbox__checkmark:before{content:\"\\e03f\";font-size:1rem}.fd-checkbox.is-display:indeterminate+.fd-checkbox__label .fd-checkbox__checkmark:before{content:\"\\e295\";font-size:1rem}.fd-checkbox.is-display:indeterminate+.fd-checkbox__label .fd-checkbox__checkmark:after{content:\"\";height:0;width:0}.fd-checkbox.is-focus,.fd-checkbox:focus{z-index:5}.fd-checkbox.is-focus+.fd-checkbox__label,.fd-checkbox:focus+.fd-checkbox__label{border-radius:var(--fdCheckbox_Outline_Border_Radius);outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:calc(var(--fdCheckbox_Focus_Outline_Offset) - var(--fdCheckbox_Padding))}.fd-checkbox.is-disabled,.fd-checkbox:disabled,.fd-checkbox[aria-disabled=true]{opacity:.0001}.fd-checkbox.is-disabled+.fd-checkbox__label,.fd-checkbox:disabled+.fd-checkbox__label,.fd-checkbox[aria-disabled=true]+.fd-checkbox__label{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-checkbox[class*=-compact]+.fd-checkbox__label,.fd-checkbox[class*=-condensed]+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy])+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy])+.fd-checkbox__label{--fdCheckbox_Dimensions:var(--fdCheckbox_Compact_Dimensions);--fdCheckbox_Padding:var(--fdCheckbox_Compact_Padding)}.fd-checkbox[class*=-compact]:indeterminate+.fd-checkbox__label,.fd-checkbox[class*=-condensed]:indeterminate+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy]):indeterminate+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy]):indeterminate+.fd-checkbox__label{--fdCheckbox_Tristate_Size:var(--fdCheckbox_Tristate_Compact_Size);--fdCheckbox_Tristate_Offset:var(--fdCheckbox_Tristate_Compact_Offset)}.fd-checkbox[class*=-compact].is-focus,.fd-checkbox[class*=-compact]:focus,.fd-checkbox[class*=-condensed].is-focus,.fd-checkbox[class*=-condensed]:focus,[class*=-compact] .fd-checkbox:not([class*=-cozy]).is-focus,[class*=-compact] .fd-checkbox:not([class*=-cozy]):focus,[class*=-condensed] .fd-checkbox:not([class*=-cozy]).is-focus,[class*=-condensed] .fd-checkbox:not([class*=-cozy]):focus{z-index:5}.fd-checkbox[class*=-compact].is-focus+.fd-checkbox__label,.fd-checkbox[class*=-compact]:focus+.fd-checkbox__label,.fd-checkbox[class*=-condensed].is-focus+.fd-checkbox__label,.fd-checkbox[class*=-condensed]:focus+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy]).is-focus+.fd-checkbox__label,[class*=-compact] .fd-checkbox:not([class*=-cozy]):focus+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy]).is-focus+.fd-checkbox__label,[class*=-condensed] .fd-checkbox:not([class*=-cozy]):focus+.fd-checkbox__label{--fdCheckbox_Outline_Border_Radius:var(--fdCheckbox_Compact_Outline_Border_Radius)}fd-checkbox .fd-checkbox__text:empty{margin:0}fd-checkbox .fd-checkbox__label{-webkit-user-select:none;user-select:none}fd-checkbox .fd-checkbox__label-container{pointer-events:auto}fd-checkbox .fd-checkbox.is-disabled+.fd-checkbox__label .fd-checkbox__label-container,fd-checkbox .fd-checkbox.is-readonly+.fd-checkbox__label .fd-checkbox__label-container{pointer-events:none!important}fd-checkbox.fd-checkbox--standalone .fd-checkbox__label{margin:0}fd-checkbox .fd-checkbox.is-display:disabled+.fd-checkbox__label{opacity:1}fd-checkbox .fd-checkbox.is-readonly+.fd-checkbox__label{opacity:1;pointer-events:none;cursor:pointer}fd-checkbox .fd-checkbox.is-readonly:focus,fd-checkbox .fd-checkbox.is-readonly:hover{cursor:pointer}\n/*! Bundled license information:\n\nfundamental-styles/dist/checkbox.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: undefined, decorators: [{
                    type: Attribute,
                    args: ['tabIndexValue']
                }] }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: i1.ContentDensityObserver }], propDecorators: { inputElement: [{
                type: ViewChild,
                args: ['inputElement']
            }], labelElement: [{
                type: ViewChild,
                args: ['labelElement']
            }], wrapLabel: [{
                type: Input
            }], valignLabel: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], role: [{
                type: Input
            }], value: [{
                type: Input
            }], ariaLabelledBy: [{
                type: Input
            }], ariaDescribedBy: [{
                type: Input
            }], title: [{
                type: Input
            }], inputId: [{
                type: Input
            }], state: [{
                type: Input
            }], name: [{
                type: Input
            }], label: [{
                type: Input
            }], disabled: [{
                type: Input
            }], readonly: [{
                type: Input
            }], tristate: [{
                type: Input
            }], tristateSelectable: [{
                type: Input
            }], labelClass: [{
                type: Input
            }], required: [{
                type: Input
            }], displayOnly: [{
                type: Input
            }], values: [{
                type: Input
            }], standalone: [{
                type: HostBinding,
                args: ['class.fd-checkbox--standalone']
            }, {
                type: Input
            }], position: [{
                type: HostBinding,
                args: ['style.position']
            }], outline: [{
                type: HostBinding,
                args: ['style.outline']
            }], focusChange: [{
                type: Output
            }], _domPortalContent: [{
                type: ViewChild,
                args: ['domPortal']
            }], _portalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet, { static: false }]
            }] } });

class CheckboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: CheckboxModule, imports: [ContentDensityModule, CheckboxComponent], exports: [CheckboxComponent, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CheckboxModule, imports: [ContentDensityModule, CheckboxComponent, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ContentDensityModule, CheckboxComponent],
                    exports: [CheckboxComponent, ContentDensityModule]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CheckboxComponent, CheckboxModule, FD_CHECKBOX_COMPONENT, FD_CHECKBOX_VALUES_DEFAULT };
//# sourceMappingURL=fundamental-ngx-core-checkbox.mjs.map
