import * as i0 from '@angular/core';
import { HostBinding, Input, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import * as i1 from '@angular/platform-browser';

class HtmlSanitizer {
    /** @hidden */
    constructor() {
        /** @hidden */
        this.tagWhitelist = {};
        /** @hidden */
        this.attributeWhitelist = {};
        /** @hidden */
        this._schemaWhiteList = ['http', 'https', 'ftp', 'mailto'];
        /** @hidden */
        this._uriAttributes = {
            href: true
        };
        /** @hidden */
        this._safeWrapper = {
            iframe: null,
            iframeDoc: null
        };
        this.extendTags();
    }
    /** @hidden */
    get defTagWhitelist() {
        return {
            A: true,
            ABBR: true,
            BLOCKQUOTE: true,
            BR: true,
            CITE: true,
            CODE: true,
            DL: true,
            DT: true,
            DD: true,
            EM: true,
            H1: true,
            H2: true,
            H3: true,
            H4: true,
            H5: true,
            H6: true,
            P: true,
            PRE: true,
            STRONG: true,
            SPAN: true,
            U: true,
            UL: true,
            OL: true,
            LI: true
        };
    }
    /** @hidden */
    get defAttributeWhitelist() {
        return {
            class: true,
            style: true,
            href: true,
            target: '_blank',
            download: true,
            hreflang: true,
            rel: true,
            type: true,
            title: true
        };
    }
    /** @hidden */
    extendTags(customTags) {
        this.tagWhitelist = { ...this.defTagWhitelist, ...customTags, BODY: true };
    }
    /** @hidden */
    extendAttrs(customAttrs) {
        this.attributeWhitelist = { ...this.defAttributeWhitelist, ...customAttrs };
    }
    /** @hidden */
    sanitizeHtml(input) {
        input = input.trim();
        if (input.length === 0) {
            return '';
        }
        this._safeWrapper = this._getSafeWrapper();
        if (!this._safeWrapper?.iframeDoc) {
            return '';
        }
        this._safeWrapper.iframeDoc.body.innerHTML = input;
        const resultElement = this._makeSanitizedCopy(this._safeWrapper.iframeDoc.body);
        this._removeSafeWrapper();
        return resultElement.innerHTML;
    }
    /** @hidden */
    _makeSanitizedCopy(node) {
        let newNode = node;
        if (node.nodeType === Node.TEXT_NODE) {
            newNode = node.cloneNode(true);
        }
        else if (node.nodeType === Node.ELEMENT_NODE && this.tagWhitelist[node.tagName]) {
            newNode = this._extendLinkTarget(this._implementTag(node));
        }
        else {
            newNode = document.createDocumentFragment();
        }
        return newNode;
    }
    /** @hidden */
    _implementTag(node) {
        const newNode = this._safeWrapper?.iframeDoc?.createElement(node.tagName);
        if (!newNode) {
            throw new Error('Failed to create node');
        }
        for (const key in this.attributeWhitelist) {
            if (this.attributeWhitelist[key]) {
                const allowed = this.attributeWhitelist[key];
                const origin = node.getAttribute(key);
                if (key in node || key === 'class') {
                    if (this._uriAttributes[key] && this._validateBySchema(origin)) {
                        continue;
                    }
                    switch (typeof allowed) {
                        case 'string':
                            newNode.setAttribute(key, allowed);
                            break;
                        default:
                            if (allowed && origin) {
                                newNode.setAttribute(key, origin);
                            }
                    }
                }
            }
        }
        for (const child of Array.from(node.childNodes)) {
            const subCopy = this._makeSanitizedCopy(child);
            if (subCopy) {
                newNode.appendChild(subCopy);
            }
        }
        return newNode;
    }
    /** @hidden */
    _extendLinkTarget(node) {
        if (node.tagName === 'A') {
            const hrefAttr = node.getAttribute('href');
            if (!hrefAttr || /^#/.test(hrefAttr)) {
                node.removeAttribute('target');
            }
            else {
                const defTarget = this.attributeWhitelist['target'] || '_blank';
                node.setAttribute('target', defTarget.toString());
            }
        }
        return node;
    }
    /** @hidden */
    _getSafeWrapper() {
        const iframe = document.createElement('iframe');
        if (iframe.sandbox === undefined) {
            console.warn('Your browser does not support sandboxed iframes. Please upgrade to a modern browser.');
            return null;
        }
        iframe.setAttribute('sandbox', 'allow-same-origin');
        iframe.style.setProperty('display', 'none');
        document.body.appendChild(iframe);
        const iframeDoc = iframe.contentDocument || iframe.contentWindow?.document;
        if (!iframeDoc) {
            console.warn('Could not resolve document from the provided iframe');
            return null;
        }
        if (!iframeDoc?.body) {
            iframeDoc.write('<body></body>');
        }
        return { iframe, iframeDoc };
    }
    /** @hidden */
    _removeSafeWrapper() {
        if (this._safeWrapper?.iframe) {
            document.body.removeChild(this._safeWrapper.iframe);
        }
    }
    /** @hidden */
    _validateBySchema(value) {
        return !!value && value.indexOf(':') > -1 && !this._startsWithAny(value, this._schemaWhiteList);
    }
    /** @hidden */
    _startsWithAny(str, substrings) {
        return !!str && substrings.some((value) => str.indexOf(value) === 0);
    }
}

/**
 * Formatted-text allowed tags, only this tags will render in component, other will skip;
 *
 * ``` selector: fd-formatted-text ```
 *
 * ```html
 * <fd-formatted-text [htmlText]="..."></fd-formatted-text>
 * ```
 */
class FormattedTextComponent {
    /** @hidden */
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
        /**
         * Target attribute for included links.
         */
        this.convertedLinksDefaultTarget = '_blank';
        /** @hidden */
        this.formattedText = '';
        this._htmlSanitizer = new HtmlSanitizer();
    }
    /** @hidden */
    ngOnInit() {
        this.render();
    }
    /** @hidden */
    ngOnChanges(changes) {
        if ('htmlText' in changes) {
            this.render();
        }
    }
    /** @hidden */
    render() {
        this._htmlSanitizer.extendAttrs({
            target: this.convertedLinksDefaultTarget
        });
        const text = this._htmlSanitizer.sanitizeHtml(this.htmlText ?? '');
        this.formattedText = this.domSanitizer.bypassSecurityTrustHtml(text.trim());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: FormattedTextComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: FormattedTextComponent, isStandalone: true, selector: "fd-formatted-text", inputs: { htmlText: "htmlText", convertedLinksDefaultTarget: "convertedLinksDefaultTarget", height: "height", width: "width" }, host: { properties: { "class.fd-formatted-text-with-height": "this.height", "style.height": "this.height", "class.fd-formatted-text-with-width": "this.width", "style.width": "this.width", "innerHTML": "this.formattedText" } }, exportAs: ["fd-formatted-text"], usesOnChanges: true, ngImport: i0, template: ``, isInline: true, styles: ["fd-formatted-text{display:block}fd-formatted-text.fd-formatted-text-with-height{overflow-y:auto}fd-formatted-text.fd-formatted-text-with-width{overflow-x:auto}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: FormattedTextComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-formatted-text', exportAs: 'fd-formatted-text', template: ``, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, styles: ["fd-formatted-text{display:block}fd-formatted-text.fd-formatted-text-with-height{overflow-y:auto}fd-formatted-text.fd-formatted-text-with-width{overflow-x:auto}\n"] }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }], propDecorators: { htmlText: [{
                type: Input
            }], convertedLinksDefaultTarget: [{
                type: Input
            }], height: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-formatted-text-with-height']
            }, {
                type: HostBinding,
                args: ['style.height']
            }], width: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-formatted-text-with-width']
            }, {
                type: HostBinding,
                args: ['style.width']
            }], formattedText: [{
                type: HostBinding,
                args: ['innerHTML']
            }] } });

/**
 * @deprecated
 * Import `FormattedTextComponent` directly as a standalone component.
 */
class FormattedTextModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: FormattedTextModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: FormattedTextModule, imports: [FormattedTextComponent], exports: [FormattedTextComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: FormattedTextModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: FormattedTextModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [FormattedTextComponent],
                    imports: [FormattedTextComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FormattedTextComponent, FormattedTextModule };
//# sourceMappingURL=fundamental-ngx-core-formatted-text.mjs.map
