import { __decorate, __metadata } from 'tslib';
import { coerceNumberProperty } from '@angular/cdk/coercion';
import * as i0 from '@angular/core';
import { InjectionToken, forwardRef, booleanAttribute, Input, ViewChild, ViewEncapsulation, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import * as i2 from '@angular/forms';
import { FormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import { applyCssClass } from '@fundamental-ngx/cdk/utils';
import * as i1 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders, ContentDensityModule } from '@fundamental-ngx/core/content-density';
import { registerFormItemControl } from '@fundamental-ngx/core/form';
import { Subscription } from 'rxjs';

const FD_RADIO_BUTTON_COMPONENT = new InjectionToken('FdRadioButtonComponent');

let uniqueId = 0;
class RadioButtonComponent {
    /**
     * Includes the radio in the page tab sequence.
     */
    set tabIndex(value) {
        this._tabIndex = coerceNumberProperty(value);
    }
    get tabIndex() {
        return this._tabIndex;
    }
    /** The field should be only used with reactive forms
     * Its purpose is to pass a current selected value from froumGroup
     * The field is mandatory when working with reactive forms
     */
    set selectedValue(val) {
        this.currentValue = val;
        this._setNativeElementCheckedState();
    }
    /** Whether the radio button is checked. */
    get checked() {
        if (this.value === undefined) {
            return false;
        }
        return this.currentValue === this.value;
    }
    /** @hidden */
    constructor(changeDetectionRef, _contentDensityObserver) {
        this.changeDetectionRef = changeDetectionRef;
        this._contentDensityObserver = _contentDensityObserver;
        /** The field to set state of radio button using:
         * 'success' | 'error' | 'warning' | 'default' | 'information'
         * by default value is set to 'default'
         */
        this.state = 'default';
        /** The field is used to tell if radio button should be disabled
         * Value: true or false
         * by default disabled state is set to false
         */
        this.disabled = false;
        /** The field is used to tell if radio button should be read only */
        this.readOnly = false;
        /**
         * uniqueId to a radio button
         */
        this.id = `radio-id-${uniqueId++}`;
        /** If it is a mandatory field */
        this.required = false;
        /** Whether the control is a standalone. */
        this.standalone = false;
        /** Vertical position of the label compared to the radio button */
        this.valignLabel = 'middle';
        /** @hidden */
        this._subscriptions = new Subscription();
        /** @hidden */
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        this.onChange = (value) => { };
        /** @hidden */
        this.onTouched = () => { };
    }
    /** This method is responsible for building a css class based on current state
     *  It is implementation of CssClassBuilder interface and
     *  should be used with @applyCssClass decorator
     */
    buildComponentCssClass() {
        return ['fd-radio', this.state !== 'default' ? `is-${this.state}` : ''];
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
        this._checkMandatoryFields();
    }
    /** @hidden */
    ngAfterViewInit() {
        this.buildComponentCssClass();
        this._checkMandatoryFields();
    }
    /** @hidden */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /** @hidden */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /** @hidden */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
        this.changeDetectionRef.detectChanges();
    }
    /** @hidden */
    setReadonlyState(isReadonly) {
        this.readOnly = isReadonly;
        this.changeDetectionRef.detectChanges();
    }
    /** @hidden */
    writeValue(value) {
        this.valueChange(value, false);
    }
    // End implementation
    /** @hidden */
    get elementRef() {
        return this.inputElement;
    }
    /** @hidden */
    labelClicked(event, applyFocus = true) {
        if (!this.readOnly && !this.disabled) {
            this.valueChange(this.value);
        }
        if (applyFocus) {
            this._setFocusOnNativeElement();
        }
        event.stopPropagation();
    }
    /** @hidden */
    valueChange(value, emitEvent = true) {
        this.currentValue = value;
        this._setNativeElementCheckedState();
        this.changeDetectionRef.detectChanges();
        if (emitEvent) {
            this.onChange(value);
        }
    }
    /** @hidden */
    _checkMandatoryFields() {
        if (this.standalone) {
            return;
        }
        if (this.name === undefined) {
            throw new Error('name field is required');
        }
        if (this.value === undefined) {
            throw new Error('value field is required');
        }
    }
    /** @hidden */
    _setFocusOnNativeElement() {
        if (this.inputElement) {
            this.inputElement.nativeElement.focus();
        }
    }
    /** @hidden */
    _setNativeElementCheckedState() {
        if (this.inputElement) {
            this.inputElement.nativeElement.checked = this.checked;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: RadioButtonComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "16.1.0", version: "20.0.2", type: RadioButtonComponent, isStandalone: true, selector: "fd-radio-button", inputs: { ariaLabel: "ariaLabel", ariaLabelledBy: "ariaLabelledBy", ariaDescribedBy: "ariaDescribedBy", title: "title", tabIndex: "tabIndex", state: "state", disabled: "disabled", readOnly: "readOnly", selectedValue: "selectedValue", name: "name", id: "id", value: "value", required: "required", standalone: "standalone", wrapLabel: ["wrapLabel", "wrapLabel", booleanAttribute], valignLabel: "valignLabel" }, host: { listeners: { "focusout": "onTouched()" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => RadioButtonComponent),
                multi: true
            },
            {
                provide: FD_RADIO_BUTTON_COMPONENT,
                useExisting: RadioButtonComponent
            },
            registerFormItemControl(RadioButtonComponent),
            contentDensityObserverProviders()
        ], viewQueries: [{ propertyName: "inputElement", first: true, predicate: ["inputElement"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<input\n    type=\"radio\"\n    class=\"fd-radio\"\n    [class.is-compact]=\"_contentDensityObserver.isCompactSignal()\"\n    [disabled]=\"disabled\"\n    [readOnly]=\"readOnly\"\n    [id]=\"id\"\n    [attr.name]=\"name\"\n    [name]=\"name\"\n    [attr.tabindex]=\"tabIndex\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledBy\"\n    [attr.aria-describedby]=\"ariaDescribedBy\"\n    [attr.aria-disabled]=\"disabled\"\n    [attr.aria-checked]=\"checked\"\n    [attr.aria-required]=\"required\"\n    [attr.aria-readonly]=\"readOnly\"\n    [ngModel]=\"currentValue\"\n    (ngModelChange)=\"valueChange($event)\"\n    [ngModelOptions]=\"{ standalone: standalone }\"\n    #inputElement\n    [value]=\"value\"\n    [attr.value]=\"value\"\n/>\n<label\n    class=\"fd-radio__label\"\n    [class.fd-radio__label--wrap]=\"wrapLabel && valignLabel === 'middle'\"\n    [class.fd-radio__label--wrap-top-aligned]=\"wrapLabel && valignLabel === 'top'\"\n    [attr.title]=\"title\"\n    [for]=\"id\"\n    (click)=\"labelClicked($event)\"\n>\n    <span class=\"fd-radio__text\">\n        <ng-content></ng-content>\n    </span>\n</label>\n", styles: [".fd-radio{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--sapField_Background);border:0;border-color:var(--sapField_BorderColor);border-radius:var(--sapField_BorderCornerRadius);border-style:solid;border-width:var(--sapField_BorderWidth);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapField_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;opacity:.0001;outline:none;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;white-space:nowrap}.fd-radio:after,.fd-radio:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-radio::-webkit-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::-moz-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio:-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::-moz-selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-radio::selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-radio.is-success{background:var(--sapField_SuccessBackgroundStyle);background-color:var(--sapField_SuccessBackground);border:var(--sapField_SuccessColor) var(--sapField_SuccessBorderWidth) var(--sapField_SuccessBorderStyle);-webkit-box-shadow:var(--sapField_SuccessShadow);box-shadow:var(--sapField_SuccessShadow)}.fd-radio.is-success.is-hover,.fd-radio.is-success:hover{background-color:var(--fdInput_Success_Background_Color_Hover);border-color:var(--sapField_SuccessColor);-webkit-box-shadow:var(--fdInput_Success_Box_Shadow_Hover);box-shadow:var(--fdInput_Success_Box_Shadow_Hover)}.fd-radio.is-success.is-focus,.fd-radio.is-success:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Success_Outline_Color);z-index:5}.fd-radio.is-success.is-focus.is-hover,.fd-radio.is-success.is-focus:hover,.fd-radio.is-success:focus.is-hover,.fd-radio.is-success:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-success.is-expanded,.fd-radio.is-success[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Success_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-error{background:var(--sapField_InvalidBackgroundStyle);background-color:var(--sapField_InvalidBackground);border:var(--sapField_InvalidColor) var(--sapField_InvalidBorderWidth) var(--sapField_InvalidBorderStyle);-webkit-box-shadow:var(--sapField_InvalidShadow);box-shadow:var(--sapField_InvalidShadow)}.fd-radio.is-error.is-hover,.fd-radio.is-error:hover{background-color:var(--fdInput_Error_Background_Color_Hover);border-color:var(--sapField_InvalidColor);-webkit-box-shadow:var(--fdInput_Error_Box_Shadow_Hover);box-shadow:var(--fdInput_Error_Box_Shadow_Hover)}.fd-radio.is-error.is-focus,.fd-radio.is-error:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Error_Outline_Color);z-index:5}.fd-radio.is-error.is-focus.is-hover,.fd-radio.is-error.is-focus:hover,.fd-radio.is-error:focus.is-hover,.fd-radio.is-error:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-error.is-expanded,.fd-radio.is-error[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Error_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-warning{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle);-webkit-box-shadow:var(--sapField_WarningShadow);box-shadow:var(--sapField_WarningShadow)}.fd-radio.is-warning.is-hover,.fd-radio.is-warning:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-radio.is-warning.is-focus,.fd-radio.is-warning:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-radio.is-warning.is-focus.is-hover,.fd-radio.is-warning.is-focus:hover,.fd-radio.is-warning:focus.is-hover,.fd-radio.is-warning:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-warning.is-expanded,.fd-radio.is-warning[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-alert{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle)}.fd-radio.is-alert.is-hover,.fd-radio.is-alert:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-radio.is-alert.is-focus,.fd-radio.is-alert:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-radio.is-alert.is-focus.is-hover,.fd-radio.is-alert.is-focus:hover,.fd-radio.is-alert:focus.is-hover,.fd-radio.is-alert:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-alert.is-expanded,.fd-radio.is-alert[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-information{background:var(--sapField_InformationBackgroundStyle);background-color:var(--sapField_InformationBackground);border:var(--sapField_InformationColor) var(--sapField_InformationBorderWidth) var(--sapField_InformationBorderStyle);-webkit-box-shadow:var(--sapField_InformationShadow);box-shadow:var(--sapField_InformationShadow)}.fd-radio.is-information.is-hover,.fd-radio.is-information:hover{background-color:var(--fdInput_Information_Background_Color_Hover);border-color:var(--sapField_InformationColor);-webkit-box-shadow:var(--fdInput_Information_Box_Shadow_Hover);box-shadow:var(--fdInput_Information_Box_Shadow_Hover)}.fd-radio.is-information.is-focus,.fd-radio.is-information:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Information_Outline_Color);z-index:5}.fd-radio.is-information.is-focus.is-hover,.fd-radio.is-information.is-focus:hover,.fd-radio.is-information:focus.is-hover,.fd-radio.is-information:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-information.is-expanded,.fd-radio.is-information[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Information_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-alert.is-focus,.fd-radio.is-alert:focus,.fd-radio.is-error.is-focus,.fd-radio.is-error:focus,.fd-radio.is-information.is-focus,.fd-radio.is-information:focus,.fd-radio.is-warning.is-focus,.fd-radio.is-warning:focus{outline-offset:var(--fdInput_Outline_Offset_States);z-index:5}.fd-radio.is-disabled,.fd-radio:disabled,.fd-radio[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-radio.is-readonly,.fd-radio.is-readonly.is-focus,.fd-radio.is-readonly.is-hover,.fd-radio.is-readonly:focus,.fd-radio.is-readonly:hover,.fd-radio[aria-readonly=true],.fd-radio[aria-readonly=true].is-focus,.fd-radio[aria-readonly=true].is-hover,.fd-radio[aria-readonly=true]:focus,.fd-radio[aria-readonly=true]:hover,.fd-radio[readonly],.fd-radio[readonly].is-focus,.fd-radio[readonly].is-hover,.fd-radio[readonly]:focus,.fd-radio[readonly]:hover{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-readonly.is-focus,.fd-radio.is-readonly:focus,.fd-radio[aria-readonly=true].is-focus,.fd-radio[aria-readonly=true]:focus,.fd-radio[readonly].is-focus,.fd-radio[readonly]:focus{z-index:5}.fd-radio__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;padding-block:0;padding-inline:0;position:relative;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;-webkit-margin-end:.5rem;cursor:text;margin-inline-end:.5rem;-ms-flex-item-align:start;align-self:flex-start;cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;line-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapField_TextColor);padding-block:var(--fdRadio_Outer_Circle_Padding);padding-inline:var(--fdRadio_Outer_Circle_Padding)}.fd-radio__label:after,.fd-radio__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-radio__label:before{content:\"\";display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;height:var(--fdRadio_Inner_Circle_Diameter);min-width:var(--fdRadio_Inner_Circle_Diameter);width:var(--fdRadio_Inner_Circle_Diameter);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-radius:50%;-webkit-margin-end:var(--fdRadio_Outer_Circle_Padding);background-color:var(--fdRadio_Background_Color);border:var(--fdRadio_Inner_Border_Width) var(--fdRadio_Inner_Border_Style) var(--fdRadio_Inner_Border_Color);margin-inline-end:var(--fdRadio_Outer_Circle_Padding)}.fd-radio__label:after{height:var(--fdRadio_Inner_Content_Size);left:var(--fdRadio_Inner_Content_Padding);min-width:var(--fdRadio_Inner_Content_Size);width:var(--fdRadio_Inner_Content_Size)}.fd-radio__label.is-focus,.fd-radio__label:focus{outline:none;z-index:5}.fd-radio__label.is-hover:before,.fd-radio__label:hover:before{background-color:var(--fdRadio_Hover_Background_Color);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Default_Hover);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Default_Hover);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Default_Hover);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Default_Hover);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Default_Hover)}.fd-radio__label[dir=rtl]:after,[dir=rtl] .fd-radio__label:after{right:var(--fdRadio_Inner_Content_Padding)}.fd-radio__label.is-empty,.fd-radio__label:empty{margin-block:0;margin-inline:0;padding-block:var(--fdRadio_Outer_Circle_Padding);padding-inline:var(--fdRadio_Outer_Circle_Padding)}.fd-radio__label.is-empty:after,.fd-radio__label.is-empty:before,.fd-radio__label:empty:after,.fd-radio__label:empty:before{margin-inline:0}.fd-radio__label--wrap .fd-radio__text{white-space:normal}.fd-radio__label--wrap-top-aligned{-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-radio__label--wrap-top-aligned .fd-radio__text{white-space:normal}.fd-radio__label--wrap-top-aligned:after{top:var(--fdRadio_Inner_Content_Padding)}.fd-radio__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-radio__text:after,.fd-radio__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-radio:checked+.fd-radio__label:after{background:var(--fdRadio_Active_Dot_Color);border-radius:50%;content:\"\";position:absolute}.fd-radio.is-error+.fd-radio__label:before,.fd-radio.is-error:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Error);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Error);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Error);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Error);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Error);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Error_Hover)}.fd-radio.is-alert+.fd-radio__label:before,.fd-radio.is-alert:checked+.fd-radio__label:after,.fd-radio.is-warning+.fd-radio__label:before,.fd-radio.is-warning:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Warning);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Warning);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Warning);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Warning);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Warning);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Warning_Hover)}.fd-radio.is-success+.fd-radio__label:before,.fd-radio.is-success:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Success);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Success);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Success);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Success);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Success);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Success_Hover)}.fd-radio.is-information+.fd-radio__label:before,.fd-radio.is-information:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Information);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Information);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Information);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Information);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Information);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Information_Hover)}.fd-radio.is-readonly+.fd-radio__label:before,.fd-radio.is-readonly:checked+.fd-radio__label:after,.fd-radio[aria-readonly=true]+.fd-radio__label:before,.fd-radio[aria-readonly=true]:checked+.fd-radio__label:after,.fd-radio[readonly]+.fd-radio__label:before,.fd-radio[readonly]:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_ReadOnly);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_ReadOnly);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_ReadOnly);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_ReadOnly);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_ReadOnly);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_ReadOnly)}.fd-radio.is-focus,.fd-radio:focus{z-index:5}.fd-radio.is-focus+.fd-radio__label,.fd-radio:focus+.fd-radio__label{border-radius:var(--fdRadio_Outline_Border_Radius);outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:calc(var(--fdRadio_Focus_Outline_Offset) - var(--fdRadio_Outer_Circle_Padding))}.fd-radio.is-disabled,.fd-radio:disabled,.fd-radio[aria-disabled=true]{opacity:.0001}.fd-radio.is-disabled+.fd-radio__label,.fd-radio:disabled+.fd-radio__label,.fd-radio[aria-disabled=true]+.fd-radio__label{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-radio[class*=-compact]+.fd-radio__label,.fd-radio[class*=-condensed]+.fd-radio__label,[class*=-compact] .fd-radio:not([class*=-cozy])+.fd-radio__label,[class*=-condensed] .fd-radio:not([class*=-cozy])+.fd-radio__label{--fdRadio_Outer_Circle_Padding:var(--fdRadio_Compact_Outer_Circle_Padding);--fdRadio_Inner_Circle_Diameter:var(--fdRadio_Compact_Inner_Circle_Diameter);--fdRadio_Inner_Content_Size:var(--fdRadio_Inner_Content_Size_Compact);--fdRadio_Inner_Content_Padding:var(--fdRadio_Inner_Content_Padding_Compact)}.fd-radio[class*=-compact].is-focus,.fd-radio[class*=-compact]:focus,.fd-radio[class*=-condensed].is-focus,.fd-radio[class*=-condensed]:focus,[class*=-compact] .fd-radio:not([class*=-cozy]).is-focus,[class*=-compact] .fd-radio:not([class*=-cozy]):focus,[class*=-condensed] .fd-radio:not([class*=-cozy]).is-focus,[class*=-condensed] .fd-radio:not([class*=-cozy]):focus{z-index:5}.fd-radio[class*=-compact].is-focus+.fd-radio__label,.fd-radio[class*=-compact]:focus+.fd-radio__label,.fd-radio[class*=-condensed].is-focus+.fd-radio__label,.fd-radio[class*=-condensed]:focus+.fd-radio__label,[class*=-compact] .fd-radio:not([class*=-cozy]).is-focus+.fd-radio__label,[class*=-compact] .fd-radio:not([class*=-cozy]):focus+.fd-radio__label,[class*=-condensed] .fd-radio:not([class*=-cozy]).is-focus+.fd-radio__label,[class*=-condensed] .fd-radio:not([class*=-cozy]):focus+.fd-radio__label{--fdRadio_Outer_Circle_Padding:var(--fdRadio_Compact_Outer_Circle_Padding);--fdRadio_Outline_Border_Radius:var(--fdRadio_Compact_Outline_Border_radius)}\n/*! Bundled license information:\n\nfundamental-styles/dist/radio.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.RadioControlValueAccessor, selector: "input[type=radio][formControlName],input[type=radio][formControl],input[type=radio][ngModel]", inputs: ["name", "formControlName", "value"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], RadioButtonComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: RadioButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-radio-button', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => RadioButtonComponent),
                            multi: true
                        },
                        {
                            provide: FD_RADIO_BUTTON_COMPONENT,
                            useExisting: RadioButtonComponent
                        },
                        registerFormItemControl(RadioButtonComponent),
                        contentDensityObserverProviders()
                    ], host: {
                        '(focusout)': 'onTouched()'
                    }, imports: [FormsModule], template: "<input\n    type=\"radio\"\n    class=\"fd-radio\"\n    [class.is-compact]=\"_contentDensityObserver.isCompactSignal()\"\n    [disabled]=\"disabled\"\n    [readOnly]=\"readOnly\"\n    [id]=\"id\"\n    [attr.name]=\"name\"\n    [name]=\"name\"\n    [attr.tabindex]=\"tabIndex\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledBy\"\n    [attr.aria-describedby]=\"ariaDescribedBy\"\n    [attr.aria-disabled]=\"disabled\"\n    [attr.aria-checked]=\"checked\"\n    [attr.aria-required]=\"required\"\n    [attr.aria-readonly]=\"readOnly\"\n    [ngModel]=\"currentValue\"\n    (ngModelChange)=\"valueChange($event)\"\n    [ngModelOptions]=\"{ standalone: standalone }\"\n    #inputElement\n    [value]=\"value\"\n    [attr.value]=\"value\"\n/>\n<label\n    class=\"fd-radio__label\"\n    [class.fd-radio__label--wrap]=\"wrapLabel && valignLabel === 'middle'\"\n    [class.fd-radio__label--wrap-top-aligned]=\"wrapLabel && valignLabel === 'top'\"\n    [attr.title]=\"title\"\n    [for]=\"id\"\n    (click)=\"labelClicked($event)\"\n>\n    <span class=\"fd-radio__text\">\n        <ng-content></ng-content>\n    </span>\n</label>\n", styles: [".fd-radio{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--sapField_Background);border:0;border-color:var(--sapField_BorderColor);border-radius:var(--sapField_BorderCornerRadius);border-style:solid;border-width:var(--sapField_BorderWidth);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapField_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;opacity:.0001;outline:none;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;white-space:nowrap}.fd-radio:after,.fd-radio:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-radio::-webkit-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::-moz-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio:-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::placeholder{color:var(--sapField_PlaceholderTextColor);font-style:italic}.fd-radio::-moz-selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-radio::selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-radio.is-success{background:var(--sapField_SuccessBackgroundStyle);background-color:var(--sapField_SuccessBackground);border:var(--sapField_SuccessColor) var(--sapField_SuccessBorderWidth) var(--sapField_SuccessBorderStyle);-webkit-box-shadow:var(--sapField_SuccessShadow);box-shadow:var(--sapField_SuccessShadow)}.fd-radio.is-success.is-hover,.fd-radio.is-success:hover{background-color:var(--fdInput_Success_Background_Color_Hover);border-color:var(--sapField_SuccessColor);-webkit-box-shadow:var(--fdInput_Success_Box_Shadow_Hover);box-shadow:var(--fdInput_Success_Box_Shadow_Hover)}.fd-radio.is-success.is-focus,.fd-radio.is-success:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Success_Outline_Color);z-index:5}.fd-radio.is-success.is-focus.is-hover,.fd-radio.is-success.is-focus:hover,.fd-radio.is-success:focus.is-hover,.fd-radio.is-success:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-success.is-expanded,.fd-radio.is-success[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Success_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-error{background:var(--sapField_InvalidBackgroundStyle);background-color:var(--sapField_InvalidBackground);border:var(--sapField_InvalidColor) var(--sapField_InvalidBorderWidth) var(--sapField_InvalidBorderStyle);-webkit-box-shadow:var(--sapField_InvalidShadow);box-shadow:var(--sapField_InvalidShadow)}.fd-radio.is-error.is-hover,.fd-radio.is-error:hover{background-color:var(--fdInput_Error_Background_Color_Hover);border-color:var(--sapField_InvalidColor);-webkit-box-shadow:var(--fdInput_Error_Box_Shadow_Hover);box-shadow:var(--fdInput_Error_Box_Shadow_Hover)}.fd-radio.is-error.is-focus,.fd-radio.is-error:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Error_Outline_Color);z-index:5}.fd-radio.is-error.is-focus.is-hover,.fd-radio.is-error.is-focus:hover,.fd-radio.is-error:focus.is-hover,.fd-radio.is-error:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-error.is-expanded,.fd-radio.is-error[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Error_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-warning{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle);-webkit-box-shadow:var(--sapField_WarningShadow);box-shadow:var(--sapField_WarningShadow)}.fd-radio.is-warning.is-hover,.fd-radio.is-warning:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-radio.is-warning.is-focus,.fd-radio.is-warning:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-radio.is-warning.is-focus.is-hover,.fd-radio.is-warning.is-focus:hover,.fd-radio.is-warning:focus.is-hover,.fd-radio.is-warning:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-warning.is-expanded,.fd-radio.is-warning[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-alert{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle)}.fd-radio.is-alert.is-hover,.fd-radio.is-alert:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-radio.is-alert.is-focus,.fd-radio.is-alert:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-radio.is-alert.is-focus.is-hover,.fd-radio.is-alert.is-focus:hover,.fd-radio.is-alert:focus.is-hover,.fd-radio.is-alert:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-alert.is-expanded,.fd-radio.is-alert[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-information{background:var(--sapField_InformationBackgroundStyle);background-color:var(--sapField_InformationBackground);border:var(--sapField_InformationColor) var(--sapField_InformationBorderWidth) var(--sapField_InformationBorderStyle);-webkit-box-shadow:var(--sapField_InformationShadow);box-shadow:var(--sapField_InformationShadow)}.fd-radio.is-information.is-hover,.fd-radio.is-information:hover{background-color:var(--fdInput_Information_Background_Color_Hover);border-color:var(--sapField_InformationColor);-webkit-box-shadow:var(--fdInput_Information_Box_Shadow_Hover);box-shadow:var(--fdInput_Information_Box_Shadow_Hover)}.fd-radio.is-information.is-focus,.fd-radio.is-information:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Information_Outline_Color);z-index:5}.fd-radio.is-information.is-focus.is-hover,.fd-radio.is-information.is-focus:hover,.fd-radio.is-information:focus.is-hover,.fd-radio.is-information:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-information.is-expanded,.fd-radio.is-information[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Information_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-radio.is-alert.is-focus,.fd-radio.is-alert:focus,.fd-radio.is-error.is-focus,.fd-radio.is-error:focus,.fd-radio.is-information.is-focus,.fd-radio.is-information:focus,.fd-radio.is-warning.is-focus,.fd-radio.is-warning:focus{outline-offset:var(--fdInput_Outline_Offset_States);z-index:5}.fd-radio.is-disabled,.fd-radio:disabled,.fd-radio[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-radio.is-readonly,.fd-radio.is-readonly.is-focus,.fd-radio.is-readonly.is-hover,.fd-radio.is-readonly:focus,.fd-radio.is-readonly:hover,.fd-radio[aria-readonly=true],.fd-radio[aria-readonly=true].is-focus,.fd-radio[aria-readonly=true].is-hover,.fd-radio[aria-readonly=true]:focus,.fd-radio[aria-readonly=true]:hover,.fd-radio[readonly],.fd-radio[readonly].is-focus,.fd-radio[readonly].is-hover,.fd-radio[readonly]:focus,.fd-radio[readonly]:hover{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-radio.is-readonly.is-focus,.fd-radio.is-readonly:focus,.fd-radio[aria-readonly=true].is-focus,.fd-radio[aria-readonly=true]:focus,.fd-radio[readonly].is-focus,.fd-radio[readonly]:focus{z-index:5}.fd-radio__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;padding-block:0;padding-inline:0;position:relative;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;-webkit-margin-end:.5rem;cursor:text;margin-inline-end:.5rem;-ms-flex-item-align:start;align-self:flex-start;cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;line-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapField_TextColor);padding-block:var(--fdRadio_Outer_Circle_Padding);padding-inline:var(--fdRadio_Outer_Circle_Padding)}.fd-radio__label:after,.fd-radio__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-radio__label:before{content:\"\";display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;height:var(--fdRadio_Inner_Circle_Diameter);min-width:var(--fdRadio_Inner_Circle_Diameter);width:var(--fdRadio_Inner_Circle_Diameter);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-radius:50%;-webkit-margin-end:var(--fdRadio_Outer_Circle_Padding);background-color:var(--fdRadio_Background_Color);border:var(--fdRadio_Inner_Border_Width) var(--fdRadio_Inner_Border_Style) var(--fdRadio_Inner_Border_Color);margin-inline-end:var(--fdRadio_Outer_Circle_Padding)}.fd-radio__label:after{height:var(--fdRadio_Inner_Content_Size);left:var(--fdRadio_Inner_Content_Padding);min-width:var(--fdRadio_Inner_Content_Size);width:var(--fdRadio_Inner_Content_Size)}.fd-radio__label.is-focus,.fd-radio__label:focus{outline:none;z-index:5}.fd-radio__label.is-hover:before,.fd-radio__label:hover:before{background-color:var(--fdRadio_Hover_Background_Color);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Default_Hover);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Default_Hover);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Default_Hover);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Default_Hover);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Default_Hover)}.fd-radio__label[dir=rtl]:after,[dir=rtl] .fd-radio__label:after{right:var(--fdRadio_Inner_Content_Padding)}.fd-radio__label.is-empty,.fd-radio__label:empty{margin-block:0;margin-inline:0;padding-block:var(--fdRadio_Outer_Circle_Padding);padding-inline:var(--fdRadio_Outer_Circle_Padding)}.fd-radio__label.is-empty:after,.fd-radio__label.is-empty:before,.fd-radio__label:empty:after,.fd-radio__label:empty:before{margin-inline:0}.fd-radio__label--wrap .fd-radio__text{white-space:normal}.fd-radio__label--wrap-top-aligned{-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-radio__label--wrap-top-aligned .fd-radio__text{white-space:normal}.fd-radio__label--wrap-top-aligned:after{top:var(--fdRadio_Inner_Content_Padding)}.fd-radio__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-radio__text:after,.fd-radio__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-radio:checked+.fd-radio__label:after{background:var(--fdRadio_Active_Dot_Color);border-radius:50%;content:\"\";position:absolute}.fd-radio.is-error+.fd-radio__label:before,.fd-radio.is-error:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Error);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Error);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Error);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Error);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Error);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Error_Hover)}.fd-radio.is-alert+.fd-radio__label:before,.fd-radio.is-alert:checked+.fd-radio__label:after,.fd-radio.is-warning+.fd-radio__label:before,.fd-radio.is-warning:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Warning);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Warning);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Warning);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Warning);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Warning);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Warning_Hover)}.fd-radio.is-success+.fd-radio__label:before,.fd-radio.is-success:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Success);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Success);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Success);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Success);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Success);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Success_Hover)}.fd-radio.is-information+.fd-radio__label:before,.fd-radio.is-information:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_Information);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_Information);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_Information);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_Information);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_Information);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_Information_Hover)}.fd-radio.is-readonly+.fd-radio__label:before,.fd-radio.is-readonly:checked+.fd-radio__label:after,.fd-radio[aria-readonly=true]+.fd-radio__label:before,.fd-radio[aria-readonly=true]:checked+.fd-radio__label:after,.fd-radio[readonly]+.fd-radio__label:before,.fd-radio[readonly]:checked+.fd-radio__label:after{--fdRadio_Background_Color:var(--fdRadio_Background_Color_ReadOnly);--fdRadio_Inner_Border_Width:var(--fdRadio_Inner_Border_Width_ReadOnly);--fdRadio_Inner_Border_Style:var(--fdRadio_Inner_Border_Style_ReadOnly);--fdRadio_Inner_Border_Color:var(--fdRadio_Inner_Border_Color_ReadOnly);--fdRadio_Active_Dot_Color:var(--fdRadio_Active_Dot_Color_ReadOnly);--fdRadio_Hover_Background_Color:var(--fdRadio_Background_Color_ReadOnly)}.fd-radio.is-focus,.fd-radio:focus{z-index:5}.fd-radio.is-focus+.fd-radio__label,.fd-radio:focus+.fd-radio__label{border-radius:var(--fdRadio_Outline_Border_Radius);outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:calc(var(--fdRadio_Focus_Outline_Offset) - var(--fdRadio_Outer_Circle_Padding))}.fd-radio.is-disabled,.fd-radio:disabled,.fd-radio[aria-disabled=true]{opacity:.0001}.fd-radio.is-disabled+.fd-radio__label,.fd-radio:disabled+.fd-radio__label,.fd-radio[aria-disabled=true]+.fd-radio__label{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-radio[class*=-compact]+.fd-radio__label,.fd-radio[class*=-condensed]+.fd-radio__label,[class*=-compact] .fd-radio:not([class*=-cozy])+.fd-radio__label,[class*=-condensed] .fd-radio:not([class*=-cozy])+.fd-radio__label{--fdRadio_Outer_Circle_Padding:var(--fdRadio_Compact_Outer_Circle_Padding);--fdRadio_Inner_Circle_Diameter:var(--fdRadio_Compact_Inner_Circle_Diameter);--fdRadio_Inner_Content_Size:var(--fdRadio_Inner_Content_Size_Compact);--fdRadio_Inner_Content_Padding:var(--fdRadio_Inner_Content_Padding_Compact)}.fd-radio[class*=-compact].is-focus,.fd-radio[class*=-compact]:focus,.fd-radio[class*=-condensed].is-focus,.fd-radio[class*=-condensed]:focus,[class*=-compact] .fd-radio:not([class*=-cozy]).is-focus,[class*=-compact] .fd-radio:not([class*=-cozy]):focus,[class*=-condensed] .fd-radio:not([class*=-cozy]).is-focus,[class*=-condensed] .fd-radio:not([class*=-cozy]):focus{z-index:5}.fd-radio[class*=-compact].is-focus+.fd-radio__label,.fd-radio[class*=-compact]:focus+.fd-radio__label,.fd-radio[class*=-condensed].is-focus+.fd-radio__label,.fd-radio[class*=-condensed]:focus+.fd-radio__label,[class*=-compact] .fd-radio:not([class*=-cozy]).is-focus+.fd-radio__label,[class*=-compact] .fd-radio:not([class*=-cozy]):focus+.fd-radio__label,[class*=-condensed] .fd-radio:not([class*=-cozy]).is-focus+.fd-radio__label,[class*=-condensed] .fd-radio:not([class*=-cozy]):focus+.fd-radio__label{--fdRadio_Outer_Circle_Padding:var(--fdRadio_Compact_Outer_Circle_Padding);--fdRadio_Outline_Border_Radius:var(--fdRadio_Compact_Outline_Border_radius)}\n/*! Bundled license information:\n\nfundamental-styles/dist/radio.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i1.ContentDensityObserver }], propDecorators: { inputElement: [{
                type: ViewChild,
                args: ['inputElement']
            }], ariaLabel: [{
                type: Input
            }], ariaLabelledBy: [{
                type: Input
            }], ariaDescribedBy: [{
                type: Input
            }], title: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }], state: [{
                type: Input
            }], disabled: [{
                type: Input
            }], readOnly: [{
                type: Input
            }], selectedValue: [{
                type: Input
            }], name: [{
                type: Input
            }], id: [{
                type: Input
            }], value: [{
                type: Input
            }], required: [{
                type: Input
            }], standalone: [{
                type: Input
            }], wrapLabel: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], valignLabel: [{
                type: Input
            }], buildComponentCssClass: [] } });

/**
 * @deprecated
 * Use direct import of `RadioButtonComponent`.
 */
class RadioModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: RadioModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: RadioModule, imports: [RadioButtonComponent, ContentDensityModule], exports: [RadioButtonComponent, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: RadioModule, imports: [RadioButtonComponent, ContentDensityModule, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: RadioModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [RadioButtonComponent, ContentDensityModule],
                    imports: [RadioButtonComponent, ContentDensityModule]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FD_RADIO_BUTTON_COMPONENT, RadioButtonComponent, RadioModule };
//# sourceMappingURL=fundamental-ngx-core-radio.mjs.map
