import { __decorate, __metadata } from 'tslib';
import * as i0 from '@angular/core';
import { InjectionToken, signal, computed, effect, HostBinding, Input, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { applyCssClass } from '@fundamental-ngx/cdk/utils';

const FD_ICON_COMPONENT = new InjectionToken('FdIconComponent');

const FD_DEFAULT_ICON_FONT_FAMILY = 'SAP-icons';
const SAP_ICONS_PREFIX = 'sap-icon';
const FD_ICON_FONT_FAMILY = {
    'SAP-icons': SAP_ICONS_PREFIX,
    BusinessSuiteInAppSymbols: `${SAP_ICONS_PREFIX}-businessSuiteInAppSymbols`,
    'SAP-icons-TNT': `${SAP_ICONS_PREFIX}-TNT`
};
/**
 * Helper function to build icon css class.
 * @param font Font family
 * @param glyph Icon
 * @param color Icon color
 * @param background Icon background color
 * @returns Computed css class string.
 */
function fdBuildIconClass(font, glyph, color, background) {
    const fontFamily = FD_ICON_FONT_FAMILY[font];
    const returnIconClass = [`${fontFamily}--${glyph}`];
    if (color) {
        returnIconClass.push(`${fontFamily}--color-${color}`);
    }
    if (background) {
        returnIconClass.push(`${fontFamily}--background-${background}`);
    }
    return returnIconClass.join(' ');
}
/**
 * The component that represents an icon.
 *
 * ```html
 * <fd-icon font="SAP-icons-TNT" glyph="exceptions"></fd-icon>
 * ```
 */
class IconComponent {
    /** The icon name to display. See the icon page for the list of icons
     * here: https://sap.github.io/fundamental-ngx/icon
     * */
    set glyph(value) {
        this._glyph.set(value);
    }
    get glyph() {
        return this._glyph();
    }
    /**
     * The icon font
     * Options include: 'SAP-icons', 'BusinessSuiteInAppSymbols' and 'SAP-icons-TNT'
     */
    set font(value) {
        this._font.set(value);
    }
    get font() {
        return this._font();
    }
    /** Icon color */
    set color(value) {
        this._color.set(value);
    }
    get color() {
        return this._color();
    }
    /** Icon color */
    set background(value) {
        this._background.set(value);
    }
    get background() {
        return this._background();
    }
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** Whether or not this icon is for a list navigation item. */
        this._navigationItemIcon = false;
        /** @hidden */
        this._glyph = signal('');
        /** @hidden */
        this._font = signal(FD_DEFAULT_ICON_FONT_FAMILY);
        /** @hidden */
        this._color = signal(null);
        /** @hidden */
        this._background = signal(null);
        /** @hidden */
        this._fontIconClass = computed(() => fdBuildIconClass(this._font(), this._glyph(), this._color(), this._background()));
        effect(() => {
            this.buildComponentCssClass();
        });
    }
    /**
     * @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        const returnClass = [this.class];
        if (!this._glyph()) {
            return returnClass;
        }
        returnClass.push(this._fontIconClass());
        return returnClass;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: IconComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: IconComponent, isStandalone: true, selector: "fd-icon", inputs: { glyph: "glyph", font: "font", color: "color", background: "background", class: "class", ariaLabel: "ariaLabel", ariaHidden: "ariaHidden" }, host: { properties: { "attr.aria-label": "this.ariaLabel", "attr.aria-hidden": "this.ariaHidden", "class.fd-list__navigation-item-icon": "this._navigationItemIcon" } }, providers: [
            {
                provide: FD_ICON_COMPONENT,
                useExisting: IconComponent
            }
        ], ngImport: i0, template: ``, isInline: true, styles: ["[class*=sap-icon]{background-color:var(--fdIcon_Background_Color,transparent);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdIcon_Color,inherit);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdIcon_Font_Size,1rem);font-style:normal;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}[class*=sap-icon]:after,[class*=sap-icon]:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}[class*=sap-icon]:before{font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}[class*=sap-icon].sap-icon--color-default{--fdIcon_Color:var(--sapContent_IconColor)}[class*=sap-icon].sap-icon--background-default{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-contrast{--fdIcon_Color:var(--sapContent_ContrastIconColor)}[class*=sap-icon].sap-icon--background-contrast{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-non-interactive{--fdIcon_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon].sap-icon--background-non-interactive{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-tile{--fdIcon_Color:var(--sapTile_IconColor)}[class*=sap-icon].sap-icon--background-tile{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-marker{--fdIcon_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon].sap-icon--background-marker{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-critical{--fdIcon_Color:var(--sapCriticalElementColor)}[class*=sap-icon].sap-icon--background-critical{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-negative{--fdIcon_Color:var(--sapNegativeElementColor)}[class*=sap-icon].sap-icon--background-negative{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-neutral{--fdIcon_Color:var(--sapNeutralElementColor)}[class*=sap-icon].sap-icon--background-neutral{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-positive{--fdIcon_Color:var(--sapPositiveElementColor)}[class*=sap-icon].sap-icon--background-positive{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-information{--fdIcon_Color:var(--sapInformativeElementColor)}[class*=sap-icon].sap-icon--background-information{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--background-default{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapContent_IconColor)}[class*=sap-icon].sap-icon--background-contrast{--fdIcon_Color:var(--sapContent_IconColor);--fdIcon_Background_Color:var(--sapGroup_ContentBackground)}[class*=sap-icon].sap-icon--background-non-interactive{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon].sap-icon--background-tile{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapTile_IconColor)}[class*=sap-icon].sap-icon--background-marker{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon].sap-icon--background-critical{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapCriticalElementColor)}[class*=sap-icon].sap-icon--background-negative{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapNegativeElementColor)}[class*=sap-icon].sap-icon--background-neutral{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapNeutralElementColor)}[class*=sap-icon].sap-icon--background-positive{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapPositiveElementColor)}[class*=sap-icon].sap-icon--background-information{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapInformativeElementColor)}[class*=sap-icon][tabindex=\"0\"]{cursor:pointer}[class*=sap-icon][tabindex=\"0\"].is-focus,[class*=sap-icon][tabindex=\"0\"]:focus{border-radius:.25rem;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);z-index:5}[class*=sap-icon-businessSuiteInAppSymbols]:before{font-family:SAP-icons-Business-Suite}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-default{--fdIcon_Color:var(--sapContent_IconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-default{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-contrast{--fdIcon_Color:var(--sapContent_ContrastIconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-contrast{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-non-interactive{--fdIcon_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-non-interactive{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-tile{--fdIcon_Color:var(--sapTile_IconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-tile{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-marker{--fdIcon_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-marker{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-critical{--fdIcon_Color:var(--sapCriticalElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-critical{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-negative{--fdIcon_Color:var(--sapNegativeElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-negative{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-neutral{--fdIcon_Color:var(--sapNeutralElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-neutral{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-positive{--fdIcon_Color:var(--sapPositiveElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-positive{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-information{--fdIcon_Color:var(--sapInformativeElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-information{--fdIcon_Background_Color: }[class*=sap-icon-TNT]:before{font-family:SAP-icons-TNT}[class*=sap-icon-TNT].sap-icon-TNT--color-default{--fdIcon_Color:var(--sapContent_IconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-default{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-contrast{--fdIcon_Color:var(--sapContent_ContrastIconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-contrast{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-non-interactive{--fdIcon_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-non-interactive{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-tile{--fdIcon_Color:var(--sapTile_IconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-tile{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-marker{--fdIcon_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-marker{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-critical{--fdIcon_Color:var(--sapCriticalElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-critical{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-negative{--fdIcon_Color:var(--sapNegativeElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-negative{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-neutral{--fdIcon_Color:var(--sapNeutralElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-neutral{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-positive{--fdIcon_Color:var(--sapPositiveElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-positive{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-information{--fdIcon_Color:var(--sapInformativeElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-information{--fdIcon_Background_Color: }.sap-icon--accidental-leave:before{content:\"\\e000\"}.sap-icon--account:before{content:\"\\e001\"}.sap-icon--wrench:before{content:\"\\e002\"}.sap-icon--windows-doors:before{content:\"\\e003\"}.sap-icon--washing-machine:before{content:\"\\e004\"}.sap-icon--visits:before{content:\"\\e005\"}.sap-icon--video:before{content:\"\\e006\"}.sap-icon--travel-expense:before{content:\"\\e007\"}.sap-icon--temperature:before{content:\"\\e008\"}.sap-icon--task:before{content:\"\\e009\"}.sap-icon--synchronize:before{content:\"\\e00a\"}.sap-icon--survey:before{content:\"\\e00b\"}.sap-icon--settings:before{content:\"\\e00c\"}.sap-icon--search:before{content:\"\\e00d\"}.sap-icon--sales-document:before{content:\"\\e00e\"}.sap-icon--retail-store:before{content:\"\\e00f\"}.sap-icon--refresh:before{content:\"\\e010\"}.sap-icon--product:before{content:\"\\e011\"}.sap-icon--present:before{content:\"\\e012\"}.sap-icon--ppt-attachment:before{content:\"\\e013\"}.sap-icon--pool:before{content:\"\\e014\"}.sap-icon--pie-chart:before{content:\"\\e015\"}.sap-icon--picture:before{content:\"\\e016\"}.sap-icon--photo-voltaic:before{content:\"\\e017\"}.sap-icon--phone:before{content:\"\\e018\"}.sap-icon--pending:before{content:\"\\e019\"}.sap-icon--pdf-attachment:before{content:\"\\e01a\"}.sap-icon--past:before{content:\"\\e01b\"}.sap-icon--outgoing-call:before{content:\"\\e01c\"}.sap-icon--opportunity:before{content:\"\\e01d\"}.sap-icon--opportunities:before{content:\"\\e01e\"}.sap-icon--notes:before{content:\"\\e01f\"}.sap-icon--money-bills:before{content:\"\\e020\"}.sap-icon--map:before{content:\"\\e021\"}.sap-icon--log:before{content:\"\\e022\"}.sap-icon--line-charts:before{content:\"\\e023\"}.sap-icon--lightbulb:before{content:\"\\e024\"}.sap-icon--leads:before{content:\"\\e025\"}.sap-icon--lead:before{content:\"\\e026\"}.sap-icon--laptop:before{content:\"\\e027\"}.sap-icon--kpi-managing-my-area:before{content:\"\\e028\"}.sap-icon--kpi-corporate-performance:before{content:\"\\e029\"}.sap-icon--incoming-call:before{content:\"\\e02a\"}.sap-icon--inbox:before{content:\"\\e02b\"}.sap-icon--horizontal-bar-chart:before{content:\"\\e02c\"}.sap-icon--history:before{content:\"\\e02d\"}.sap-icon--heating-cooling:before{content:\"\\e02e\"}.sap-icon--gantt-bars:before{content:\"\\e02f\"}.sap-icon--future:before{content:\"\\e030\"}.sap-icon--fridge:before{content:\"\\e031\"}.sap-icon--fallback:before{content:\"\\e032\"}.sap-icon--expense-report:before{content:\"\\e033\"}.sap-icon--excel-attachment:before{content:\"\\e034\"}.sap-icon--energy-saving-lightbulb:before{content:\"\\e035\"}.sap-icon--employee:before{content:\"\\e036\"}.sap-icon--email:before{content:\"\\e037\"}.sap-icon--edit:before{content:\"\\e038\"}.sap-icon--duplicate:before{content:\"\\e039\"}.sap-icon--download:before{content:\"\\e03a\"}.sap-icon--doc-attachment:before{content:\"\\e03b\"}.sap-icon--dishwasher:before{content:\"\\e03c\"}.sap-icon--delete:before{content:\"\\e03d\"}.sap-icon--decline:before{content:\"\\e03e\"}.sap-icon--complete:before{content:\"\\e03f\"}.sap-icon--competitor:before{content:\"\\e040\"}.sap-icon--collections-management:before{content:\"\\e041\"}.sap-icon--chalkboard:before{content:\"\\e042\"}.sap-icon--cart:before{content:\"\\e043\"}.sap-icon--card:before{content:\"\\e044\"}.sap-icon--camera:before{content:\"\\e045\"}.sap-icon--calendar:before{content:\"\\e046\"}.sap-icon--begin:before{content:\"\\e047\"}.sap-icon--basket:before{content:\"\\e048\"}.sap-icon--bar-chart:before{content:\"\\e049\"}.sap-icon--attachment:before{content:\"\\e04a\"}.sap-icon--arrow-top:before{content:\"\\e04b\"}.sap-icon--arrow-right:before{content:\"\\e04c\"}.sap-icon--arrow-left:before{content:\"\\e04d\"}.sap-icon--arrow-bottom:before{content:\"\\e04e\"}.sap-icon--approvals:before{content:\"\\e04f\"}.sap-icon--appointment:before{content:\"\\e050\"}.sap-icon--alphabetical-order:before{content:\"\\e051\"}.sap-icon--along-stacked-chart:before{content:\"\\e052\"}.sap-icon--alert:before{content:\"\\e053\"}.sap-icon--addresses:before{content:\"\\e054\"}.sap-icon--address-book:before{content:\"\\e055\"}.sap-icon--add-filter:before{content:\"\\e056\"}.sap-icon--add-favorite:before{content:\"\\e057\"}.sap-icon--add:before{content:\"\\e058\"}.sap-icon--activities:before{content:\"\\e059\"}.sap-icon--action:before{content:\"\\e05a\"}.sap-icon--accept:before{content:\"\\e05b\"}.sap-icon--hint:before{content:\"\\e05c\"}.sap-icon--group:before{content:\"\\e05d\"}.sap-icon--check-availability:before{content:\"\\e05e\"}.sap-icon--weather-proofing:before{content:\"\\e05f\"}.sap-icon--payment-approval:before{content:\"\\e060\"}.sap-icon--batch-payments:before{content:\"\\e061\"}.sap-icon--bed:before{content:\"\\e062\"}.sap-icon--arobase:before{content:\"\\e063\"}.sap-icon--family-care:before{content:\"\\e064\"}.sap-icon--favorite:before{content:\"\\e065\"}.sap-icon--navigation-right-arrow:before{content:\"\\e066\"}.sap-icon--navigation-left-arrow:before{content:\"\\e067\"}.sap-icon--e-care:before{content:\"\\e068\"}.sap-icon--less:before{content:\"\\e069\"}.sap-icon--lateness:before{content:\"\\e06a\"}.sap-icon--lab:before{content:\"\\e06b\"}.sap-icon--internet-browser:before{content:\"\\e06c\"}.sap-icon--instance:before{content:\"\\e06d\"}.sap-icon--inspection:before{content:\"\\e06e\"}.sap-icon--image-viewer:before{content:\"\\e06f\"}.sap-icon--home:before{content:\"\\e070\"}.sap-icon--grid:before{content:\"\\e071\"}.sap-icon--goalseek:before{content:\"\\e072\"}.sap-icon--general-leave-request:before{content:\"\\e073\"}.sap-icon--create-leave-request:before{content:\"\\e074\"}.sap-icon--flight:before{content:\"\\e075\"}.sap-icon--filter:before{content:\"\\e076\"}.sap-icon--favorite-list:before{content:\"\\e077\"}.sap-icon--factory:before{content:\"\\e078\"}.sap-icon--endoscopy:before{content:\"\\e079\"}.sap-icon--employee-pane:before{content:\"\\e07a\"}.sap-icon--employee-approvals:before{content:\"\\e07b\"}.sap-icon--email-read:before{content:\"\\e07c\"}.sap-icon--electrocardiogram:before{content:\"\\e07d\"}.sap-icon--documents:before{content:\"\\e07e\"}.sap-icon--decision:before{content:\"\\e07f\"}.sap-icon--database:before{content:\"\\e080\"}.sap-icon--customer-history:before{content:\"\\e081\"}.sap-icon--customer:before{content:\"\\e082\"}.sap-icon--credit-card:before{content:\"\\e083\"}.sap-icon--create-entry-time:before{content:\"\\e084\"}.sap-icon--contacts:before{content:\"\\e085\"}.sap-icon--compare:before{content:\"\\e086\"}.sap-icon--clinical-order:before{content:\"\\e087\"}.sap-icon--chain-link:before{content:\"\\e088\"}.sap-icon--pull-down:before{content:\"\\e089\"}.sap-icon--cargo-train:before{content:\"\\e08a\"}.sap-icon--car-rental:before{content:\"\\e08b\"}.sap-icon--business-card:before{content:\"\\e08c\"}.sap-icon--bar-code:before{content:\"\\e08d\"}.sap-icon--folder-blank:before{content:\"\\e08e\"}.sap-icon--passenger-train:before{content:\"\\e08f\"}.sap-icon--question-mark:before{content:\"\\e090\"}.sap-icon--world:before{content:\"\\e091\"}.sap-icon--iphone:before{content:\"\\e092\"}.sap-icon--ipad:before{content:\"\\e093\"}.sap-icon--warning:before{content:\"\\e094\"}.sap-icon--sort:before{content:\"\\e095\"}.sap-icon--course-book:before{content:\"\\e096\"}.sap-icon--course-program:before{content:\"\\e097\"}.sap-icon--add-coursebook:before{content:\"\\e098\"}.sap-icon--print:before{content:\"\\e099\"}.sap-icon--save:before{content:\"\\e09a\"}.sap-icon--play:before{content:\"\\e09b\"}.sap-icon--pause:before{content:\"\\e09c\"}.sap-icon--record:before{content:\"\\e09d\"}.sap-icon--response:before{content:\"\\e09e\"}.sap-icon--pushpin-on:before{content:\"\\e09f\"}.sap-icon--pushpin-off:before{content:\"\\e0a0\"}.sap-icon--unfavorite:before{content:\"\\e0a1\"}.sap-icon--learning-assistant:before{content:\"\\e0a2\"}.sap-icon--timesheet:before{content:\"\\e0a3\"}.sap-icon--time-entry-request:before{content:\"\\e0a4\"}.sap-icon--list:before{content:\"\\e0a5\"}.sap-icon--action-settings:before{content:\"\\e0a6\"}.sap-icon--share:before{content:\"\\e0a7\"}.sap-icon--feed:before{content:\"\\e0a8\"}.sap-icon--role:before{content:\"\\e0a9\"}.sap-icon--flag:before{content:\"\\e0aa\"}.sap-icon--post:before{content:\"\\e0ab\"}.sap-icon--inspect:before{content:\"\\e0ac\"}.sap-icon--inspect-down:before{content:\"\\e0ad\"}.sap-icon--appointment-2:before{content:\"\\e0ae\"}.sap-icon--target-group:before{content:\"\\e0af\"}.sap-icon--marketing-campaign:before{content:\"\\e0b0\"}.sap-icon--message-error:before,.sap-icon--notification:before{content:\"\\e0b1\"}.sap-icon--comment:before{content:\"\\e0b2\"}.sap-icon--shipping-status:before{content:\"\\e0b3\"}.sap-icon--collaborate:before{content:\"\\e0b4\"}.sap-icon--shortcut:before{content:\"\\e0b5\"}.sap-icon--lead-outdated:before{content:\"\\e0b6\"}.sap-icon--tools-opportunity:before{content:\"\\e0b7\"}.sap-icon--permission:before{content:\"\\e0b8\"}.sap-icon--supplier:before{content:\"\\e0b9\"}.sap-icon--table-view:before{content:\"\\e0ba\"}.sap-icon--table-chart:before{content:\"\\e0bb\"}.sap-icon--switch-views:before{content:\"\\e0bc\"}.sap-icon--e-learning:before{content:\"\\e0bd\"}.sap-icon--manager:before{content:\"\\e0be\"}.sap-icon--switch-classes:before{content:\"\\e0bf\"}.sap-icon--simple-payment:before{content:\"\\e0c0\"}.sap-icon--signature:before{content:\"\\e0c1\"}.sap-icon--sales-order-item:before{content:\"\\e0c2\"}.sap-icon--sales-order:before{content:\"\\e0c3\"}.sap-icon--request:before{content:\"\\e0c4\"}.sap-icon--receipt:before{content:\"\\e0c5\"}.sap-icon--puzzle:before{content:\"\\e0c6\"}.sap-icon--process:before{content:\"\\e0c7\"}.sap-icon--private:before{content:\"\\e0c8\"}.sap-icon--popup-window:before{content:\"\\e0c9\"}.sap-icon--person-placeholder:before{content:\"\\e0ca\"}.sap-icon--per-diem:before{content:\"\\e0cb\"}.sap-icon--paper-plane:before{content:\"\\e0cc\"}.sap-icon--paid-leave:before{content:\"\\e0cd\"}.sap-icon--pdf-reader:before{content:\"\\e0ce\"}.sap-icon--overview-chart:before{content:\"\\e0cf\"}.sap-icon--overlay:before{content:\"\\e0d0\"}.sap-icon--org-chart:before{content:\"\\e0d1\"}.sap-icon--number-sign:before{content:\"\\e0d2\"}.sap-icon--notification-2:before{content:\"\\e0d3\"}.sap-icon--my-sales-order:before{content:\"\\e0d4\"}.sap-icon--meal:before{content:\"\\e0d5\"}.sap-icon--loan:before{content:\"\\e0d6\"}.sap-icon--order-status:before{content:\"\\e0d7\"}.sap-icon--customer-order-entry:before{content:\"\\e0d8\"}.sap-icon--performance:before{content:\"\\e0d9\"}.sap-icon--menu:before{content:\"\\e0da\"}.sap-icon--employee-lookup:before{content:\"\\e0db\"}.sap-icon--education:before{content:\"\\e0dc\"}.sap-icon--customer-briefing:before{content:\"\\e0dd\"}.sap-icon--customer-and-contacts:before{content:\"\\e0de\"}.sap-icon--my-view:before{content:\"\\e0df\"}.sap-icon--accelerated:before{content:\"\\e0e0\"}.sap-icon--to-be-reviewed:before{content:\"\\e0e1\"}.sap-icon--warning2:before{content:\"\\e0e2\"}.sap-icon--feeder-arrow:before{content:\"\\e0e3\"}.sap-icon--quality-issue:before{content:\"\\e0e4\"}.sap-icon--workflow-tasks:before{content:\"\\e0e5\"}.sap-icon--create:before{content:\"\\e0e6\"}.sap-icon--home-share:before{content:\"\\e0e7\"}.sap-icon--globe:before{content:\"\\e0e8\"}.sap-icon--tags:before{content:\"\\e0e9\"}.sap-icon--work-history:before{content:\"\\e0ea\"}.sap-icon--x-ray:before{content:\"\\e0eb\"}.sap-icon--wounds-doc:before{content:\"\\e0ec\"}.sap-icon--web-cam:before{content:\"\\e0ed\"}.sap-icon--waiver:before{content:\"\\e0ee\"}.sap-icon--vertical-bar-chart:before{content:\"\\e0ef\"}.sap-icon--upstacked-chart:before{content:\"\\e0f0\"}.sap-icon--trip-report:before{content:\"\\e0f1\"}.sap-icon--microphone:before{content:\"\\e0f2\"}.sap-icon--unpaid-leave:before{content:\"\\e0f3\"}.sap-icon--tree:before{content:\"\\e0f4\"}.sap-icon--toaster-up:before{content:\"\\e0f5\"}.sap-icon--toaster-top:before{content:\"\\e0f6\"}.sap-icon--toaster-down:before{content:\"\\e0f7\"}.sap-icon--time-account:before{content:\"\\e0f8\"}.sap-icon--theater:before{content:\"\\e0f9\"}.sap-icon--taxi:before{content:\"\\e0fa\"}.sap-icon--subway-train:before{content:\"\\e0fb\"}.sap-icon--study-leave:before{content:\"\\e0fc\"}.sap-icon--stethoscope:before{content:\"\\e0fd\"}.sap-icon--step:before{content:\"\\e0fe\"}.sap-icon--sonography:before{content:\"\\e0ff\"}.sap-icon--soccor:before{content:\"\\e100\"}.sap-icon--physical-activity:before{content:\"\\e101\"}.sap-icon--pharmacy:before{content:\"\\e102\"}.sap-icon--official-service:before{content:\"\\e103\"}.sap-icon--offsite-work:before{content:\"\\e104\"}.sap-icon--nutrition-activity:before{content:\"\\e105\"}.sap-icon--newspaper:before{content:\"\\e106\"}.sap-icon--monitor-payments:before{content:\"\\e107\"}.sap-icon--map-2:before{content:\"\\e108\"}.sap-icon--machine:before{content:\"\\e109\"}.sap-icon--mri-scan:before{content:\"\\e10a\"}.sap-icon--end-user-experience-monitoring:before{content:\"\\e10b\"}.sap-icon--unwired:before{content:\"\\e10c\"}.sap-icon--customer-financial-fact-sheet:before{content:\"\\e10d\"}.sap-icon--retail-store-manager:before{content:\"\\e10e\"}.sap-icon--Netweaver-business-client:before{content:\"\\e10f\"}.sap-icon--electronic-medical-record:before{content:\"\\e110\"}.sap-icon--eam-work-order:before{content:\"\\e111\"}.sap-icon--customer-view:before{content:\"\\e112\"}.sap-icon--crm-service-manager:before{content:\"\\e113\"}.sap-icon--crm-sales:before{content:\"\\e114\"}.sap-icon--widgets:before{content:\"\\e115\"}.sap-icon--commission-check:before{content:\"\\e116\"}.sap-icon--collections-insight:before{content:\"\\e117\"}.sap-icon--clinical-task-tracker:before{content:\"\\e118\"}.sap-icon--citizen-connect:before{content:\"\\e119\"}.sap-icon--cart-approval:before{content:\"\\e11a\"}.sap-icon--capital-projects:before{content:\"\\e11b\"}.sap-icon--bo-strategy-management:before{content:\"\\e11c\"}.sap-icon--business-objects-mobile:before{content:\"\\e11d\"}.sap-icon--business-objects-explorer:before{content:\"\\e11e\"}.sap-icon--business-objects-experience:before{content:\"\\e11f\"}.sap-icon--bbyd-dashboard:before{content:\"\\e120\"}.sap-icon--bbyd-active-sales:before{content:\"\\e121\"}.sap-icon--business-by-design:before{content:\"\\e122\"}.sap-icon--business-one:before{content:\"\\e123\"}.sap-icon--sap-box:before{content:\"\\e124\"}.sap-icon--manager-insight:before{content:\"\\e125\"}.sap-icon--accounting-document-verification:before{content:\"\\e126\"}.sap-icon--hr-approval:before{content:\"\\e127\"}.sap-icon--idea-wall:before{content:\"\\e128\"}.sap-icon--Chart-Tree-Map:before{content:\"\\e129\"}.sap-icon--cart-5:before{content:\"\\e12a\"}.sap-icon--cart-4:before{content:\"\\e12b\"}.sap-icon--wallet:before{content:\"\\e12c\"}.sap-icon--vehicle-repair:before{content:\"\\e12d\"}.sap-icon--upload:before{content:\"\\e12e\"}.sap-icon--unlocked:before{content:\"\\e12f\"}.sap-icon--umbrella:before{content:\"\\e130\"}.sap-icon--travel-request:before{content:\"\\e131\"}.sap-icon--travel-expense-report:before{content:\"\\e132\"}.sap-icon--travel-itinerary:before{content:\"\\e133\"}.sap-icon--time-overtime:before{content:\"\\e134\"}.sap-icon--thing-type:before{content:\"\\e135\"}.sap-icon--technical-object:before{content:\"\\e136\"}.sap-icon--tag:before{content:\"\\e137\"}.sap-icon--syringe:before{content:\"\\e138\"}.sap-icon--syntax:before{content:\"\\e139\"}.sap-icon--suitcase:before{content:\"\\e13a\"}.sap-icon--simulate:before{content:\"\\e13b\"}.sap-icon--shield:before{content:\"\\e13c\"}.sap-icon--share-2:before{content:\"\\e13d\"}.sap-icon--sales-quote:before{content:\"\\e13e\"}.sap-icon--repost:before{content:\"\\e13f\"}.sap-icon--provision:before{content:\"\\e140\"}.sap-icon--projector:before{content:\"\\e141\"}.sap-icon--add-product:before{content:\"\\e142\"}.sap-icon--pipeline-analysis:before{content:\"\\e143\"}.sap-icon--add-photo:before{content:\"\\e144\"}.sap-icon--palette:before{content:\"\\e145\"}.sap-icon--nurse:before{content:\"\\e146\"}.sap-icon--sales-notification:before{content:\"\\e147\"}.sap-icon--mileage:before{content:\"\\e148\"}.sap-icon--meeting-room:before{content:\"\\e149\"}.sap-icon--media-forward:before{content:\"\\e14a\"}.sap-icon--media-play:before{content:\"\\e14b\"}.sap-icon--media-pause:before{content:\"\\e14c\"}.sap-icon--media-reverse:before{content:\"\\e14d\"}.sap-icon--media-rewind:before{content:\"\\e14e\"}.sap-icon--measurement-document:before{content:\"\\e14f\"}.sap-icon--measuring-point:before{content:\"\\e150\"}.sap-icon--measure:before{content:\"\\e151\"}.sap-icon--map-3:before{content:\"\\e152\"}.sap-icon--locked:before{content:\"\\e153\"}.sap-icon--letter:before{content:\"\\e154\"}.sap-icon--journey-arrive:before{content:\"\\e155\"}.sap-icon--journey-change:before{content:\"\\e156\"}.sap-icon--journey-depart:before{content:\"\\e157\"}.sap-icon--it-system:before{content:\"\\e158\"}.sap-icon--it-instance:before{content:\"\\e159\"}.sap-icon--it-host:before{content:\"\\e15a\"}.sap-icon--iphone-2:before{content:\"\\e15b\"}.sap-icon--ipad-2:before{content:\"\\e15c\"}.sap-icon--inventory:before{content:\"\\e15d\"}.sap-icon--insurance-house:before{content:\"\\e15e\"}.sap-icon--insurance-life:before{content:\"\\e15f\"}.sap-icon--insurance-car:before{content:\"\\e160\"}.sap-icon--initiative:before{content:\"\\e161\"}.sap-icon--incident:before{content:\"\\e162\"}.sap-icon--group-2:before{content:\"\\e163\"}.sap-icon--goal:before{content:\"\\e164\"}.sap-icon--functional-location:before{content:\"\\e165\"}.sap-icon--full-screen:before{content:\"\\e166\"}.sap-icon--form:before{content:\"\\e167\"}.sap-icon--fob-watch:before{content:\"\\e168\"}.sap-icon--blank-tag:before{content:\"\\e169\"}.sap-icon--family-protection:before{content:\"\\e16a\"}.sap-icon--folder:before{content:\"\\e16b\"}.sap-icon--fax-machine:before{content:\"\\e16c\"}.sap-icon--example:before{content:\"\\e16d\"}.sap-icon--eraser:before{content:\"\\e16e\"}.sap-icon--employee-rejections:before{content:\"\\e16f\"}.sap-icon--drop-down-list:before{content:\"\\e170\"}.sap-icon--draw-rectangle:before{content:\"\\e171\"}.sap-icon--document:before{content:\"\\e172\"}.sap-icon--doctor:before{content:\"\\e173\"}.sap-icon--discussion-2:before{content:\"\\e174\"}.sap-icon--discussion:before{content:\"\\e175\"}.sap-icon--dimension:before{content:\"\\e176\"}.sap-icon--customer-and-supplier:before{content:\"\\e177\"}.sap-icon--crop:before{content:\"\\e178\"}.sap-icon--add-contact:before{content:\"\\e179\"}.sap-icon--compare-2:before{content:\"\\e17a\"}.sap-icon--color-fill:before{content:\"\\e17b\"}.sap-icon--collision:before{content:\"\\e17c\"}.sap-icon--curriculum:before{content:\"\\e17d\"}.sap-icon--chart-axis:before{content:\"\\e17e\"}.sap-icon--full-stacked-chart:before{content:\"\\e17f\"}.sap-icon--full-stacked-column-chart:before{content:\"\\e180\"}.sap-icon--vertical-bar-chart-2:before{content:\"\\e181\"}.sap-icon--horizontal-bar-chart-2:before{content:\"\\e182\"}.sap-icon--horizontal-stacked-chart:before{content:\"\\e183\"}.sap-icon--vertical-stacked-chart:before{content:\"\\e184\"}.sap-icon--choropleth-chart:before{content:\"\\e185\"}.sap-icon--geographic-bubble-chart:before{content:\"\\e186\"}.sap-icon--multiple-radar-chart:before{content:\"\\e187\"}.sap-icon--radar-chart:before{content:\"\\e188\"}.sap-icon--crossed-line-chart:before{content:\"\\e189\"}.sap-icon--multiple-line-chart:before{content:\"\\e18a\"}.sap-icon--multiple-bar-chart:before{content:\"\\e18b\"}.sap-icon--line-chart:before{content:\"\\e18c\"}.sap-icon--line-chart-dual-axis:before{content:\"\\e18d\"}.sap-icon--bubble-chart:before{content:\"\\e18e\"}.sap-icon--scatter-chart:before{content:\"\\e18f\"}.sap-icon--multiple-pie-chart:before{content:\"\\e190\"}.sap-icon--column-chart-dual-axis:before{content:\"\\e191\"}.sap-icon--tag-cloud-chart:before{content:\"\\e192\"}.sap-icon--area-chart:before{content:\"\\e193\"}.sap-icon--cause:before{content:\"\\e194\"}.sap-icon--cart-3:before{content:\"\\e195\"}.sap-icon--cart-2:before{content:\"\\e196\"}.sap-icon--bus-public-transport:before{content:\"\\e197\"}.sap-icon--burglary:before{content:\"\\e198\"}.sap-icon--building:before{content:\"\\e199\"}.sap-icon--border:before{content:\"\\e19a\"}.sap-icon--bookmark:before{content:\"\\e19b\"}.sap-icon--badge:before{content:\"\\e19c\"}.sap-icon--attachment-audio:before{content:\"\\e19d\"}.sap-icon--attachment-video:before{content:\"\\e19e\"}.sap-icon--attachment-html:before{content:\"\\e19f\"}.sap-icon--attachment-photo:before{content:\"\\e1a0\"}.sap-icon--attachment-e-pub:before{content:\"\\e1a1\"}.sap-icon--attachment-zip-file:before{content:\"\\e1a2\"}.sap-icon--attachment-text-file:before{content:\"\\e1a3\"}.sap-icon--add-equipment:before{content:\"\\e1a4\"}.sap-icon--add-activity:before{content:\"\\e1a5\"}.sap-icon--activity-individual:before{content:\"\\e1a6\"}.sap-icon--activity-2:before{content:\"\\e1a7\"}.sap-icon--add-activity-2:before{content:\"\\e1a8\"}.sap-icon--activity-items:before{content:\"\\e1a9\"}.sap-icon--activity-assigned-to-goal:before{content:\"\\e1aa\"}.sap-icon--status-completed:before,.sap-icon--status-positive:before{content:\"\\e1ab\"}.sap-icon--status-error:before,.sap-icon--status-negative:before{content:\"\\e1ac\"}.sap-icon--status-inactive:before{content:\"\\e1ad\"}.sap-icon--status-critical:before,.sap-icon--status-in-progress:before{content:\"\\e1ae\"}.sap-icon--blank-tag-2:before{content:\"\\e1af\"}.sap-icon--cart-full:before{content:\"\\e1b0\"}.sap-icon--locate-me:before{content:\"\\e1b1\"}.sap-icon--paging:before{content:\"\\e1b2\"}.sap-icon--company-view:before{content:\"\\e1b3\"}.sap-icon--document-text:before{content:\"\\e1b4\"}.sap-icon--explorer:before{content:\"\\e1b5\"}.sap-icon--personnel-view:before{content:\"\\e1b6\"}.sap-icon--sorting-ranking:before{content:\"\\e1b7\"}.sap-icon--drill-down:before{content:\"\\e1b8\"}.sap-icon--drill-up:before{content:\"\\e1b9\"}.sap-icon--vds-file:before{content:\"\\e1ba\"}.sap-icon--sap-logo-shape:before{content:\"\\e1bb\"}.sap-icon--folder-full:before{content:\"\\e1bc\"}.sap-icon--system-exit:before{content:\"\\e1bd\"}.sap-icon--system-exit-2:before{content:\"\\e1be\"}.sap-icon--close-command-field:before{content:\"\\e1bf\"}.sap-icon--open-command-field:before{content:\"\\e1c0\"}.sap-icon--sys-enter-2:before{content:\"\\e1c1\"}.sap-icon--sys-enter:before{content:\"\\e1c2\"}.sap-icon--sys-help-2:before{content:\"\\e1c3\"}.sap-icon--sys-help:before{content:\"\\e1c4\"}.sap-icon--sys-back:before{content:\"\\e1c5\"}.sap-icon--sys-back-2:before{content:\"\\e1c6\"}.sap-icon--sys-cancel:before{content:\"\\e1c7\"}.sap-icon--sys-cancel-2:before{content:\"\\e1c8\"}.sap-icon--open-folder:before{content:\"\\e1c9\"}.sap-icon--sys-find-next:before{content:\"\\e1ca\"}.sap-icon--sys-find:before{content:\"\\e1cb\"}.sap-icon--sys-monitor:before{content:\"\\e1cc\"}.sap-icon--sys-prev-page:before{content:\"\\e1cd\"}.sap-icon--sys-first-page:before{content:\"\\e1ce\"}.sap-icon--sys-next-page:before{content:\"\\e1cf\"}.sap-icon--sys-last-page:before{content:\"\\e1d0\"}.sap-icon--generate-shortcut:before{content:\"\\e1d1\"}.sap-icon--create-session:before{content:\"\\e1d2\"}.sap-icon--display-more:before{content:\"\\e1d3\"}.sap-icon--enter-more:before{content:\"\\e1d4\"}.sap-icon--zoom-in:before{content:\"\\e1d5\"}.sap-icon--zoom-out:before{content:\"\\e1d6\"}.sap-icon--header:before{content:\"\\e1d7\"}.sap-icon--detail-view:before,.sap-icon--show-edit:before{content:\"\\e1d8\"}.sap-icon--collapse:before{content:\"\\e1d9\"}.sap-icon--expand:before{content:\"\\e1da\"}.sap-icon--positive:before{content:\"\\e1db\"}.sap-icon--negative:before{content:\"\\e1dc\"}.sap-icon--display:before{content:\"\\e1dd\"}.sap-icon--menu2:before{content:\"\\e1de\"}.sap-icon--redo:before{content:\"\\e1df\"}.sap-icon--undo:before{content:\"\\e1e0\"}.sap-icon--navigation-up-arrow:before{content:\"\\e1e1\"}.sap-icon--navigation-down-arrow:before{content:\"\\e1e2\"}.sap-icon--down:before{content:\"\\e1e3\"}.sap-icon--up:before{content:\"\\e1e4\"}.sap-icon--shelf:before{content:\"\\e1e5\"}.sap-icon--background:before{content:\"\\e1e6\"}.sap-icon--resize:before{content:\"\\e1e7\"}.sap-icon--move:before{content:\"\\e1e8\"}.sap-icon--show:before{content:\"\\e1e9\"}.sap-icon--hide:before{content:\"\\e1ea\"}.sap-icon--nav-back:before{content:\"\\e1eb\"}.sap-icon--error:before{content:\"\\e1ec\"}.sap-icon--slim-arrow-right:before{content:\"\\e1ed\"}.sap-icon--slim-arrow-left:before{content:\"\\e1ee\"}.sap-icon--slim-arrow-down:before{content:\"\\e1ef\"}.sap-icon--slim-arrow-up:before{content:\"\\e1f0\"}.sap-icon--forward:before{content:\"\\e1f1\"}.sap-icon--overflow:before{content:\"\\e1f2\"}.sap-icon--value-help:before{content:\"\\e1f3\"}.sap-icon--multiselect:before{content:\"\\e1f4\"}.sap-icon--exitfullscreen:before{content:\"\\e1f5\"}.sap-icon--sys-add:before{content:\"\\e1f6\"}.sap-icon--sys-minus:before{content:\"\\e1f7\"}.sap-icon--dropdown:before{content:\"\\e1f8\"}.sap-icon--expand-group:before{content:\"\\e1f9\"}.sap-icon--vertical-grip:before{content:\"\\e1fa\"}.sap-icon--horizontal-grip:before{content:\"\\e1fb\"}.sap-icon--sort-descending:before{content:\"\\e1fc\"}.sap-icon--sort-ascending:before{content:\"\\e1fd\"}.sap-icon--arrow-down:before{content:\"\\e1fe\"}.sap-icon--legend:before{content:\"\\e1ff\"}.sap-icon--collapse-group:before{content:\"\\e200\"}.sap-icon--message-warning:before{content:\"\\e201\"}.sap-icon--message-information:before{content:\"\\e202\"}.sap-icon--message-success:before{content:\"\\e203\"}.sap-icon--restart:before{content:\"\\e204\"}.sap-icon--stop:before{content:\"\\e205\"}.sap-icon--add-process:before{content:\"\\e206\"}.sap-icon--cancel-maintenance:before{content:\"\\e207\"}.sap-icon--activate:before{content:\"\\e208\"}.sap-icon--resize-horizontal:before{content:\"\\e209\"}.sap-icon--resize-vertical:before{content:\"\\e20a\"}.sap-icon--connected:before{content:\"\\e20b\"}.sap-icon--disconnected:before{content:\"\\e20c\"}.sap-icon--edit-outside:before{content:\"\\e20d\"}.sap-icon--key:before{content:\"\\e20e\"}.sap-icon--minimize:before{content:\"\\e20f\"}.sap-icon--back-to-top:before{content:\"\\e210\"}.sap-icon--hello-world:before{content:\"\\e211\"}.sap-icon--outbox:before{content:\"\\e212\"}.sap-icon--donut-chart:before{content:\"\\e213\"}.sap-icon--heatmap-chart:before{content:\"\\e214\"}.sap-icon--horizontal-bullet-chart:before{content:\"\\e215\"}.sap-icon--vertical-bullet-chart:before{content:\"\\e216\"}.sap-icon--call:before{content:\"\\e217\"}.sap-icon--download-from-cloud:before{content:\"\\e218\"}.sap-icon--upload-to-cloud:before{content:\"\\e219\"}.sap-icon--jam:before{content:\"\\e21a\"}.sap-icon--sap-ui5:before{content:\"\\e21b\"}.sap-icon--message-popup:before{content:\"\\e21c\"}.sap-icon--cloud:before{content:\"\\e21d\"}.sap-icon--horizontal-waterfall-chart:before{content:\"\\e21e\"}.sap-icon--vertical-waterfall-chart:before{content:\"\\e21f\"}.sap-icon--broken-link:before{content:\"\\e220\"}.sap-icon--headset:before{content:\"\\e221\"}.sap-icon--thumb-up:before{content:\"\\e222\"}.sap-icon--thumb-down:before{content:\"\\e223\"}.sap-icon--multiselect-all:before{content:\"\\e224\"}.sap-icon--multiselect-none:before{content:\"\\e225\"}.sap-icon--scissors:before{content:\"\\e226\"}.sap-icon--sound:before{content:\"\\e227\"}.sap-icon--sound-loud:before{content:\"\\e228\"}.sap-icon--sound-off:before{content:\"\\e229\"}.sap-icon--date-time:before{content:\"\\e22a\"}.sap-icon--user-settings:before{content:\"\\e22b\"}.sap-icon--key-user-settings:before{content:\"\\e23c\"}.sap-icon--developer-settings:before{content:\"\\e22d\"}.sap-icon--text-formatting:before{content:\"\\e22e\"}.sap-icon--bold-text:before{content:\"\\e22f\"}.sap-icon--italic-text:before{content:\"\\e230\"}.sap-icon--underline-text:before{content:\"\\e231\"}.sap-icon--text-align-justified:before{content:\"\\e232\"}.sap-icon--text-align-left:before{content:\"\\e233\"}.sap-icon--text-align-center:before{content:\"\\e234\"}.sap-icon--text-align-right:before{content:\"\\e235\"}.sap-icon--bullet-text:before{content:\"\\e236\"}.sap-icon--numbered-text:before{content:\"\\e237\"}.sap-icon--co:before{content:\"\\e238\"}.sap-icon--ui-notifications:before{content:\"\\e239\"}.sap-icon--bell:before{content:\"\\e23a\"}.sap-icon--cancel-share:before{content:\"\\e23b\"}.sap-icon--write-new-document:before{content:\"\\e23c\"}.sap-icon--write-new:before{content:\"\\e23d\"}.sap-icon--cancel:before{content:\"\\e23e\"}.sap-icon--screen-split-one:before{content:\"\\e23f\"}.sap-icon--screen-split-two:before{content:\"\\e240\"}.sap-icon--screen-split-three:before{content:\"\\e241\"}.sap-icon--customize:before{content:\"\\e242\"}.sap-icon--user-edit:before{content:\"\\e243\"}.sap-icon--source-code:before{content:\"\\e244\"}.sap-icon--copy:before{content:\"\\e245\"}.sap-icon--paste:before{content:\"\\e246\"}.sap-icon--line-chart-time-axis:before{content:\"\\e247\"}.sap-icon--clear-filter:before{content:\"\\e248\"}.sap-icon--reset:before{content:\"\\e249\"}.sap-icon--trend-up:before{content:\"\\e24a\"}.sap-icon--trend-down:before{content:\"\\e24b\"}.sap-icon--cursor:before{content:\"\\e24c\"}.sap-icon--add-document:before{content:\"\\e24d\"}.sap-icon--create-form:before{content:\"\\e24e\"}.sap-icon--resize-corner:before{content:\"\\e24f\"}.sap-icon--chevron-phase:before{content:\"\\e250\"}.sap-icon--chevron-phase-2:before{content:\"\\e251\"}.sap-icon--rhombus-milestone:before{content:\"\\e252\"}.sap-icon--rhombus-milestone-2:before{content:\"\\e253\"}.sap-icon--circle-task:before{content:\"\\e254\"}.sap-icon--circle-task-2:before{content:\"\\e255\"}.sap-icon--project-definition-triangle:before{content:\"\\e256\"}.sap-icon--project-definition-triangle-2:before{content:\"\\e257\"}.sap-icon--master-task-triangle:before{content:\"\\e258\"}.sap-icon--master-task-triangle-2:before{content:\"\\e259\"}.sap-icon--program-triangles:before{content:\"\\e25a\"}.sap-icon--program-triangles-2:before{content:\"\\e25b\"}.sap-icon--mirrored-task-circle:before{content:\"\\e25c\"}.sap-icon--mirrored-task-circle-2:before{content:\"\\e25d\"}.sap-icon--checklist-item:before{content:\"\\e25e\"}.sap-icon--checklist-item-2:before{content:\"\\e25f\"}.sap-icon--checklist:before{content:\"\\e260\"}.sap-icon--checklist-2:before{content:\"\\e261\"}.sap-icon--chart-table-view:before{content:\"\\e262\"}.sap-icon--filter-analytics:before{content:\"\\e263\"}.sap-icon--filter-facets:before{content:\"\\e264\"}.sap-icon--filter-fields:before{content:\"\\e265\"}.sap-icon--indent:before{content:\"\\e266\"}.sap-icon--outdent:before{content:\"\\e267\"}.sap-icon--heading-1:before{content:\"\\e268\"}.sap-icon--heading-2:before{content:\"\\e269\"}.sap-icon--heading-3:before{content:\"\\e26a\"}.sap-icon--decrease-line-height:before{content:\"\\e26b\"}.sap-icon--increase-line-height:before{content:\"\\e26c\"}.sap-icon--fx:before{content:\"\\e26d\"}.sap-icon--add-folder:before{content:\"\\e26e\"}.sap-icon--away:before{content:\"\\e26f\"}.sap-icon--busy:before{content:\"\\e270\"}.sap-icon--appear-offline:before{content:\"\\e271\"}.sap-icon--blur:before{content:\"\\e272\"}.sap-icon--pixelate:before{content:\"\\e273\"}.sap-icon--horizontal-combination-chart:before{content:\"\\e274\"}.sap-icon--add-employee:before{content:\"\\e275\"}.sap-icon--text-color:before{content:\"\\e276\"}.sap-icon--browse-folder:before{content:\"\\e277\"}.sap-icon--primary-key:before{content:\"\\e278\"}.sap-icon--two-keys:before{content:\"\\e279\"}.sap-icon--strikethrough:before{content:\"\\e27a\"}.sap-icon--text:before{content:\"\\e27b\"}.sap-icon--responsive:before{content:\"\\e27c\"}.sap-icon--desktop-mobile:before{content:\"\\e27d\"}.sap-icon--table-row:before{content:\"\\e27e\"}.sap-icon--table-column:before{content:\"\\e27f\"}.sap-icon--validate:before{content:\"\\e280\"}.sap-icon--keyboard-and-mouse:before{content:\"\\e281\"}.sap-icon--touch:before{content:\"\\e282\"}.sap-icon--expand-all:before{content:\"\\e283\"}.sap-icon--collapse-all:before{content:\"\\e284\"}.sap-icon--combine:before{content:\"\\e285\"}.sap-icon--split:before{content:\"\\e286\"}.sap-icon--megamenu:before{content:\"\\e287\"}.sap-icon--feedback:before{content:\"\\e288\"}.sap-icon--information:before{content:\"\\e289\"}.sap-icon--s4hana:before{content:\"\\e28a\"}.sap-icon--translate:before{content:\"\\e28b\"}.sap-icon--clear-all:before{content:\"\\e28c\"}.sap-icon--command-line-interfaces:before{content:\"\\e28d\"}.sap-icon--icon-sum:before{content:\"\\e28e\"}.sap-icon--icon-qr-code:before{content:\"\\e28f\"}.sap-icon--space-navigation:before{content:\"\\e290\"}.sap-icon--in-progress:before{content:\"\\e291\"}.sap-icon--not-editable:before{content:\"\\e292\"}.sap-icon--heart:before{content:\"\\e293\"}.sap-icon--heart-2:before{content:\"\\e294\"}.sap-icon--tri-state:before{content:\"\\e295\"}.sap-icon--bookmark-2:before{content:\"\\e296\"}.sap-icon--detail-less:before{content:\"\\e297\"}.sap-icon--detail-more:before{content:\"\\e298\"}.sap-icon--flag-2:before{content:\"\\e299\"}.sap-icon--folder-2:before{content:\"\\e29a\"}.sap-icon--paint-bucket:before{content:\"\\e29b\"}.sap-icon--direction-arrows:before{content:\"\\e29c\"}.sap-icon--binary:before{content:\"\\e29d\"}.sap-icon--female:before{content:\"\\e29e\"}.sap-icon--male:before{content:\"\\e29f\"}.sap-icon--gender-male-and-female:before{content:\"\\e300\"}.sap-icon--rotate:before{content:\"\\e301\"}.sap-icon--biometric-thumb:before{content:\"\\e306\"}.sap-icon--biometric-face:before{content:\"\\e307\"}.sap-icon--people-connected:before{content:\"\\e308\"}.sap-icon--select-appointments:before{content:\"\\e30b\"}.sap-icon--light-mode:before{content:\"\\e309\"}.sap-icon--dark-mode:before{content:\"\\e30a\"}.sap-icon--time-off:before{content:\"\\e30c\"}.sap-icon--add-calendar:before{content:\"\\e30d\"}.sap-icon--currency:before{content:\"\\e30e\"}.sap-icon--bell-2:before{content:\"\\e2a0\"}.sap-icon--accessibility:before{content:\"\\e2a1\"}.sap-icon--high-priority:before{content:\"\\e2a2\"}.sap-icon--da:before{content:\"\\e2a3\"}.sap-icon--da-2:before{content:\"\\e2a4\"}.sap-icon--ai:before{content:\"\\e2a5\"}.sap-icon--in-progress-2:before{content:\"\\e2a6\"}.sap-icon--unsynchronize:before{content:\"\\e2a7\"}.sap-icon--verified:before{content:\"\\e2a8\"}.sap-icon--walk-me:before{content:\"\\e2a9\"}.sap-icon-businessSuiteInAppSymbols--heart:before{content:\"\\e000\"}.sap-icon-businessSuiteInAppSymbols--quarter:before{content:\"\\e001\"}.sap-icon-businessSuiteInAppSymbols--year:before{content:\"\\e002\"}.sap-icon-businessSuiteInAppSymbols--equalizer:before{content:\"\\e003\"}.sap-icon-businessSuiteInAppSymbols--component:before{content:\"\\e004\"}.sap-icon-businessSuiteInAppSymbols--component-private:before{content:\"\\e005\"}.sap-icon-businessSuiteInAppSymbols--raw-material:before{content:\"\\e006\"}.sap-icon-businessSuiteInAppSymbols--sms:before{content:\"\\e007\"}.sap-icon-businessSuiteInAppSymbols--add-note:before{content:\"\\e008\"}.sap-icon-businessSuiteInAppSymbols--change-time-horizon:before{content:\"\\e009\"}.sap-icon-businessSuiteInAppSymbols--table-chart-customization:before{content:\"\\e00a\"}.sap-icon-businessSuiteInAppSymbols--delegated-important-task:before{content:\"\\e00b\"}.sap-icon-businessSuiteInAppSymbols--forklift:before{content:\"\\e00c\"}.sap-icon-businessSuiteInAppSymbols--coins:before{content:\"\\e00d\"}.sap-icon-businessSuiteInAppSymbols--filter-menu:before{content:\"\\e00e\"}.sap-icon-businessSuiteInAppSymbols--target-to-date:before{content:\"\\e00f\"}.sap-icon-businessSuiteInAppSymbols--program:before{content:\"\\e010\"}.sap-icon-businessSuiteInAppSymbols--phase:before{content:\"\\e011\"}.sap-icon-businessSuiteInAppSymbols--checklist:before{content:\"\\e012\"}.sap-icon-businessSuiteInAppSymbols--mirrored-task:before{content:\"\\e013\"}.sap-icon-businessSuiteInAppSymbols--sub-project:before{content:\"\\e014\"}.sap-icon-businessSuiteInAppSymbols--checklist-item:before{content:\"\\e015\"}.sap-icon-businessSuiteInAppSymbols--adhoc-analysis:before{content:\"\\e016\"}.sap-icon-businessSuiteInAppSymbols--change-analysis:before{content:\"\\e017\"}.sap-icon-businessSuiteInAppSymbols--review-demands:before{content:\"\\e018\"}.sap-icon-businessSuiteInAppSymbols--project-definition:before{content:\"\\e019\"}.sap-icon-businessSuiteInAppSymbols--data-access:before{content:\"\\e01a\"}.sap-icon-businessSuiteInAppSymbols--define-shortage:before{content:\"\\e01b\"}.sap-icon-businessSuiteInAppSymbols--review-supplies:before{content:\"\\e01c\"}.sap-icon-businessSuiteInAppSymbols--change-log:before{content:\"\\e01d\"}.sap-icon-businessSuiteInAppSymbols--priority-1:before{content:\"\\e01e\"}.sap-icon-businessSuiteInAppSymbols--priority-2:before{content:\"\\e01f\"}.sap-icon-businessSuiteInAppSymbols--jam:before{content:\"\\e020\"}.sap-icon-businessSuiteInAppSymbols--milestone:before{content:\"\\e021\"}.sap-icon-businessSuiteInAppSymbols--bulleting-with-numbers:before{content:\"\\e022\"}.sap-icon-businessSuiteInAppSymbols--decrease-indent:before{content:\"\\e023\"}.sap-icon-businessSuiteInAppSymbols--increase-indent:before{content:\"\\e024\"}.sap-icon-businessSuiteInAppSymbols--bold:before{content:\"\\e025\"}.sap-icon-businessSuiteInAppSymbols--italic:before{content:\"\\e026\"}.sap-icon-businessSuiteInAppSymbols--strike-through:before{content:\"\\e027\"}.sap-icon-businessSuiteInAppSymbols--underline:before{content:\"\\e028\"}.sap-icon-businessSuiteInAppSymbols--save-as:before{content:\"\\e029\"}.sap-icon-businessSuiteInAppSymbols--segmentation:before{content:\"\\e02a\"}.sap-icon-businessSuiteInAppSymbols--context-menu:before{content:\"\\e02b\"}.sap-icon-businessSuiteInAppSymbols--snapshot:before{content:\"\\e02c\"}.sap-icon-businessSuiteInAppSymbols--subtraction-b-a:before{content:\"\\e02d\"}.sap-icon-businessSuiteInAppSymbols--subtraction-a-b:before{content:\"\\e02e\"}.sap-icon-businessSuiteInAppSymbols--intersection:before{content:\"\\e02f\"}.sap-icon-businessSuiteInAppSymbols--union:before{content:\"\\e030\"}.sap-icon-businessSuiteInAppSymbols--top:before{content:\"\\e031\"}.sap-icon-businessSuiteInAppSymbols--bottom:before{content:\"\\e032\"}.sap-icon-businessSuiteInAppSymbols--page-up:before{content:\"\\e033\"}.sap-icon-businessSuiteInAppSymbols--page-down:before{content:\"\\e034\"}.sap-icon-businessSuiteInAppSymbols--create-dashboard:before{content:\"\\e035\"}.sap-icon-businessSuiteInAppSymbols--xcelsius-file:before{content:\"\\e036\"}.sap-icon-businessSuiteInAppSymbols--open-folder:before{content:\"\\e037\"}.sap-icon-businessSuiteInAppSymbols--neutral:before{content:\"\\e038\"}.sap-icon-businessSuiteInAppSymbols--split-segmentation:before{content:\"\\e039\"}.sap-icon-businessSuiteInAppSymbols--manage-budget:before{content:\"\\e03a\"}.sap-icon-businessSuiteInAppSymbols--blocked:before{content:\"\\e03b\"}.sap-icon-businessSuiteInAppSymbols--pipette:before{content:\"\\e03c\"}.sap-icon-businessSuiteInAppSymbols--top-recipe:before{content:\"\\e03d\"}.sap-icon-businessSuiteInAppSymbols--recipe:before{content:\"\\e03e\"}.sap-icon-businessSuiteInAppSymbols--ingredients:before{content:\"\\e03f\"}.sap-icon-businessSuiteInAppSymbols--multiple-charts:before{content:\"\\e040\"}.sap-icon-businessSuiteInAppSymbols--descending-bars:before{content:\"\\e041\"}.sap-icon-businessSuiteInAppSymbols--descending-stacked-bars:before{content:\"\\e042\"}.sap-icon-businessSuiteInAppSymbols--scatter-plot:before{content:\"\\e043\"}.sap-icon-businessSuiteInAppSymbols--spill:before{content:\"\\e044\"}.sap-icon-businessSuiteInAppSymbols--fire:before{content:\"\\e045\"}.sap-icon-businessSuiteInAppSymbols--stratification:before{content:\"\\e046\"}.sap-icon-businessSuiteInAppSymbols--relationship:before{content:\"\\e047\"}.sap-icon-businessSuiteInAppSymbols--margin-decomposition:before{content:\"\\e048\"}.sap-icon-businessSuiteInAppSymbols--control-group:before{content:\"\\e049\"}.sap-icon-businessSuiteInAppSymbols--comparison-chart:before{content:\"\\e04a\"}.sap-icon-businessSuiteInAppSymbols--responsible-area:before{content:\"\\e04b\"}.sap-icon-businessSuiteInAppSymbols--increase:before{content:\"\\e04c\"}.sap-icon-businessSuiteInAppSymbols--decrease:before{content:\"\\e04d\"}.sap-icon-businessSuiteInAppSymbols--current-stock:before{content:\"\\e04e\"}.sap-icon-businessSuiteInAppSymbols--expedite:before{content:\"\\e04f\"}.sap-icon-businessSuiteInAppSymbols--postpone:before{content:\"\\e050\"}.sap-icon-businessSuiteInAppSymbols--approved:before{content:\"\\e051\"}.sap-icon-businessSuiteInAppSymbols--partially-delivered:before{content:\"\\e052\"}.sap-icon-businessSuiteInAppSymbols--line-bar-chart:before{content:\"\\e053\"}.sap-icon-businessSuiteInAppSymbols--expand-all:before{content:\"\\e054\"}.sap-icon-businessSuiteInAppSymbols--submission:before{content:\"\\e055\"}.sap-icon-businessSuiteInAppSymbols--change-request:before{content:\"\\e056\"}.sap-icon-businessSuiteInAppSymbols--column-unselected:before{content:\"\\e057\"}.sap-icon-businessSuiteInAppSymbols--column-selected:before{content:\"\\e058\"}.sap-icon-businessSuiteInAppSymbols--row-unselected:before{content:\"\\e059\"}.sap-icon-businessSuiteInAppSymbols--row-selected:before{content:\"\\e05a\"}.sap-icon-businessSuiteInAppSymbols--stock-requirements:before{content:\"\\e05b\"}.sap-icon-businessSuiteInAppSymbols--gender-male-and-female:before{content:\"\\e05c\"}.sap-icon-businessSuiteInAppSymbols--marital-status:before{content:\"\\e05d\"}.sap-icon-businessSuiteInAppSymbols--birthday:before{content:\"\\e05e\"}.sap-icon-businessSuiteInAppSymbols--classification:before{content:\"\\e05f\"}.sap-icon-businessSuiteInAppSymbols--marked-for-deletion:before{content:\"\\e060\"}.sap-icon-businessSuiteInAppSymbols--bullet-chart:before{content:\"\\e061\"}.sap-icon-businessSuiteInAppSymbols--remove-filter:before{content:\"\\e062\"}.sap-icon-businessSuiteInAppSymbols--bank-account:before{content:\"\\e063\"}.sap-icon-businessSuiteInAppSymbols--savings-account:before{content:\"\\e064\"}.sap-icon-businessSuiteInAppSymbols--debit-card:before{content:\"\\e065\"}.sap-icon-businessSuiteInAppSymbols--vip-customer:before{content:\"\\e066\"}.sap-icon-businessSuiteInAppSymbols--undesirable-customer:before{content:\"\\e067\"}.sap-icon-businessSuiteInAppSymbols--answered-change-request:before{content:\"\\e068\"}.sap-icon-businessSuiteInAppSymbols--collected-change-request:before{content:\"\\e069\"}.sap-icon-businessSuiteInAppSymbols--draw-freehand:before{content:\"\\e06a\"}.sap-icon-businessSuiteInAppSymbols--draw-circle:before{content:\"\\e06b\"}.sap-icon-businessSuiteInAppSymbols--completed:before{content:\"\\e06c\"}.sap-icon-businessSuiteInAppSymbols--answered:before{content:\"\\e06d\"}.sap-icon-businessSuiteInAppSymbols--traffic-cone:before{content:\"\\e06e\"}.sap-icon-businessSuiteInAppSymbols--traffic-lights:before{content:\"\\e06f\"}.sap-icon-businessSuiteInAppSymbols--container:before{content:\"\\e070\"}.sap-icon-businessSuiteInAppSymbols--container-loading:before{content:\"\\e071\"}.sap-icon-businessSuiteInAppSymbols--traffic-jam:before{content:\"\\e072\"}.sap-icon-businessSuiteInAppSymbols--products:before{content:\"\\e073\"}.sap-icon-businessSuiteInAppSymbols--sidepanel:before{content:\"\\e074\"}.sap-icon-businessSuiteInAppSymbols--split-screen:before{content:\"\\e075\"}.sap-icon-businessSuiteInAppSymbols--truck-driver-2:before{content:\"\\e076\"}.sap-icon-businessSuiteInAppSymbols--keep-segment:before{content:\"\\e077\"}.sap-icon-businessSuiteInAppSymbols--exclude-segment:before{content:\"\\e078\"}.sap-icon-businessSuiteInAppSymbols--separate-segments:before{content:\"\\e079\"}.sap-icon-businessSuiteInAppSymbols--distribute-segments:before{content:\"\\e07a\"}.sap-icon-businessSuiteInAppSymbols--next-open-item:before{content:\"\\e07b\"}.sap-icon-businessSuiteInAppSymbols--where-used:before{content:\"\\e07c\"}.sap-icon-businessSuiteInAppSymbols--outbound-delivery:before{content:\"\\e07d\"}.sap-icon-businessSuiteInAppSymbols--outbound-delivery-inactive:before{content:\"\\e07e\"}.sap-icon-businessSuiteInAppSymbols--outbound-delivery-active:before{content:\"\\e07f\"}.sap-icon-businessSuiteInAppSymbols--target:before{content:\"\\e080\"}.sap-icon-businessSuiteInAppSymbols--source:before{content:\"\\e081\"}.sap-icon-businessSuiteInAppSymbols--material:before{content:\"\\e082\"}.sap-icon-businessSuiteInAppSymbols--due-date:before{content:\"\\e083\"}.sap-icon-businessSuiteInAppSymbols--overdue:before{content:\"\\e084\"}.sap-icon-businessSuiteInAppSymbols--set-as-default:before{content:\"\\e085\"}.sap-icon-businessSuiteInAppSymbols--face-very-bad:before{content:\"\\e086\"}.sap-icon-businessSuiteInAppSymbols--face-bad:before{content:\"\\e087\"}.sap-icon-businessSuiteInAppSymbols--face-skeptical:before{content:\"\\e088\"}.sap-icon-businessSuiteInAppSymbols--face-neutral:before{content:\"\\e089\"}.sap-icon-businessSuiteInAppSymbols--face-astonished:before{content:\"\\e08a\"}.sap-icon-businessSuiteInAppSymbols--face-happy:before{content:\"\\e08b\"}.sap-icon-businessSuiteInAppSymbols--face-very-happy:before{content:\"\\e08c\"}.sap-icon-businessSuiteInAppSymbols--face-awful:before{content:\"\\e08d\"}.sap-icon-businessSuiteInAppSymbols--face-devastated:before{content:\"\\e08e\"}.sap-icon-businessSuiteInAppSymbols--face-okey-dokey:before{content:\"\\e08f\"}.sap-icon-businessSuiteInAppSymbols--alarm:before{content:\"\\e090\"}.sap-icon-businessSuiteInAppSymbols--activate:before{content:\"\\e091\"}.sap-icon-businessSuiteInAppSymbols--segment-preview-reference-objects:before{content:\"\\e092\"}.sap-icon-businessSuiteInAppSymbols--radius:before{content:\"\\e093\"}.sap-icon-businessSuiteInAppSymbols--polygone-black:before{content:\"\\e094\"}.sap-icon-businessSuiteInAppSymbols--polygone-white:before{content:\"\\e095\"}.sap-icon-businessSuiteInAppSymbols--ploygone:before{content:\"\\e096\"}.sap-icon-businessSuiteInAppSymbols--no-filter:before{content:\"\\e097\"}.sap-icon-businessSuiteInAppSymbols--grip:before{content:\"\\e098\"}.sap-icon-businessSuiteInAppSymbols--add-component:before{content:\"\\e099\"}.sap-icon-businessSuiteInAppSymbols--water:before{content:\"\\e09a\"}.sap-icon-businessSuiteInAppSymbols--gas:before{content:\"\\e09b\"}.sap-icon-businessSuiteInAppSymbols--liquid:before{content:\"\\e09c\"}.sap-icon-businessSuiteInAppSymbols--time-deposit:before{content:\"\\e09d\"}.sap-icon-businessSuiteInAppSymbols--early-widthdrawal-for-time-deposits:before{content:\"\\e09e\"}.sap-icon-businessSuiteInAppSymbols--business-partner:before{content:\"\\e0e3\"}.sap-icon-businessSuiteInAppSymbols--truck-load:before{content:\"\\e0e8\"}.sap-icon-businessSuiteInAppSymbols--truck-unload:before{content:\"\\e0e9\"}.sap-icon-businessSuiteInAppSymbols--truck-load-unload:before{content:\"\\e0ea\"}.sap-icon-businessSuiteInAppSymbols--pharmacy:before{content:\"\\e0eb\"}.sap-icon-businessSuiteInAppSymbols--medicine-syrup:before{content:\"\\e0ec\"}.sap-icon-businessSuiteInAppSymbols--reminder:before{content:\"\\e0ed\"}.sap-icon-businessSuiteInAppSymbols--medicine-pill:before{content:\"\\e0ee\"}.sap-icon-businessSuiteInAppSymbols--medicine-ointment:before{content:\"\\e0ef\"}.sap-icon-businessSuiteInAppSymbols--medicine-drops:before{content:\"\\e0f0\"}.sap-icon-businessSuiteInAppSymbols--blood-test:before{content:\"\\e0f1\"}.sap-icon-businessSuiteInAppSymbols--temperature:before{content:\"\\e0f2\"}.sap-icon-businessSuiteInAppSymbols--medicine-inhaler:before{content:\"\\e0f3\"}.sap-icon-businessSuiteInAppSymbols--foot-steps:before{content:\"\\e0f4\"}.sap-icon-businessSuiteInAppSymbols--weight:before{content:\"\\e0f5\"}.sap-icon-businessSuiteInAppSymbols--health-tracking:before{content:\"\\e0f6\"}.sap-icon-businessSuiteInAppSymbols--blood-pressure:before{content:\"\\e0f7\"}.sap-icon-businessSuiteInAppSymbols--immunization:before{content:\"\\e0f8\"}.sap-icon-businessSuiteInAppSymbols--allergies:before{content:\"\\e0f9\"}.sap-icon-businessSuiteInAppSymbols--rescheduling2:before{content:\"\\e0fa\"}.sap-icon-businessSuiteInAppSymbols--resequencing2:before{content:\"\\e0fb\"}.sap-icon-businessSuiteInAppSymbols--no-time-change:before{content:\"\\e0fc\"}.sap-icon-businessSuiteInAppSymbols--time-change:before{content:\"\\e0fd\"}.sap-icon-businessSuiteInAppSymbols--smart-matcher:before{content:\"\\e0fe\"}.sap-icon-businessSuiteInAppSymbols--legal-section:before{content:\"\\e10a\"}.sap-icon-businessSuiteInAppSymbols--causes:before{content:\"\\e10b\"}.sap-icon-businessSuiteInAppSymbols--effects:before{content:\"\\e10c\"}.sap-icon-businessSuiteInAppSymbols--shared-by-me:before{content:\"\\e10d\"}.sap-icon-businessSuiteInAppSymbols--shared-with-me:before{content:\"\\e10e\"}.sap-icon-businessSuiteInAppSymbols--alert-groups:before{content:\"\\e111\"}.sap-icon-businessSuiteInAppSymbols--function-alert:before{content:\"\\e112\"}.sap-icon-businessSuiteInAppSymbols--function-hierarchy:before{content:\"\\e113\"}.sap-icon-businessSuiteInAppSymbols--rfid:before{content:\"\\e114\"}.sap-icon-businessSuiteInAppSymbols--input:before{content:\"\\e115\"}.sap-icon-businessSuiteInAppSymbols--software-item:before{content:\"\\e116\"}.sap-icon-businessSuiteInAppSymbols--product-view:before{content:\"\\e117\"}.sap-icon-businessSuiteInAppSymbols--software-item-variant:before{content:\"\\e118\"}.sap-icon-businessSuiteInAppSymbols--lighthouse:before{content:\"\\e119\"}.sap-icon-businessSuiteInAppSymbols--demand-unit:before{content:\"\\e11a\"}.sap-icon-businessSuiteInAppSymbols--fma-management:before{content:\"\\e11b\"}.sap-icon-businessSuiteInAppSymbols--fma-validation:before{content:\"\\e11c\"}.sap-icon-businessSuiteInAppSymbols--fma-analytics:before{content:\"\\e11d\"}.sap-icon-businessSuiteInAppSymbols--class:before{content:\"\\e11e\"}.sap-icon-businessSuiteInAppSymbols--overview:before{content:\"\\e11f\"}.sap-icon-businessSuiteInAppSymbols--production:before{content:\"\\e120\"}.sap-icon-businessSuiteInAppSymbols--subclass:before{content:\"\\e121\"}.sap-icon-businessSuiteInAppSymbols--variant-configuration:before{content:\"\\e122\"}.sap-icon-businessSuiteInAppSymbols--sum:before{content:\"\\e123\"}.sap-icon-businessSuiteInAppSymbols--empty-trailer:before{content:\"\\e12f\"}.sap-icon-businessSuiteInAppSymbols--door:before{content:\"\\e130\"}.sap-icon-businessSuiteInAppSymbols--loading-point:before{content:\"\\e131\"}.sap-icon-businessSuiteInAppSymbols--stock-warehouse:before{content:\"\\e132\"}.sap-icon-businessSuiteInAppSymbols--gate:before{content:\"\\e133\"}.sap-icon-businessSuiteInAppSymbols--timeseries-waterfall-chart:before{content:\"\\e134\"}.sap-icon-businessSuiteInAppSymbols--stages-warning:before{content:\"\\e138\"}.sap-icon-businessSuiteInAppSymbols--empty-warning:before{content:\"\\e139\"}.sap-icon-businessSuiteInAppSymbols--move-folder:before{content:\"\\e169\"}.sap-icon-businessSuiteInAppSymbols--remove-folder:before{content:\"\\e16a\"}.sap-icon-businessSuiteInAppSymbols--match-case:before{content:\"\\e16b\"}.sap-icon-businessSuiteInAppSymbols--match-whole-word:before{content:\"\\e16c\"}.sap-icon-businessSuiteInAppSymbols--remove-total:before{content:\"\\e16d\"}.sap-icon-businessSuiteInAppSymbols--after-total:before{content:\"\\e16e\"}.sap-icon-businessSuiteInAppSymbols--before-total:before{content:\"\\e16f\"}.sap-icon-businessSuiteInAppSymbols--workbook-filter:before{content:\"\\e170\"}.sap-icon-businessSuiteInAppSymbols--icon-update-filter:before{content:\"\\e171\"}.sap-icon-businessSuiteInAppSymbols--cell-lock:before{content:\"\\e172\"}.sap-icon-businessSuiteInAppSymbols--max-container:before{content:\"\\e17b\"}.sap-icon-businessSuiteInAppSymbols--max-interval:before{content:\"\\e17c\"}.sap-icon-businessSuiteInAppSymbols--min-interval:before{content:\"\\e17d\"}.sap-icon-businessSuiteInAppSymbols--cross-order:before{content:\"\\e17e\"}.sap-icon-businessSuiteInAppSymbols--empty-order:before{content:\"\\e17f\"}.sap-icon-businessSuiteInAppSymbols--cross-sequence:before{content:\"\\e180\"}.sap-icon-businessSuiteInAppSymbols--empty-sequence:before{content:\"\\e181\"}.sap-icon-businessSuiteInAppSymbols--cross-union:before{content:\"\\e182\"}.sap-icon-businessSuiteInAppSymbols--empty-union:before{content:\"\\e183\"}.sap-icon-businessSuiteInAppSymbols--cross-target:before{content:\"\\e184\"}.sap-icon-businessSuiteInAppSymbols--non-stackable:before{content:\"\\e185\"}.sap-icon-businessSuiteInAppSymbols--back-to-search:before{content:\"\\e186\"}.sap-icon-businessSuiteInAppSymbols--business-objects-folder:before{content:\"\\e187\"}.sap-icon-businessSuiteInAppSymbols--dangerous-goods:before{content:\"\\e18a\"}.sap-icon-businessSuiteInAppSymbols--staging:before{content:\"\\e189\"}.sap-icon-TNT--technicalsystem:before{content:\"\\e000\"}.sap-icon-TNT--systemjava:before{content:\"\\e001\"}.sap-icon-TNT--systemabap:before{content:\"\\e002\"}.sap-icon-TNT--systemrecommendations:before{content:\"\\e003\"}.sap-icon-TNT--system:before{content:\"\\e004\"}.sap-icon-TNT--systemtrex:before{content:\"\\e005\"}.sap-icon-TNT--systemtracks:before{content:\"\\e006\"}.sap-icon-TNT--technicalscenario:before{content:\"\\e007\"}.sap-icon-TNT--technicalinstance:before{content:\"\\e008\"}.sap-icon-TNT--throughput-backlog:before{content:\"\\e009\"}.sap-icon-TNT--batch-processing:before{content:\"\\e00a\"}.sap-icon-TNT--database-consistency:before{content:\"\\e00b\"}.sap-icon-TNT--intermediate-message:before{content:\"\\e00c\"}.sap-icon-TNT--exceptions:before{content:\"\\e00d\"}.sap-icon-TNT--system-HANA:before{content:\"\\e00e\"}.sap-icon-TNT--python:before{content:\"\\e00f\"}.sap-icon-TNT--raise-fault:before{content:\"\\e010\"}.sap-icon-TNT--code1:before{content:\"\\e011\"}.sap-icon-TNT--code2:before{content:\"\\e012\"}.sap-icon-TNT--spike-arrest:before{content:\"\\e013\"}.sap-icon-TNT--verify-API:before{content:\"\\e014\"}.sap-icon-TNT--user:before{content:\"\\e015\"}.sap-icon-TNT--note:before{content:\"\\e016\"}.sap-icon-TNT--throwing-message:before{content:\"\\e017\"}.sap-icon-TNT--catching-message:before{content:\"\\e018\"}.sap-icon-TNT--start-event:before{content:\"\\e019\"}.sap-icon-TNT--end-event:before{content:\"\\e01a\"}.sap-icon-TNT--gateway:before{content:\"\\e01b\"}.sap-icon-TNT--sub-process-marker:before{content:\"\\e01c\"}.sap-icon-TNT--ad-hoc-marker:before{content:\"\\e01d\"}.sap-icon-TNT--manual-task:before{content:\"\\e01e\"}.sap-icon-TNT--send-task:before{content:\"\\e01f\"}.sap-icon-TNT--receive-task:before{content:\"\\e020\"}.sap-icon-TNT--script-task:before{content:\"\\e021\"}.sap-icon-TNT--marquee:before{content:\"\\e022\"}.sap-icon-TNT--data-input-arrow:before{content:\"\\e023\"}.sap-icon-TNT--data-output-arrow:before{content:\"\\e024\"}.sap-icon-TNT--more:before{content:\"\\e025\"}.sap-icon-TNT--pattern:before{content:\"\\e026\"}.sap-icon-TNT--task:before{content:\"\\e027\"}.sap-icon-TNT--arrow:before{content:\"\\e028\"}.sap-icon-TNT--data:before{content:\"\\e029\"}.sap-icon-TNT--data-store:before{content:\"\\e02a\"}.sap-icon-TNT--pool:before{content:\"\\e02b\"}.sap-icon-TNT--swimlane:before{content:\"\\e02c\"}.sap-icon-TNT--select:before{content:\"\\e02d\"}.sap-icon-TNT--cursor:before{content:\"\\e02e\"}.sap-icon-TNT--api:before{content:\"\\e02f\"}.sap-icon-TNT--o-data:before{content:\"\\e030\"}.sap-icon-TNT--javascript:before{content:\"\\e031\"}.sap-icon-TNT--value-mapping:before{content:\"\\e032\"}.sap-icon-TNT--terminate-end-event:before{content:\"\\e033\"}.sap-icon-TNT--parallel-gateway:before{content:\"\\e034\"}.sap-icon-TNT--exclusive-gateway:before{content:\"\\e035\"}.sap-icon-TNT--service-task:before{content:\"\\e036\"}.sap-icon-TNT--workflow-editor:before{content:\"\\e037\"}.sap-icon-TNT--boundary-interrupting:before{content:\"\\e038\"}.sap-icon-TNT--boundary-non-interrupting:before{content:\"\\e039\"}.sap-icon-TNT--block:before{content:\"\\e03a\"}.sap-icon-TNT--constrain-block:before{content:\"\\e03b\"}.sap-icon-TNT--actor:before{content:\"\\e03c\"}.sap-icon-TNT--instance-specification:before{content:\"\\e03d\"}.sap-icon-TNT--value-type:before{content:\"\\e03e\"}.sap-icon-TNT--interface-block:before{content:\"\\e03f\"}.sap-icon-TNT--unit:before{content:\"\\e040\"}.sap-icon-TNT--signal:before{content:\"\\e041\"}.sap-icon-TNT--quantity-kind:before{content:\"\\e042\"}.sap-icon-TNT--item-flow:before{content:\"\\e043\"}.sap-icon-TNT--dependency:before{content:\"\\e044\"}.sap-icon-TNT--generalization:before{content:\"\\e045\"}.sap-icon-TNT--aggregation:before{content:\"\\e046\"}.sap-icon-TNT--composition:before{content:\"\\e047\"}.sap-icon-TNT--association:before{content:\"\\e048\"}.sap-icon-TNT--port:before{content:\"\\e049\"}.sap-icon-TNT--proxy-port:before{content:\"\\e04a\"}.sap-icon-TNT--full-port:before{content:\"\\e04b\"}.sap-icon-TNT--operations:before{content:\"\\e04c\"}.sap-icon-TNT--constrains:before{content:\"\\e04d\"}.sap-icon-TNT--receptions:before{content:\"\\e04e\"}.sap-icon-TNT--references:before{content:\"\\e04f\"}.sap-icon-TNT--parts:before{content:\"\\e050\"}.sap-icon-TNT--flow:before{content:\"\\e051\"}.sap-icon-TNT--values:before{content:\"\\e052\"}.sap-icon-TNT--bill-of-material:before{content:\"\\e053\"}.sap-icon-TNT--document-info-recording:before{content:\"\\e054\"}.sap-icon-TNT--use-case-diagram:before{content:\"\\e055\"}.sap-icon-TNT--bdd-diagram:before{content:\"\\e056\"}.sap-icon-TNT--requirement-diagram:before{content:\"\\e057\"}.sap-icon-TNT--package-diagram:before{content:\"\\e058\"}.sap-icon-TNT--internal-block-diagram:before{content:\"\\e059\"}.sap-icon-TNT--requirement-containment-relationship:before{content:\"\\e05a\"}.sap-icon-TNT--use-case:before{content:\"\\e05b\"}.sap-icon-TNT--use-case-extension-point:before{content:\"\\e05c\"}.sap-icon-TNT--communication-path:before{content:\"\\e05d\"}.sap-icon-TNT--note-connection:before{content:\"\\e05e\"}.sap-icon-TNT--subject:before{content:\"\\e05f\"}.sap-icon-TNT--auto-layout:before{content:\"\\e060\"}.sap-icon-TNT--required-interface:before{content:\"\\e061\"}.sap-icon-TNT--provided-interface:before{content:\"\\e062\"}.sap-icon-TNT--sub-content:before{content:\"\\e063\"}.sap-icon-TNT--connector:before{content:\"\\e064\"}.sap-icon-TNT--local-process-call:before{content:\"\\e065\"}.sap-icon-TNT--aggregator:before{content:\"\\e066\"}.sap-icon-TNT--splitter:before{content:\"\\e067\"}.sap-icon-TNT--converter:before{content:\"\\e068\"}.sap-icon-TNT--content-modifier:before{content:\"\\e069\"}.sap-icon-TNT--message-start-event:before{content:\"\\e06a\"}.sap-icon-TNT--message-end-event:before{content:\"\\e06d\"}.sap-icon-TNT--escalation-end-event:before{content:\"\\e06c\"}.sap-icon-TNT--start-timer-event:before{content:\"\\e06d\"}.sap-icon-TNT--error-start-event:before{content:\"\\e06e\"}.sap-icon-TNT--error-end-event:before{content:\"\\e06f\"}.sap-icon-TNT--content-enricher:before{content:\"\\e070\"}.sap-icon-TNT--realization:before{content:\"\\e071\"}.sap-icon-TNT--interface:before{content:\"\\e072\"}.sap-icon-TNT--usiness-capability:before{content:\"\\e073\"}.sap-icon-TNT--progress-group:before{content:\"\\e074\"}.sap-icon-TNT--value-stream:before{content:\"\\e075\"}.sap-icon-TNT--value-flow:before{content:\"\\e076\"}.sap-icon-TNT--application:before{content:\"\\e077\"}.sap-icon-TNT--etl-job:before{content:\"\\e078\"}.sap-icon-TNT--business-service:before{content:\"\\e079\"}.sap-icon-TNT--application-service:before{content:\"\\e07a\"}.sap-icon-TNT--network-node:before{content:\"\\e07b\"}.sap-icon-TNT--network:before{content:\"\\e07c\"}.sap-icon-TNT--deployment-instance:before{content:\"\\e07d\"}.sap-icon-TNT--intranet:before{content:\"\\e07e\"}.sap-icon-TNT--mobile-network:before{content:\"\\e07f\"}.sap-icon-TNT--private-cloud:before{content:\"\\e080\"}.sap-icon-TNT--antenna:before{content:\"\\e081\"}.sap-icon-TNT--firewall:before{content:\"\\e082\"}.sap-icon-TNT--hub:before{content:\"\\e083\"}.sap-icon-TNT--modem:before{content:\"\\e084\"}.sap-icon-TNT--repeater:before{content:\"\\e085\"}.sap-icon-TNT--router:before{content:\"\\e086\"}.sap-icon-TNT--switch:before{content:\"\\e087\"}.sap-icon-TNT--satellite:before{content:\"\\e088\"}.sap-icon-TNT--system-2:before{content:\"\\e089\"}.sap-icon-TNT--status-activating:before{content:\"\\e08a\"}.sap-icon-TNT--status-suspended:before{content:\"\\e08b\"}.sap-icon-TNT--status-suspending:before{content:\"\\e08c\"}.sap-icon-TNT--status-terminated:before{content:\"\\e08d\"}.sap-icon-TNT--status-terminating:before{content:\"\\e08e\"}.sap-icon-TNT--solution-not-licensed:before{content:\"\\e08f\"}.sap-icon-TNT--clear-all-mapping:before{content:\"\\e090\"}.sap-icon-TNT--map-all-fields:before{content:\"\\e091\"}.sap-icon-TNT--process-package:before{content:\"\\e092\"}.sap-icon-TNT--process-kpis:before{content:\"\\e093\"}.sap-icon-TNT--insights:before{content:\"\\e094\"}.sap-icon-TNT--escalation-boundary-interrupting:before{content:\"\\e095\"}.sap-icon-TNT--escalation-boundary-non-interrupting:before{content:\"\\e096\"}.sap-icon-TNT--escalation-throwing:before{content:\"\\e097\"}.sap-icon-TNT--solution:before{content:\"\\e098\"}.sap-icon-TNT--binary:before{content:\"\\e099\"}.sap-icon-TNT--uuid:before{content:\"\\e09a\"}.sap-icon-TNT--github:before{content:\"\\e09b\"}.sap-icon-TNT--robot:before{content:\"\\e09c\"}.sap-icon-TNT--string:before{content:\"\\e09d\"}.sap-icon-TNT--boolean:before{content:\"\\e09e\"}.sap-icon-TNT--array:before{content:\"\\e09f\"}.sap-icon-TNT--any:before{content:\"\\e101\"}.sap-icon-TNT--integer:before{content:\"\\e102\"}.sap-icon-TNT--float:before{content:\"\\e103\"}.sap-icon-TNT--build-work-zone:before{content:\"\\e104\"}.sap-icon-TNT--build-apps:before{content:\"\\e105\"}.sap-icon-TNT--build-process-automation:before{content:\"\\e106\"}.sap-icon-TNT--indicator:before{content:\"\\e107\"}.sap-icon-TNT--indicator-active:before{content:\"\\e108\"}.sap-icon-TNT--task-optional:before{content:\"\\e109\"}.sap-icon-TNT--task-done:before{content:\"\\e10a\"}.sap-icon-TNT--ai-1:before{content:\"\\e10b\"}.sap-icon-TNT--ai-2:before{content:\"\\e10c\"}.sap-icon-TNT--bound-validation-rule:before{content:\"\\e10d\"}.sap-icon-TNT--business-application-studio:before{content:\"\\e110\"}.sap-icon-TNT--clone-from-gi:before{content:\"\\e111\"}.sap-icon-TNT--business-accelerator:before{content:\"\\e112\"}.sap-icon-TNT--ai-feature-estimator:before{content:\"\\e113\"}.sap-icon-TNT--service-estimator:before{content:\"\\e114\"}.sap-icon-TNT--add-project:before{content:\"\\e115\"}.sap-icon-TNT--add-issue:before{content:\"\\e116\"}[class*=sap-icon].fd-inline-help__trigger{padding:0 .25rem;outline-offset:-.125rem}\n/*! Bundled license information:\n\nfundamental-styles/dist/icon.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], IconComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: IconComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-icon', template: ``, providers: [
                        {
                            provide: FD_ICON_COMPONENT,
                            useExisting: IconComponent
                        }
                    ], encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, styles: ["[class*=sap-icon]{background-color:var(--fdIcon_Background_Color,transparent);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdIcon_Color,inherit);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdIcon_Font_Size,1rem);font-style:normal;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}[class*=sap-icon]:after,[class*=sap-icon]:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}[class*=sap-icon]:before{font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}[class*=sap-icon].sap-icon--color-default{--fdIcon_Color:var(--sapContent_IconColor)}[class*=sap-icon].sap-icon--background-default{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-contrast{--fdIcon_Color:var(--sapContent_ContrastIconColor)}[class*=sap-icon].sap-icon--background-contrast{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-non-interactive{--fdIcon_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon].sap-icon--background-non-interactive{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-tile{--fdIcon_Color:var(--sapTile_IconColor)}[class*=sap-icon].sap-icon--background-tile{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-marker{--fdIcon_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon].sap-icon--background-marker{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-critical{--fdIcon_Color:var(--sapCriticalElementColor)}[class*=sap-icon].sap-icon--background-critical{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-negative{--fdIcon_Color:var(--sapNegativeElementColor)}[class*=sap-icon].sap-icon--background-negative{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-neutral{--fdIcon_Color:var(--sapNeutralElementColor)}[class*=sap-icon].sap-icon--background-neutral{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-positive{--fdIcon_Color:var(--sapPositiveElementColor)}[class*=sap-icon].sap-icon--background-positive{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--color-information{--fdIcon_Color:var(--sapInformativeElementColor)}[class*=sap-icon].sap-icon--background-information{--fdIcon_Background_Color: }[class*=sap-icon].sap-icon--background-default{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapContent_IconColor)}[class*=sap-icon].sap-icon--background-contrast{--fdIcon_Color:var(--sapContent_IconColor);--fdIcon_Background_Color:var(--sapGroup_ContentBackground)}[class*=sap-icon].sap-icon--background-non-interactive{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon].sap-icon--background-tile{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapTile_IconColor)}[class*=sap-icon].sap-icon--background-marker{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon].sap-icon--background-critical{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapCriticalElementColor)}[class*=sap-icon].sap-icon--background-negative{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapNegativeElementColor)}[class*=sap-icon].sap-icon--background-neutral{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapNeutralElementColor)}[class*=sap-icon].sap-icon--background-positive{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapPositiveElementColor)}[class*=sap-icon].sap-icon--background-information{--fdIcon_Color:var(--sapGroup_ContentBackground);--fdIcon_Background_Color:var(--sapInformativeElementColor)}[class*=sap-icon][tabindex=\"0\"]{cursor:pointer}[class*=sap-icon][tabindex=\"0\"].is-focus,[class*=sap-icon][tabindex=\"0\"]:focus{border-radius:.25rem;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);z-index:5}[class*=sap-icon-businessSuiteInAppSymbols]:before{font-family:SAP-icons-Business-Suite}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-default{--fdIcon_Color:var(--sapContent_IconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-default{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-contrast{--fdIcon_Color:var(--sapContent_ContrastIconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-contrast{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-non-interactive{--fdIcon_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-non-interactive{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-tile{--fdIcon_Color:var(--sapTile_IconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-tile{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-marker{--fdIcon_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-marker{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-critical{--fdIcon_Color:var(--sapCriticalElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-critical{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-negative{--fdIcon_Color:var(--sapNegativeElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-negative{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-neutral{--fdIcon_Color:var(--sapNeutralElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-neutral{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-positive{--fdIcon_Color:var(--sapPositiveElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-positive{--fdIcon_Background_Color: }[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--color-information{--fdIcon_Color:var(--sapInformativeElementColor)}[class*=sap-icon-businessSuiteInAppSymbols].sap-icon-businessSuiteInAppSymbols--background-information{--fdIcon_Background_Color: }[class*=sap-icon-TNT]:before{font-family:SAP-icons-TNT}[class*=sap-icon-TNT].sap-icon-TNT--color-default{--fdIcon_Color:var(--sapContent_IconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-default{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-contrast{--fdIcon_Color:var(--sapContent_ContrastIconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-contrast{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-non-interactive{--fdIcon_Color:var(--sapContent_NonInteractiveIconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-non-interactive{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-tile{--fdIcon_Color:var(--sapTile_IconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-tile{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-marker{--fdIcon_Color:var(--sapContent_MarkerIconColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-marker{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-critical{--fdIcon_Color:var(--sapCriticalElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-critical{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-negative{--fdIcon_Color:var(--sapNegativeElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-negative{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-neutral{--fdIcon_Color:var(--sapNeutralElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-neutral{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-positive{--fdIcon_Color:var(--sapPositiveElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-positive{--fdIcon_Background_Color: }[class*=sap-icon-TNT].sap-icon-TNT--color-information{--fdIcon_Color:var(--sapInformativeElementColor)}[class*=sap-icon-TNT].sap-icon-TNT--background-information{--fdIcon_Background_Color: }.sap-icon--accidental-leave:before{content:\"\\e000\"}.sap-icon--account:before{content:\"\\e001\"}.sap-icon--wrench:before{content:\"\\e002\"}.sap-icon--windows-doors:before{content:\"\\e003\"}.sap-icon--washing-machine:before{content:\"\\e004\"}.sap-icon--visits:before{content:\"\\e005\"}.sap-icon--video:before{content:\"\\e006\"}.sap-icon--travel-expense:before{content:\"\\e007\"}.sap-icon--temperature:before{content:\"\\e008\"}.sap-icon--task:before{content:\"\\e009\"}.sap-icon--synchronize:before{content:\"\\e00a\"}.sap-icon--survey:before{content:\"\\e00b\"}.sap-icon--settings:before{content:\"\\e00c\"}.sap-icon--search:before{content:\"\\e00d\"}.sap-icon--sales-document:before{content:\"\\e00e\"}.sap-icon--retail-store:before{content:\"\\e00f\"}.sap-icon--refresh:before{content:\"\\e010\"}.sap-icon--product:before{content:\"\\e011\"}.sap-icon--present:before{content:\"\\e012\"}.sap-icon--ppt-attachment:before{content:\"\\e013\"}.sap-icon--pool:before{content:\"\\e014\"}.sap-icon--pie-chart:before{content:\"\\e015\"}.sap-icon--picture:before{content:\"\\e016\"}.sap-icon--photo-voltaic:before{content:\"\\e017\"}.sap-icon--phone:before{content:\"\\e018\"}.sap-icon--pending:before{content:\"\\e019\"}.sap-icon--pdf-attachment:before{content:\"\\e01a\"}.sap-icon--past:before{content:\"\\e01b\"}.sap-icon--outgoing-call:before{content:\"\\e01c\"}.sap-icon--opportunity:before{content:\"\\e01d\"}.sap-icon--opportunities:before{content:\"\\e01e\"}.sap-icon--notes:before{content:\"\\e01f\"}.sap-icon--money-bills:before{content:\"\\e020\"}.sap-icon--map:before{content:\"\\e021\"}.sap-icon--log:before{content:\"\\e022\"}.sap-icon--line-charts:before{content:\"\\e023\"}.sap-icon--lightbulb:before{content:\"\\e024\"}.sap-icon--leads:before{content:\"\\e025\"}.sap-icon--lead:before{content:\"\\e026\"}.sap-icon--laptop:before{content:\"\\e027\"}.sap-icon--kpi-managing-my-area:before{content:\"\\e028\"}.sap-icon--kpi-corporate-performance:before{content:\"\\e029\"}.sap-icon--incoming-call:before{content:\"\\e02a\"}.sap-icon--inbox:before{content:\"\\e02b\"}.sap-icon--horizontal-bar-chart:before{content:\"\\e02c\"}.sap-icon--history:before{content:\"\\e02d\"}.sap-icon--heating-cooling:before{content:\"\\e02e\"}.sap-icon--gantt-bars:before{content:\"\\e02f\"}.sap-icon--future:before{content:\"\\e030\"}.sap-icon--fridge:before{content:\"\\e031\"}.sap-icon--fallback:before{content:\"\\e032\"}.sap-icon--expense-report:before{content:\"\\e033\"}.sap-icon--excel-attachment:before{content:\"\\e034\"}.sap-icon--energy-saving-lightbulb:before{content:\"\\e035\"}.sap-icon--employee:before{content:\"\\e036\"}.sap-icon--email:before{content:\"\\e037\"}.sap-icon--edit:before{content:\"\\e038\"}.sap-icon--duplicate:before{content:\"\\e039\"}.sap-icon--download:before{content:\"\\e03a\"}.sap-icon--doc-attachment:before{content:\"\\e03b\"}.sap-icon--dishwasher:before{content:\"\\e03c\"}.sap-icon--delete:before{content:\"\\e03d\"}.sap-icon--decline:before{content:\"\\e03e\"}.sap-icon--complete:before{content:\"\\e03f\"}.sap-icon--competitor:before{content:\"\\e040\"}.sap-icon--collections-management:before{content:\"\\e041\"}.sap-icon--chalkboard:before{content:\"\\e042\"}.sap-icon--cart:before{content:\"\\e043\"}.sap-icon--card:before{content:\"\\e044\"}.sap-icon--camera:before{content:\"\\e045\"}.sap-icon--calendar:before{content:\"\\e046\"}.sap-icon--begin:before{content:\"\\e047\"}.sap-icon--basket:before{content:\"\\e048\"}.sap-icon--bar-chart:before{content:\"\\e049\"}.sap-icon--attachment:before{content:\"\\e04a\"}.sap-icon--arrow-top:before{content:\"\\e04b\"}.sap-icon--arrow-right:before{content:\"\\e04c\"}.sap-icon--arrow-left:before{content:\"\\e04d\"}.sap-icon--arrow-bottom:before{content:\"\\e04e\"}.sap-icon--approvals:before{content:\"\\e04f\"}.sap-icon--appointment:before{content:\"\\e050\"}.sap-icon--alphabetical-order:before{content:\"\\e051\"}.sap-icon--along-stacked-chart:before{content:\"\\e052\"}.sap-icon--alert:before{content:\"\\e053\"}.sap-icon--addresses:before{content:\"\\e054\"}.sap-icon--address-book:before{content:\"\\e055\"}.sap-icon--add-filter:before{content:\"\\e056\"}.sap-icon--add-favorite:before{content:\"\\e057\"}.sap-icon--add:before{content:\"\\e058\"}.sap-icon--activities:before{content:\"\\e059\"}.sap-icon--action:before{content:\"\\e05a\"}.sap-icon--accept:before{content:\"\\e05b\"}.sap-icon--hint:before{content:\"\\e05c\"}.sap-icon--group:before{content:\"\\e05d\"}.sap-icon--check-availability:before{content:\"\\e05e\"}.sap-icon--weather-proofing:before{content:\"\\e05f\"}.sap-icon--payment-approval:before{content:\"\\e060\"}.sap-icon--batch-payments:before{content:\"\\e061\"}.sap-icon--bed:before{content:\"\\e062\"}.sap-icon--arobase:before{content:\"\\e063\"}.sap-icon--family-care:before{content:\"\\e064\"}.sap-icon--favorite:before{content:\"\\e065\"}.sap-icon--navigation-right-arrow:before{content:\"\\e066\"}.sap-icon--navigation-left-arrow:before{content:\"\\e067\"}.sap-icon--e-care:before{content:\"\\e068\"}.sap-icon--less:before{content:\"\\e069\"}.sap-icon--lateness:before{content:\"\\e06a\"}.sap-icon--lab:before{content:\"\\e06b\"}.sap-icon--internet-browser:before{content:\"\\e06c\"}.sap-icon--instance:before{content:\"\\e06d\"}.sap-icon--inspection:before{content:\"\\e06e\"}.sap-icon--image-viewer:before{content:\"\\e06f\"}.sap-icon--home:before{content:\"\\e070\"}.sap-icon--grid:before{content:\"\\e071\"}.sap-icon--goalseek:before{content:\"\\e072\"}.sap-icon--general-leave-request:before{content:\"\\e073\"}.sap-icon--create-leave-request:before{content:\"\\e074\"}.sap-icon--flight:before{content:\"\\e075\"}.sap-icon--filter:before{content:\"\\e076\"}.sap-icon--favorite-list:before{content:\"\\e077\"}.sap-icon--factory:before{content:\"\\e078\"}.sap-icon--endoscopy:before{content:\"\\e079\"}.sap-icon--employee-pane:before{content:\"\\e07a\"}.sap-icon--employee-approvals:before{content:\"\\e07b\"}.sap-icon--email-read:before{content:\"\\e07c\"}.sap-icon--electrocardiogram:before{content:\"\\e07d\"}.sap-icon--documents:before{content:\"\\e07e\"}.sap-icon--decision:before{content:\"\\e07f\"}.sap-icon--database:before{content:\"\\e080\"}.sap-icon--customer-history:before{content:\"\\e081\"}.sap-icon--customer:before{content:\"\\e082\"}.sap-icon--credit-card:before{content:\"\\e083\"}.sap-icon--create-entry-time:before{content:\"\\e084\"}.sap-icon--contacts:before{content:\"\\e085\"}.sap-icon--compare:before{content:\"\\e086\"}.sap-icon--clinical-order:before{content:\"\\e087\"}.sap-icon--chain-link:before{content:\"\\e088\"}.sap-icon--pull-down:before{content:\"\\e089\"}.sap-icon--cargo-train:before{content:\"\\e08a\"}.sap-icon--car-rental:before{content:\"\\e08b\"}.sap-icon--business-card:before{content:\"\\e08c\"}.sap-icon--bar-code:before{content:\"\\e08d\"}.sap-icon--folder-blank:before{content:\"\\e08e\"}.sap-icon--passenger-train:before{content:\"\\e08f\"}.sap-icon--question-mark:before{content:\"\\e090\"}.sap-icon--world:before{content:\"\\e091\"}.sap-icon--iphone:before{content:\"\\e092\"}.sap-icon--ipad:before{content:\"\\e093\"}.sap-icon--warning:before{content:\"\\e094\"}.sap-icon--sort:before{content:\"\\e095\"}.sap-icon--course-book:before{content:\"\\e096\"}.sap-icon--course-program:before{content:\"\\e097\"}.sap-icon--add-coursebook:before{content:\"\\e098\"}.sap-icon--print:before{content:\"\\e099\"}.sap-icon--save:before{content:\"\\e09a\"}.sap-icon--play:before{content:\"\\e09b\"}.sap-icon--pause:before{content:\"\\e09c\"}.sap-icon--record:before{content:\"\\e09d\"}.sap-icon--response:before{content:\"\\e09e\"}.sap-icon--pushpin-on:before{content:\"\\e09f\"}.sap-icon--pushpin-off:before{content:\"\\e0a0\"}.sap-icon--unfavorite:before{content:\"\\e0a1\"}.sap-icon--learning-assistant:before{content:\"\\e0a2\"}.sap-icon--timesheet:before{content:\"\\e0a3\"}.sap-icon--time-entry-request:before{content:\"\\e0a4\"}.sap-icon--list:before{content:\"\\e0a5\"}.sap-icon--action-settings:before{content:\"\\e0a6\"}.sap-icon--share:before{content:\"\\e0a7\"}.sap-icon--feed:before{content:\"\\e0a8\"}.sap-icon--role:before{content:\"\\e0a9\"}.sap-icon--flag:before{content:\"\\e0aa\"}.sap-icon--post:before{content:\"\\e0ab\"}.sap-icon--inspect:before{content:\"\\e0ac\"}.sap-icon--inspect-down:before{content:\"\\e0ad\"}.sap-icon--appointment-2:before{content:\"\\e0ae\"}.sap-icon--target-group:before{content:\"\\e0af\"}.sap-icon--marketing-campaign:before{content:\"\\e0b0\"}.sap-icon--message-error:before,.sap-icon--notification:before{content:\"\\e0b1\"}.sap-icon--comment:before{content:\"\\e0b2\"}.sap-icon--shipping-status:before{content:\"\\e0b3\"}.sap-icon--collaborate:before{content:\"\\e0b4\"}.sap-icon--shortcut:before{content:\"\\e0b5\"}.sap-icon--lead-outdated:before{content:\"\\e0b6\"}.sap-icon--tools-opportunity:before{content:\"\\e0b7\"}.sap-icon--permission:before{content:\"\\e0b8\"}.sap-icon--supplier:before{content:\"\\e0b9\"}.sap-icon--table-view:before{content:\"\\e0ba\"}.sap-icon--table-chart:before{content:\"\\e0bb\"}.sap-icon--switch-views:before{content:\"\\e0bc\"}.sap-icon--e-learning:before{content:\"\\e0bd\"}.sap-icon--manager:before{content:\"\\e0be\"}.sap-icon--switch-classes:before{content:\"\\e0bf\"}.sap-icon--simple-payment:before{content:\"\\e0c0\"}.sap-icon--signature:before{content:\"\\e0c1\"}.sap-icon--sales-order-item:before{content:\"\\e0c2\"}.sap-icon--sales-order:before{content:\"\\e0c3\"}.sap-icon--request:before{content:\"\\e0c4\"}.sap-icon--receipt:before{content:\"\\e0c5\"}.sap-icon--puzzle:before{content:\"\\e0c6\"}.sap-icon--process:before{content:\"\\e0c7\"}.sap-icon--private:before{content:\"\\e0c8\"}.sap-icon--popup-window:before{content:\"\\e0c9\"}.sap-icon--person-placeholder:before{content:\"\\e0ca\"}.sap-icon--per-diem:before{content:\"\\e0cb\"}.sap-icon--paper-plane:before{content:\"\\e0cc\"}.sap-icon--paid-leave:before{content:\"\\e0cd\"}.sap-icon--pdf-reader:before{content:\"\\e0ce\"}.sap-icon--overview-chart:before{content:\"\\e0cf\"}.sap-icon--overlay:before{content:\"\\e0d0\"}.sap-icon--org-chart:before{content:\"\\e0d1\"}.sap-icon--number-sign:before{content:\"\\e0d2\"}.sap-icon--notification-2:before{content:\"\\e0d3\"}.sap-icon--my-sales-order:before{content:\"\\e0d4\"}.sap-icon--meal:before{content:\"\\e0d5\"}.sap-icon--loan:before{content:\"\\e0d6\"}.sap-icon--order-status:before{content:\"\\e0d7\"}.sap-icon--customer-order-entry:before{content:\"\\e0d8\"}.sap-icon--performance:before{content:\"\\e0d9\"}.sap-icon--menu:before{content:\"\\e0da\"}.sap-icon--employee-lookup:before{content:\"\\e0db\"}.sap-icon--education:before{content:\"\\e0dc\"}.sap-icon--customer-briefing:before{content:\"\\e0dd\"}.sap-icon--customer-and-contacts:before{content:\"\\e0de\"}.sap-icon--my-view:before{content:\"\\e0df\"}.sap-icon--accelerated:before{content:\"\\e0e0\"}.sap-icon--to-be-reviewed:before{content:\"\\e0e1\"}.sap-icon--warning2:before{content:\"\\e0e2\"}.sap-icon--feeder-arrow:before{content:\"\\e0e3\"}.sap-icon--quality-issue:before{content:\"\\e0e4\"}.sap-icon--workflow-tasks:before{content:\"\\e0e5\"}.sap-icon--create:before{content:\"\\e0e6\"}.sap-icon--home-share:before{content:\"\\e0e7\"}.sap-icon--globe:before{content:\"\\e0e8\"}.sap-icon--tags:before{content:\"\\e0e9\"}.sap-icon--work-history:before{content:\"\\e0ea\"}.sap-icon--x-ray:before{content:\"\\e0eb\"}.sap-icon--wounds-doc:before{content:\"\\e0ec\"}.sap-icon--web-cam:before{content:\"\\e0ed\"}.sap-icon--waiver:before{content:\"\\e0ee\"}.sap-icon--vertical-bar-chart:before{content:\"\\e0ef\"}.sap-icon--upstacked-chart:before{content:\"\\e0f0\"}.sap-icon--trip-report:before{content:\"\\e0f1\"}.sap-icon--microphone:before{content:\"\\e0f2\"}.sap-icon--unpaid-leave:before{content:\"\\e0f3\"}.sap-icon--tree:before{content:\"\\e0f4\"}.sap-icon--toaster-up:before{content:\"\\e0f5\"}.sap-icon--toaster-top:before{content:\"\\e0f6\"}.sap-icon--toaster-down:before{content:\"\\e0f7\"}.sap-icon--time-account:before{content:\"\\e0f8\"}.sap-icon--theater:before{content:\"\\e0f9\"}.sap-icon--taxi:before{content:\"\\e0fa\"}.sap-icon--subway-train:before{content:\"\\e0fb\"}.sap-icon--study-leave:before{content:\"\\e0fc\"}.sap-icon--stethoscope:before{content:\"\\e0fd\"}.sap-icon--step:before{content:\"\\e0fe\"}.sap-icon--sonography:before{content:\"\\e0ff\"}.sap-icon--soccor:before{content:\"\\e100\"}.sap-icon--physical-activity:before{content:\"\\e101\"}.sap-icon--pharmacy:before{content:\"\\e102\"}.sap-icon--official-service:before{content:\"\\e103\"}.sap-icon--offsite-work:before{content:\"\\e104\"}.sap-icon--nutrition-activity:before{content:\"\\e105\"}.sap-icon--newspaper:before{content:\"\\e106\"}.sap-icon--monitor-payments:before{content:\"\\e107\"}.sap-icon--map-2:before{content:\"\\e108\"}.sap-icon--machine:before{content:\"\\e109\"}.sap-icon--mri-scan:before{content:\"\\e10a\"}.sap-icon--end-user-experience-monitoring:before{content:\"\\e10b\"}.sap-icon--unwired:before{content:\"\\e10c\"}.sap-icon--customer-financial-fact-sheet:before{content:\"\\e10d\"}.sap-icon--retail-store-manager:before{content:\"\\e10e\"}.sap-icon--Netweaver-business-client:before{content:\"\\e10f\"}.sap-icon--electronic-medical-record:before{content:\"\\e110\"}.sap-icon--eam-work-order:before{content:\"\\e111\"}.sap-icon--customer-view:before{content:\"\\e112\"}.sap-icon--crm-service-manager:before{content:\"\\e113\"}.sap-icon--crm-sales:before{content:\"\\e114\"}.sap-icon--widgets:before{content:\"\\e115\"}.sap-icon--commission-check:before{content:\"\\e116\"}.sap-icon--collections-insight:before{content:\"\\e117\"}.sap-icon--clinical-task-tracker:before{content:\"\\e118\"}.sap-icon--citizen-connect:before{content:\"\\e119\"}.sap-icon--cart-approval:before{content:\"\\e11a\"}.sap-icon--capital-projects:before{content:\"\\e11b\"}.sap-icon--bo-strategy-management:before{content:\"\\e11c\"}.sap-icon--business-objects-mobile:before{content:\"\\e11d\"}.sap-icon--business-objects-explorer:before{content:\"\\e11e\"}.sap-icon--business-objects-experience:before{content:\"\\e11f\"}.sap-icon--bbyd-dashboard:before{content:\"\\e120\"}.sap-icon--bbyd-active-sales:before{content:\"\\e121\"}.sap-icon--business-by-design:before{content:\"\\e122\"}.sap-icon--business-one:before{content:\"\\e123\"}.sap-icon--sap-box:before{content:\"\\e124\"}.sap-icon--manager-insight:before{content:\"\\e125\"}.sap-icon--accounting-document-verification:before{content:\"\\e126\"}.sap-icon--hr-approval:before{content:\"\\e127\"}.sap-icon--idea-wall:before{content:\"\\e128\"}.sap-icon--Chart-Tree-Map:before{content:\"\\e129\"}.sap-icon--cart-5:before{content:\"\\e12a\"}.sap-icon--cart-4:before{content:\"\\e12b\"}.sap-icon--wallet:before{content:\"\\e12c\"}.sap-icon--vehicle-repair:before{content:\"\\e12d\"}.sap-icon--upload:before{content:\"\\e12e\"}.sap-icon--unlocked:before{content:\"\\e12f\"}.sap-icon--umbrella:before{content:\"\\e130\"}.sap-icon--travel-request:before{content:\"\\e131\"}.sap-icon--travel-expense-report:before{content:\"\\e132\"}.sap-icon--travel-itinerary:before{content:\"\\e133\"}.sap-icon--time-overtime:before{content:\"\\e134\"}.sap-icon--thing-type:before{content:\"\\e135\"}.sap-icon--technical-object:before{content:\"\\e136\"}.sap-icon--tag:before{content:\"\\e137\"}.sap-icon--syringe:before{content:\"\\e138\"}.sap-icon--syntax:before{content:\"\\e139\"}.sap-icon--suitcase:before{content:\"\\e13a\"}.sap-icon--simulate:before{content:\"\\e13b\"}.sap-icon--shield:before{content:\"\\e13c\"}.sap-icon--share-2:before{content:\"\\e13d\"}.sap-icon--sales-quote:before{content:\"\\e13e\"}.sap-icon--repost:before{content:\"\\e13f\"}.sap-icon--provision:before{content:\"\\e140\"}.sap-icon--projector:before{content:\"\\e141\"}.sap-icon--add-product:before{content:\"\\e142\"}.sap-icon--pipeline-analysis:before{content:\"\\e143\"}.sap-icon--add-photo:before{content:\"\\e144\"}.sap-icon--palette:before{content:\"\\e145\"}.sap-icon--nurse:before{content:\"\\e146\"}.sap-icon--sales-notification:before{content:\"\\e147\"}.sap-icon--mileage:before{content:\"\\e148\"}.sap-icon--meeting-room:before{content:\"\\e149\"}.sap-icon--media-forward:before{content:\"\\e14a\"}.sap-icon--media-play:before{content:\"\\e14b\"}.sap-icon--media-pause:before{content:\"\\e14c\"}.sap-icon--media-reverse:before{content:\"\\e14d\"}.sap-icon--media-rewind:before{content:\"\\e14e\"}.sap-icon--measurement-document:before{content:\"\\e14f\"}.sap-icon--measuring-point:before{content:\"\\e150\"}.sap-icon--measure:before{content:\"\\e151\"}.sap-icon--map-3:before{content:\"\\e152\"}.sap-icon--locked:before{content:\"\\e153\"}.sap-icon--letter:before{content:\"\\e154\"}.sap-icon--journey-arrive:before{content:\"\\e155\"}.sap-icon--journey-change:before{content:\"\\e156\"}.sap-icon--journey-depart:before{content:\"\\e157\"}.sap-icon--it-system:before{content:\"\\e158\"}.sap-icon--it-instance:before{content:\"\\e159\"}.sap-icon--it-host:before{content:\"\\e15a\"}.sap-icon--iphone-2:before{content:\"\\e15b\"}.sap-icon--ipad-2:before{content:\"\\e15c\"}.sap-icon--inventory:before{content:\"\\e15d\"}.sap-icon--insurance-house:before{content:\"\\e15e\"}.sap-icon--insurance-life:before{content:\"\\e15f\"}.sap-icon--insurance-car:before{content:\"\\e160\"}.sap-icon--initiative:before{content:\"\\e161\"}.sap-icon--incident:before{content:\"\\e162\"}.sap-icon--group-2:before{content:\"\\e163\"}.sap-icon--goal:before{content:\"\\e164\"}.sap-icon--functional-location:before{content:\"\\e165\"}.sap-icon--full-screen:before{content:\"\\e166\"}.sap-icon--form:before{content:\"\\e167\"}.sap-icon--fob-watch:before{content:\"\\e168\"}.sap-icon--blank-tag:before{content:\"\\e169\"}.sap-icon--family-protection:before{content:\"\\e16a\"}.sap-icon--folder:before{content:\"\\e16b\"}.sap-icon--fax-machine:before{content:\"\\e16c\"}.sap-icon--example:before{content:\"\\e16d\"}.sap-icon--eraser:before{content:\"\\e16e\"}.sap-icon--employee-rejections:before{content:\"\\e16f\"}.sap-icon--drop-down-list:before{content:\"\\e170\"}.sap-icon--draw-rectangle:before{content:\"\\e171\"}.sap-icon--document:before{content:\"\\e172\"}.sap-icon--doctor:before{content:\"\\e173\"}.sap-icon--discussion-2:before{content:\"\\e174\"}.sap-icon--discussion:before{content:\"\\e175\"}.sap-icon--dimension:before{content:\"\\e176\"}.sap-icon--customer-and-supplier:before{content:\"\\e177\"}.sap-icon--crop:before{content:\"\\e178\"}.sap-icon--add-contact:before{content:\"\\e179\"}.sap-icon--compare-2:before{content:\"\\e17a\"}.sap-icon--color-fill:before{content:\"\\e17b\"}.sap-icon--collision:before{content:\"\\e17c\"}.sap-icon--curriculum:before{content:\"\\e17d\"}.sap-icon--chart-axis:before{content:\"\\e17e\"}.sap-icon--full-stacked-chart:before{content:\"\\e17f\"}.sap-icon--full-stacked-column-chart:before{content:\"\\e180\"}.sap-icon--vertical-bar-chart-2:before{content:\"\\e181\"}.sap-icon--horizontal-bar-chart-2:before{content:\"\\e182\"}.sap-icon--horizontal-stacked-chart:before{content:\"\\e183\"}.sap-icon--vertical-stacked-chart:before{content:\"\\e184\"}.sap-icon--choropleth-chart:before{content:\"\\e185\"}.sap-icon--geographic-bubble-chart:before{content:\"\\e186\"}.sap-icon--multiple-radar-chart:before{content:\"\\e187\"}.sap-icon--radar-chart:before{content:\"\\e188\"}.sap-icon--crossed-line-chart:before{content:\"\\e189\"}.sap-icon--multiple-line-chart:before{content:\"\\e18a\"}.sap-icon--multiple-bar-chart:before{content:\"\\e18b\"}.sap-icon--line-chart:before{content:\"\\e18c\"}.sap-icon--line-chart-dual-axis:before{content:\"\\e18d\"}.sap-icon--bubble-chart:before{content:\"\\e18e\"}.sap-icon--scatter-chart:before{content:\"\\e18f\"}.sap-icon--multiple-pie-chart:before{content:\"\\e190\"}.sap-icon--column-chart-dual-axis:before{content:\"\\e191\"}.sap-icon--tag-cloud-chart:before{content:\"\\e192\"}.sap-icon--area-chart:before{content:\"\\e193\"}.sap-icon--cause:before{content:\"\\e194\"}.sap-icon--cart-3:before{content:\"\\e195\"}.sap-icon--cart-2:before{content:\"\\e196\"}.sap-icon--bus-public-transport:before{content:\"\\e197\"}.sap-icon--burglary:before{content:\"\\e198\"}.sap-icon--building:before{content:\"\\e199\"}.sap-icon--border:before{content:\"\\e19a\"}.sap-icon--bookmark:before{content:\"\\e19b\"}.sap-icon--badge:before{content:\"\\e19c\"}.sap-icon--attachment-audio:before{content:\"\\e19d\"}.sap-icon--attachment-video:before{content:\"\\e19e\"}.sap-icon--attachment-html:before{content:\"\\e19f\"}.sap-icon--attachment-photo:before{content:\"\\e1a0\"}.sap-icon--attachment-e-pub:before{content:\"\\e1a1\"}.sap-icon--attachment-zip-file:before{content:\"\\e1a2\"}.sap-icon--attachment-text-file:before{content:\"\\e1a3\"}.sap-icon--add-equipment:before{content:\"\\e1a4\"}.sap-icon--add-activity:before{content:\"\\e1a5\"}.sap-icon--activity-individual:before{content:\"\\e1a6\"}.sap-icon--activity-2:before{content:\"\\e1a7\"}.sap-icon--add-activity-2:before{content:\"\\e1a8\"}.sap-icon--activity-items:before{content:\"\\e1a9\"}.sap-icon--activity-assigned-to-goal:before{content:\"\\e1aa\"}.sap-icon--status-completed:before,.sap-icon--status-positive:before{content:\"\\e1ab\"}.sap-icon--status-error:before,.sap-icon--status-negative:before{content:\"\\e1ac\"}.sap-icon--status-inactive:before{content:\"\\e1ad\"}.sap-icon--status-critical:before,.sap-icon--status-in-progress:before{content:\"\\e1ae\"}.sap-icon--blank-tag-2:before{content:\"\\e1af\"}.sap-icon--cart-full:before{content:\"\\e1b0\"}.sap-icon--locate-me:before{content:\"\\e1b1\"}.sap-icon--paging:before{content:\"\\e1b2\"}.sap-icon--company-view:before{content:\"\\e1b3\"}.sap-icon--document-text:before{content:\"\\e1b4\"}.sap-icon--explorer:before{content:\"\\e1b5\"}.sap-icon--personnel-view:before{content:\"\\e1b6\"}.sap-icon--sorting-ranking:before{content:\"\\e1b7\"}.sap-icon--drill-down:before{content:\"\\e1b8\"}.sap-icon--drill-up:before{content:\"\\e1b9\"}.sap-icon--vds-file:before{content:\"\\e1ba\"}.sap-icon--sap-logo-shape:before{content:\"\\e1bb\"}.sap-icon--folder-full:before{content:\"\\e1bc\"}.sap-icon--system-exit:before{content:\"\\e1bd\"}.sap-icon--system-exit-2:before{content:\"\\e1be\"}.sap-icon--close-command-field:before{content:\"\\e1bf\"}.sap-icon--open-command-field:before{content:\"\\e1c0\"}.sap-icon--sys-enter-2:before{content:\"\\e1c1\"}.sap-icon--sys-enter:before{content:\"\\e1c2\"}.sap-icon--sys-help-2:before{content:\"\\e1c3\"}.sap-icon--sys-help:before{content:\"\\e1c4\"}.sap-icon--sys-back:before{content:\"\\e1c5\"}.sap-icon--sys-back-2:before{content:\"\\e1c6\"}.sap-icon--sys-cancel:before{content:\"\\e1c7\"}.sap-icon--sys-cancel-2:before{content:\"\\e1c8\"}.sap-icon--open-folder:before{content:\"\\e1c9\"}.sap-icon--sys-find-next:before{content:\"\\e1ca\"}.sap-icon--sys-find:before{content:\"\\e1cb\"}.sap-icon--sys-monitor:before{content:\"\\e1cc\"}.sap-icon--sys-prev-page:before{content:\"\\e1cd\"}.sap-icon--sys-first-page:before{content:\"\\e1ce\"}.sap-icon--sys-next-page:before{content:\"\\e1cf\"}.sap-icon--sys-last-page:before{content:\"\\e1d0\"}.sap-icon--generate-shortcut:before{content:\"\\e1d1\"}.sap-icon--create-session:before{content:\"\\e1d2\"}.sap-icon--display-more:before{content:\"\\e1d3\"}.sap-icon--enter-more:before{content:\"\\e1d4\"}.sap-icon--zoom-in:before{content:\"\\e1d5\"}.sap-icon--zoom-out:before{content:\"\\e1d6\"}.sap-icon--header:before{content:\"\\e1d7\"}.sap-icon--detail-view:before,.sap-icon--show-edit:before{content:\"\\e1d8\"}.sap-icon--collapse:before{content:\"\\e1d9\"}.sap-icon--expand:before{content:\"\\e1da\"}.sap-icon--positive:before{content:\"\\e1db\"}.sap-icon--negative:before{content:\"\\e1dc\"}.sap-icon--display:before{content:\"\\e1dd\"}.sap-icon--menu2:before{content:\"\\e1de\"}.sap-icon--redo:before{content:\"\\e1df\"}.sap-icon--undo:before{content:\"\\e1e0\"}.sap-icon--navigation-up-arrow:before{content:\"\\e1e1\"}.sap-icon--navigation-down-arrow:before{content:\"\\e1e2\"}.sap-icon--down:before{content:\"\\e1e3\"}.sap-icon--up:before{content:\"\\e1e4\"}.sap-icon--shelf:before{content:\"\\e1e5\"}.sap-icon--background:before{content:\"\\e1e6\"}.sap-icon--resize:before{content:\"\\e1e7\"}.sap-icon--move:before{content:\"\\e1e8\"}.sap-icon--show:before{content:\"\\e1e9\"}.sap-icon--hide:before{content:\"\\e1ea\"}.sap-icon--nav-back:before{content:\"\\e1eb\"}.sap-icon--error:before{content:\"\\e1ec\"}.sap-icon--slim-arrow-right:before{content:\"\\e1ed\"}.sap-icon--slim-arrow-left:before{content:\"\\e1ee\"}.sap-icon--slim-arrow-down:before{content:\"\\e1ef\"}.sap-icon--slim-arrow-up:before{content:\"\\e1f0\"}.sap-icon--forward:before{content:\"\\e1f1\"}.sap-icon--overflow:before{content:\"\\e1f2\"}.sap-icon--value-help:before{content:\"\\e1f3\"}.sap-icon--multiselect:before{content:\"\\e1f4\"}.sap-icon--exitfullscreen:before{content:\"\\e1f5\"}.sap-icon--sys-add:before{content:\"\\e1f6\"}.sap-icon--sys-minus:before{content:\"\\e1f7\"}.sap-icon--dropdown:before{content:\"\\e1f8\"}.sap-icon--expand-group:before{content:\"\\e1f9\"}.sap-icon--vertical-grip:before{content:\"\\e1fa\"}.sap-icon--horizontal-grip:before{content:\"\\e1fb\"}.sap-icon--sort-descending:before{content:\"\\e1fc\"}.sap-icon--sort-ascending:before{content:\"\\e1fd\"}.sap-icon--arrow-down:before{content:\"\\e1fe\"}.sap-icon--legend:before{content:\"\\e1ff\"}.sap-icon--collapse-group:before{content:\"\\e200\"}.sap-icon--message-warning:before{content:\"\\e201\"}.sap-icon--message-information:before{content:\"\\e202\"}.sap-icon--message-success:before{content:\"\\e203\"}.sap-icon--restart:before{content:\"\\e204\"}.sap-icon--stop:before{content:\"\\e205\"}.sap-icon--add-process:before{content:\"\\e206\"}.sap-icon--cancel-maintenance:before{content:\"\\e207\"}.sap-icon--activate:before{content:\"\\e208\"}.sap-icon--resize-horizontal:before{content:\"\\e209\"}.sap-icon--resize-vertical:before{content:\"\\e20a\"}.sap-icon--connected:before{content:\"\\e20b\"}.sap-icon--disconnected:before{content:\"\\e20c\"}.sap-icon--edit-outside:before{content:\"\\e20d\"}.sap-icon--key:before{content:\"\\e20e\"}.sap-icon--minimize:before{content:\"\\e20f\"}.sap-icon--back-to-top:before{content:\"\\e210\"}.sap-icon--hello-world:before{content:\"\\e211\"}.sap-icon--outbox:before{content:\"\\e212\"}.sap-icon--donut-chart:before{content:\"\\e213\"}.sap-icon--heatmap-chart:before{content:\"\\e214\"}.sap-icon--horizontal-bullet-chart:before{content:\"\\e215\"}.sap-icon--vertical-bullet-chart:before{content:\"\\e216\"}.sap-icon--call:before{content:\"\\e217\"}.sap-icon--download-from-cloud:before{content:\"\\e218\"}.sap-icon--upload-to-cloud:before{content:\"\\e219\"}.sap-icon--jam:before{content:\"\\e21a\"}.sap-icon--sap-ui5:before{content:\"\\e21b\"}.sap-icon--message-popup:before{content:\"\\e21c\"}.sap-icon--cloud:before{content:\"\\e21d\"}.sap-icon--horizontal-waterfall-chart:before{content:\"\\e21e\"}.sap-icon--vertical-waterfall-chart:before{content:\"\\e21f\"}.sap-icon--broken-link:before{content:\"\\e220\"}.sap-icon--headset:before{content:\"\\e221\"}.sap-icon--thumb-up:before{content:\"\\e222\"}.sap-icon--thumb-down:before{content:\"\\e223\"}.sap-icon--multiselect-all:before{content:\"\\e224\"}.sap-icon--multiselect-none:before{content:\"\\e225\"}.sap-icon--scissors:before{content:\"\\e226\"}.sap-icon--sound:before{content:\"\\e227\"}.sap-icon--sound-loud:before{content:\"\\e228\"}.sap-icon--sound-off:before{content:\"\\e229\"}.sap-icon--date-time:before{content:\"\\e22a\"}.sap-icon--user-settings:before{content:\"\\e22b\"}.sap-icon--key-user-settings:before{content:\"\\e23c\"}.sap-icon--developer-settings:before{content:\"\\e22d\"}.sap-icon--text-formatting:before{content:\"\\e22e\"}.sap-icon--bold-text:before{content:\"\\e22f\"}.sap-icon--italic-text:before{content:\"\\e230\"}.sap-icon--underline-text:before{content:\"\\e231\"}.sap-icon--text-align-justified:before{content:\"\\e232\"}.sap-icon--text-align-left:before{content:\"\\e233\"}.sap-icon--text-align-center:before{content:\"\\e234\"}.sap-icon--text-align-right:before{content:\"\\e235\"}.sap-icon--bullet-text:before{content:\"\\e236\"}.sap-icon--numbered-text:before{content:\"\\e237\"}.sap-icon--co:before{content:\"\\e238\"}.sap-icon--ui-notifications:before{content:\"\\e239\"}.sap-icon--bell:before{content:\"\\e23a\"}.sap-icon--cancel-share:before{content:\"\\e23b\"}.sap-icon--write-new-document:before{content:\"\\e23c\"}.sap-icon--write-new:before{content:\"\\e23d\"}.sap-icon--cancel:before{content:\"\\e23e\"}.sap-icon--screen-split-one:before{content:\"\\e23f\"}.sap-icon--screen-split-two:before{content:\"\\e240\"}.sap-icon--screen-split-three:before{content:\"\\e241\"}.sap-icon--customize:before{content:\"\\e242\"}.sap-icon--user-edit:before{content:\"\\e243\"}.sap-icon--source-code:before{content:\"\\e244\"}.sap-icon--copy:before{content:\"\\e245\"}.sap-icon--paste:before{content:\"\\e246\"}.sap-icon--line-chart-time-axis:before{content:\"\\e247\"}.sap-icon--clear-filter:before{content:\"\\e248\"}.sap-icon--reset:before{content:\"\\e249\"}.sap-icon--trend-up:before{content:\"\\e24a\"}.sap-icon--trend-down:before{content:\"\\e24b\"}.sap-icon--cursor:before{content:\"\\e24c\"}.sap-icon--add-document:before{content:\"\\e24d\"}.sap-icon--create-form:before{content:\"\\e24e\"}.sap-icon--resize-corner:before{content:\"\\e24f\"}.sap-icon--chevron-phase:before{content:\"\\e250\"}.sap-icon--chevron-phase-2:before{content:\"\\e251\"}.sap-icon--rhombus-milestone:before{content:\"\\e252\"}.sap-icon--rhombus-milestone-2:before{content:\"\\e253\"}.sap-icon--circle-task:before{content:\"\\e254\"}.sap-icon--circle-task-2:before{content:\"\\e255\"}.sap-icon--project-definition-triangle:before{content:\"\\e256\"}.sap-icon--project-definition-triangle-2:before{content:\"\\e257\"}.sap-icon--master-task-triangle:before{content:\"\\e258\"}.sap-icon--master-task-triangle-2:before{content:\"\\e259\"}.sap-icon--program-triangles:before{content:\"\\e25a\"}.sap-icon--program-triangles-2:before{content:\"\\e25b\"}.sap-icon--mirrored-task-circle:before{content:\"\\e25c\"}.sap-icon--mirrored-task-circle-2:before{content:\"\\e25d\"}.sap-icon--checklist-item:before{content:\"\\e25e\"}.sap-icon--checklist-item-2:before{content:\"\\e25f\"}.sap-icon--checklist:before{content:\"\\e260\"}.sap-icon--checklist-2:before{content:\"\\e261\"}.sap-icon--chart-table-view:before{content:\"\\e262\"}.sap-icon--filter-analytics:before{content:\"\\e263\"}.sap-icon--filter-facets:before{content:\"\\e264\"}.sap-icon--filter-fields:before{content:\"\\e265\"}.sap-icon--indent:before{content:\"\\e266\"}.sap-icon--outdent:before{content:\"\\e267\"}.sap-icon--heading-1:before{content:\"\\e268\"}.sap-icon--heading-2:before{content:\"\\e269\"}.sap-icon--heading-3:before{content:\"\\e26a\"}.sap-icon--decrease-line-height:before{content:\"\\e26b\"}.sap-icon--increase-line-height:before{content:\"\\e26c\"}.sap-icon--fx:before{content:\"\\e26d\"}.sap-icon--add-folder:before{content:\"\\e26e\"}.sap-icon--away:before{content:\"\\e26f\"}.sap-icon--busy:before{content:\"\\e270\"}.sap-icon--appear-offline:before{content:\"\\e271\"}.sap-icon--blur:before{content:\"\\e272\"}.sap-icon--pixelate:before{content:\"\\e273\"}.sap-icon--horizontal-combination-chart:before{content:\"\\e274\"}.sap-icon--add-employee:before{content:\"\\e275\"}.sap-icon--text-color:before{content:\"\\e276\"}.sap-icon--browse-folder:before{content:\"\\e277\"}.sap-icon--primary-key:before{content:\"\\e278\"}.sap-icon--two-keys:before{content:\"\\e279\"}.sap-icon--strikethrough:before{content:\"\\e27a\"}.sap-icon--text:before{content:\"\\e27b\"}.sap-icon--responsive:before{content:\"\\e27c\"}.sap-icon--desktop-mobile:before{content:\"\\e27d\"}.sap-icon--table-row:before{content:\"\\e27e\"}.sap-icon--table-column:before{content:\"\\e27f\"}.sap-icon--validate:before{content:\"\\e280\"}.sap-icon--keyboard-and-mouse:before{content:\"\\e281\"}.sap-icon--touch:before{content:\"\\e282\"}.sap-icon--expand-all:before{content:\"\\e283\"}.sap-icon--collapse-all:before{content:\"\\e284\"}.sap-icon--combine:before{content:\"\\e285\"}.sap-icon--split:before{content:\"\\e286\"}.sap-icon--megamenu:before{content:\"\\e287\"}.sap-icon--feedback:before{content:\"\\e288\"}.sap-icon--information:before{content:\"\\e289\"}.sap-icon--s4hana:before{content:\"\\e28a\"}.sap-icon--translate:before{content:\"\\e28b\"}.sap-icon--clear-all:before{content:\"\\e28c\"}.sap-icon--command-line-interfaces:before{content:\"\\e28d\"}.sap-icon--icon-sum:before{content:\"\\e28e\"}.sap-icon--icon-qr-code:before{content:\"\\e28f\"}.sap-icon--space-navigation:before{content:\"\\e290\"}.sap-icon--in-progress:before{content:\"\\e291\"}.sap-icon--not-editable:before{content:\"\\e292\"}.sap-icon--heart:before{content:\"\\e293\"}.sap-icon--heart-2:before{content:\"\\e294\"}.sap-icon--tri-state:before{content:\"\\e295\"}.sap-icon--bookmark-2:before{content:\"\\e296\"}.sap-icon--detail-less:before{content:\"\\e297\"}.sap-icon--detail-more:before{content:\"\\e298\"}.sap-icon--flag-2:before{content:\"\\e299\"}.sap-icon--folder-2:before{content:\"\\e29a\"}.sap-icon--paint-bucket:before{content:\"\\e29b\"}.sap-icon--direction-arrows:before{content:\"\\e29c\"}.sap-icon--binary:before{content:\"\\e29d\"}.sap-icon--female:before{content:\"\\e29e\"}.sap-icon--male:before{content:\"\\e29f\"}.sap-icon--gender-male-and-female:before{content:\"\\e300\"}.sap-icon--rotate:before{content:\"\\e301\"}.sap-icon--biometric-thumb:before{content:\"\\e306\"}.sap-icon--biometric-face:before{content:\"\\e307\"}.sap-icon--people-connected:before{content:\"\\e308\"}.sap-icon--select-appointments:before{content:\"\\e30b\"}.sap-icon--light-mode:before{content:\"\\e309\"}.sap-icon--dark-mode:before{content:\"\\e30a\"}.sap-icon--time-off:before{content:\"\\e30c\"}.sap-icon--add-calendar:before{content:\"\\e30d\"}.sap-icon--currency:before{content:\"\\e30e\"}.sap-icon--bell-2:before{content:\"\\e2a0\"}.sap-icon--accessibility:before{content:\"\\e2a1\"}.sap-icon--high-priority:before{content:\"\\e2a2\"}.sap-icon--da:before{content:\"\\e2a3\"}.sap-icon--da-2:before{content:\"\\e2a4\"}.sap-icon--ai:before{content:\"\\e2a5\"}.sap-icon--in-progress-2:before{content:\"\\e2a6\"}.sap-icon--unsynchronize:before{content:\"\\e2a7\"}.sap-icon--verified:before{content:\"\\e2a8\"}.sap-icon--walk-me:before{content:\"\\e2a9\"}.sap-icon-businessSuiteInAppSymbols--heart:before{content:\"\\e000\"}.sap-icon-businessSuiteInAppSymbols--quarter:before{content:\"\\e001\"}.sap-icon-businessSuiteInAppSymbols--year:before{content:\"\\e002\"}.sap-icon-businessSuiteInAppSymbols--equalizer:before{content:\"\\e003\"}.sap-icon-businessSuiteInAppSymbols--component:before{content:\"\\e004\"}.sap-icon-businessSuiteInAppSymbols--component-private:before{content:\"\\e005\"}.sap-icon-businessSuiteInAppSymbols--raw-material:before{content:\"\\e006\"}.sap-icon-businessSuiteInAppSymbols--sms:before{content:\"\\e007\"}.sap-icon-businessSuiteInAppSymbols--add-note:before{content:\"\\e008\"}.sap-icon-businessSuiteInAppSymbols--change-time-horizon:before{content:\"\\e009\"}.sap-icon-businessSuiteInAppSymbols--table-chart-customization:before{content:\"\\e00a\"}.sap-icon-businessSuiteInAppSymbols--delegated-important-task:before{content:\"\\e00b\"}.sap-icon-businessSuiteInAppSymbols--forklift:before{content:\"\\e00c\"}.sap-icon-businessSuiteInAppSymbols--coins:before{content:\"\\e00d\"}.sap-icon-businessSuiteInAppSymbols--filter-menu:before{content:\"\\e00e\"}.sap-icon-businessSuiteInAppSymbols--target-to-date:before{content:\"\\e00f\"}.sap-icon-businessSuiteInAppSymbols--program:before{content:\"\\e010\"}.sap-icon-businessSuiteInAppSymbols--phase:before{content:\"\\e011\"}.sap-icon-businessSuiteInAppSymbols--checklist:before{content:\"\\e012\"}.sap-icon-businessSuiteInAppSymbols--mirrored-task:before{content:\"\\e013\"}.sap-icon-businessSuiteInAppSymbols--sub-project:before{content:\"\\e014\"}.sap-icon-businessSuiteInAppSymbols--checklist-item:before{content:\"\\e015\"}.sap-icon-businessSuiteInAppSymbols--adhoc-analysis:before{content:\"\\e016\"}.sap-icon-businessSuiteInAppSymbols--change-analysis:before{content:\"\\e017\"}.sap-icon-businessSuiteInAppSymbols--review-demands:before{content:\"\\e018\"}.sap-icon-businessSuiteInAppSymbols--project-definition:before{content:\"\\e019\"}.sap-icon-businessSuiteInAppSymbols--data-access:before{content:\"\\e01a\"}.sap-icon-businessSuiteInAppSymbols--define-shortage:before{content:\"\\e01b\"}.sap-icon-businessSuiteInAppSymbols--review-supplies:before{content:\"\\e01c\"}.sap-icon-businessSuiteInAppSymbols--change-log:before{content:\"\\e01d\"}.sap-icon-businessSuiteInAppSymbols--priority-1:before{content:\"\\e01e\"}.sap-icon-businessSuiteInAppSymbols--priority-2:before{content:\"\\e01f\"}.sap-icon-businessSuiteInAppSymbols--jam:before{content:\"\\e020\"}.sap-icon-businessSuiteInAppSymbols--milestone:before{content:\"\\e021\"}.sap-icon-businessSuiteInAppSymbols--bulleting-with-numbers:before{content:\"\\e022\"}.sap-icon-businessSuiteInAppSymbols--decrease-indent:before{content:\"\\e023\"}.sap-icon-businessSuiteInAppSymbols--increase-indent:before{content:\"\\e024\"}.sap-icon-businessSuiteInAppSymbols--bold:before{content:\"\\e025\"}.sap-icon-businessSuiteInAppSymbols--italic:before{content:\"\\e026\"}.sap-icon-businessSuiteInAppSymbols--strike-through:before{content:\"\\e027\"}.sap-icon-businessSuiteInAppSymbols--underline:before{content:\"\\e028\"}.sap-icon-businessSuiteInAppSymbols--save-as:before{content:\"\\e029\"}.sap-icon-businessSuiteInAppSymbols--segmentation:before{content:\"\\e02a\"}.sap-icon-businessSuiteInAppSymbols--context-menu:before{content:\"\\e02b\"}.sap-icon-businessSuiteInAppSymbols--snapshot:before{content:\"\\e02c\"}.sap-icon-businessSuiteInAppSymbols--subtraction-b-a:before{content:\"\\e02d\"}.sap-icon-businessSuiteInAppSymbols--subtraction-a-b:before{content:\"\\e02e\"}.sap-icon-businessSuiteInAppSymbols--intersection:before{content:\"\\e02f\"}.sap-icon-businessSuiteInAppSymbols--union:before{content:\"\\e030\"}.sap-icon-businessSuiteInAppSymbols--top:before{content:\"\\e031\"}.sap-icon-businessSuiteInAppSymbols--bottom:before{content:\"\\e032\"}.sap-icon-businessSuiteInAppSymbols--page-up:before{content:\"\\e033\"}.sap-icon-businessSuiteInAppSymbols--page-down:before{content:\"\\e034\"}.sap-icon-businessSuiteInAppSymbols--create-dashboard:before{content:\"\\e035\"}.sap-icon-businessSuiteInAppSymbols--xcelsius-file:before{content:\"\\e036\"}.sap-icon-businessSuiteInAppSymbols--open-folder:before{content:\"\\e037\"}.sap-icon-businessSuiteInAppSymbols--neutral:before{content:\"\\e038\"}.sap-icon-businessSuiteInAppSymbols--split-segmentation:before{content:\"\\e039\"}.sap-icon-businessSuiteInAppSymbols--manage-budget:before{content:\"\\e03a\"}.sap-icon-businessSuiteInAppSymbols--blocked:before{content:\"\\e03b\"}.sap-icon-businessSuiteInAppSymbols--pipette:before{content:\"\\e03c\"}.sap-icon-businessSuiteInAppSymbols--top-recipe:before{content:\"\\e03d\"}.sap-icon-businessSuiteInAppSymbols--recipe:before{content:\"\\e03e\"}.sap-icon-businessSuiteInAppSymbols--ingredients:before{content:\"\\e03f\"}.sap-icon-businessSuiteInAppSymbols--multiple-charts:before{content:\"\\e040\"}.sap-icon-businessSuiteInAppSymbols--descending-bars:before{content:\"\\e041\"}.sap-icon-businessSuiteInAppSymbols--descending-stacked-bars:before{content:\"\\e042\"}.sap-icon-businessSuiteInAppSymbols--scatter-plot:before{content:\"\\e043\"}.sap-icon-businessSuiteInAppSymbols--spill:before{content:\"\\e044\"}.sap-icon-businessSuiteInAppSymbols--fire:before{content:\"\\e045\"}.sap-icon-businessSuiteInAppSymbols--stratification:before{content:\"\\e046\"}.sap-icon-businessSuiteInAppSymbols--relationship:before{content:\"\\e047\"}.sap-icon-businessSuiteInAppSymbols--margin-decomposition:before{content:\"\\e048\"}.sap-icon-businessSuiteInAppSymbols--control-group:before{content:\"\\e049\"}.sap-icon-businessSuiteInAppSymbols--comparison-chart:before{content:\"\\e04a\"}.sap-icon-businessSuiteInAppSymbols--responsible-area:before{content:\"\\e04b\"}.sap-icon-businessSuiteInAppSymbols--increase:before{content:\"\\e04c\"}.sap-icon-businessSuiteInAppSymbols--decrease:before{content:\"\\e04d\"}.sap-icon-businessSuiteInAppSymbols--current-stock:before{content:\"\\e04e\"}.sap-icon-businessSuiteInAppSymbols--expedite:before{content:\"\\e04f\"}.sap-icon-businessSuiteInAppSymbols--postpone:before{content:\"\\e050\"}.sap-icon-businessSuiteInAppSymbols--approved:before{content:\"\\e051\"}.sap-icon-businessSuiteInAppSymbols--partially-delivered:before{content:\"\\e052\"}.sap-icon-businessSuiteInAppSymbols--line-bar-chart:before{content:\"\\e053\"}.sap-icon-businessSuiteInAppSymbols--expand-all:before{content:\"\\e054\"}.sap-icon-businessSuiteInAppSymbols--submission:before{content:\"\\e055\"}.sap-icon-businessSuiteInAppSymbols--change-request:before{content:\"\\e056\"}.sap-icon-businessSuiteInAppSymbols--column-unselected:before{content:\"\\e057\"}.sap-icon-businessSuiteInAppSymbols--column-selected:before{content:\"\\e058\"}.sap-icon-businessSuiteInAppSymbols--row-unselected:before{content:\"\\e059\"}.sap-icon-businessSuiteInAppSymbols--row-selected:before{content:\"\\e05a\"}.sap-icon-businessSuiteInAppSymbols--stock-requirements:before{content:\"\\e05b\"}.sap-icon-businessSuiteInAppSymbols--gender-male-and-female:before{content:\"\\e05c\"}.sap-icon-businessSuiteInAppSymbols--marital-status:before{content:\"\\e05d\"}.sap-icon-businessSuiteInAppSymbols--birthday:before{content:\"\\e05e\"}.sap-icon-businessSuiteInAppSymbols--classification:before{content:\"\\e05f\"}.sap-icon-businessSuiteInAppSymbols--marked-for-deletion:before{content:\"\\e060\"}.sap-icon-businessSuiteInAppSymbols--bullet-chart:before{content:\"\\e061\"}.sap-icon-businessSuiteInAppSymbols--remove-filter:before{content:\"\\e062\"}.sap-icon-businessSuiteInAppSymbols--bank-account:before{content:\"\\e063\"}.sap-icon-businessSuiteInAppSymbols--savings-account:before{content:\"\\e064\"}.sap-icon-businessSuiteInAppSymbols--debit-card:before{content:\"\\e065\"}.sap-icon-businessSuiteInAppSymbols--vip-customer:before{content:\"\\e066\"}.sap-icon-businessSuiteInAppSymbols--undesirable-customer:before{content:\"\\e067\"}.sap-icon-businessSuiteInAppSymbols--answered-change-request:before{content:\"\\e068\"}.sap-icon-businessSuiteInAppSymbols--collected-change-request:before{content:\"\\e069\"}.sap-icon-businessSuiteInAppSymbols--draw-freehand:before{content:\"\\e06a\"}.sap-icon-businessSuiteInAppSymbols--draw-circle:before{content:\"\\e06b\"}.sap-icon-businessSuiteInAppSymbols--completed:before{content:\"\\e06c\"}.sap-icon-businessSuiteInAppSymbols--answered:before{content:\"\\e06d\"}.sap-icon-businessSuiteInAppSymbols--traffic-cone:before{content:\"\\e06e\"}.sap-icon-businessSuiteInAppSymbols--traffic-lights:before{content:\"\\e06f\"}.sap-icon-businessSuiteInAppSymbols--container:before{content:\"\\e070\"}.sap-icon-businessSuiteInAppSymbols--container-loading:before{content:\"\\e071\"}.sap-icon-businessSuiteInAppSymbols--traffic-jam:before{content:\"\\e072\"}.sap-icon-businessSuiteInAppSymbols--products:before{content:\"\\e073\"}.sap-icon-businessSuiteInAppSymbols--sidepanel:before{content:\"\\e074\"}.sap-icon-businessSuiteInAppSymbols--split-screen:before{content:\"\\e075\"}.sap-icon-businessSuiteInAppSymbols--truck-driver-2:before{content:\"\\e076\"}.sap-icon-businessSuiteInAppSymbols--keep-segment:before{content:\"\\e077\"}.sap-icon-businessSuiteInAppSymbols--exclude-segment:before{content:\"\\e078\"}.sap-icon-businessSuiteInAppSymbols--separate-segments:before{content:\"\\e079\"}.sap-icon-businessSuiteInAppSymbols--distribute-segments:before{content:\"\\e07a\"}.sap-icon-businessSuiteInAppSymbols--next-open-item:before{content:\"\\e07b\"}.sap-icon-businessSuiteInAppSymbols--where-used:before{content:\"\\e07c\"}.sap-icon-businessSuiteInAppSymbols--outbound-delivery:before{content:\"\\e07d\"}.sap-icon-businessSuiteInAppSymbols--outbound-delivery-inactive:before{content:\"\\e07e\"}.sap-icon-businessSuiteInAppSymbols--outbound-delivery-active:before{content:\"\\e07f\"}.sap-icon-businessSuiteInAppSymbols--target:before{content:\"\\e080\"}.sap-icon-businessSuiteInAppSymbols--source:before{content:\"\\e081\"}.sap-icon-businessSuiteInAppSymbols--material:before{content:\"\\e082\"}.sap-icon-businessSuiteInAppSymbols--due-date:before{content:\"\\e083\"}.sap-icon-businessSuiteInAppSymbols--overdue:before{content:\"\\e084\"}.sap-icon-businessSuiteInAppSymbols--set-as-default:before{content:\"\\e085\"}.sap-icon-businessSuiteInAppSymbols--face-very-bad:before{content:\"\\e086\"}.sap-icon-businessSuiteInAppSymbols--face-bad:before{content:\"\\e087\"}.sap-icon-businessSuiteInAppSymbols--face-skeptical:before{content:\"\\e088\"}.sap-icon-businessSuiteInAppSymbols--face-neutral:before{content:\"\\e089\"}.sap-icon-businessSuiteInAppSymbols--face-astonished:before{content:\"\\e08a\"}.sap-icon-businessSuiteInAppSymbols--face-happy:before{content:\"\\e08b\"}.sap-icon-businessSuiteInAppSymbols--face-very-happy:before{content:\"\\e08c\"}.sap-icon-businessSuiteInAppSymbols--face-awful:before{content:\"\\e08d\"}.sap-icon-businessSuiteInAppSymbols--face-devastated:before{content:\"\\e08e\"}.sap-icon-businessSuiteInAppSymbols--face-okey-dokey:before{content:\"\\e08f\"}.sap-icon-businessSuiteInAppSymbols--alarm:before{content:\"\\e090\"}.sap-icon-businessSuiteInAppSymbols--activate:before{content:\"\\e091\"}.sap-icon-businessSuiteInAppSymbols--segment-preview-reference-objects:before{content:\"\\e092\"}.sap-icon-businessSuiteInAppSymbols--radius:before{content:\"\\e093\"}.sap-icon-businessSuiteInAppSymbols--polygone-black:before{content:\"\\e094\"}.sap-icon-businessSuiteInAppSymbols--polygone-white:before{content:\"\\e095\"}.sap-icon-businessSuiteInAppSymbols--ploygone:before{content:\"\\e096\"}.sap-icon-businessSuiteInAppSymbols--no-filter:before{content:\"\\e097\"}.sap-icon-businessSuiteInAppSymbols--grip:before{content:\"\\e098\"}.sap-icon-businessSuiteInAppSymbols--add-component:before{content:\"\\e099\"}.sap-icon-businessSuiteInAppSymbols--water:before{content:\"\\e09a\"}.sap-icon-businessSuiteInAppSymbols--gas:before{content:\"\\e09b\"}.sap-icon-businessSuiteInAppSymbols--liquid:before{content:\"\\e09c\"}.sap-icon-businessSuiteInAppSymbols--time-deposit:before{content:\"\\e09d\"}.sap-icon-businessSuiteInAppSymbols--early-widthdrawal-for-time-deposits:before{content:\"\\e09e\"}.sap-icon-businessSuiteInAppSymbols--business-partner:before{content:\"\\e0e3\"}.sap-icon-businessSuiteInAppSymbols--truck-load:before{content:\"\\e0e8\"}.sap-icon-businessSuiteInAppSymbols--truck-unload:before{content:\"\\e0e9\"}.sap-icon-businessSuiteInAppSymbols--truck-load-unload:before{content:\"\\e0ea\"}.sap-icon-businessSuiteInAppSymbols--pharmacy:before{content:\"\\e0eb\"}.sap-icon-businessSuiteInAppSymbols--medicine-syrup:before{content:\"\\e0ec\"}.sap-icon-businessSuiteInAppSymbols--reminder:before{content:\"\\e0ed\"}.sap-icon-businessSuiteInAppSymbols--medicine-pill:before{content:\"\\e0ee\"}.sap-icon-businessSuiteInAppSymbols--medicine-ointment:before{content:\"\\e0ef\"}.sap-icon-businessSuiteInAppSymbols--medicine-drops:before{content:\"\\e0f0\"}.sap-icon-businessSuiteInAppSymbols--blood-test:before{content:\"\\e0f1\"}.sap-icon-businessSuiteInAppSymbols--temperature:before{content:\"\\e0f2\"}.sap-icon-businessSuiteInAppSymbols--medicine-inhaler:before{content:\"\\e0f3\"}.sap-icon-businessSuiteInAppSymbols--foot-steps:before{content:\"\\e0f4\"}.sap-icon-businessSuiteInAppSymbols--weight:before{content:\"\\e0f5\"}.sap-icon-businessSuiteInAppSymbols--health-tracking:before{content:\"\\e0f6\"}.sap-icon-businessSuiteInAppSymbols--blood-pressure:before{content:\"\\e0f7\"}.sap-icon-businessSuiteInAppSymbols--immunization:before{content:\"\\e0f8\"}.sap-icon-businessSuiteInAppSymbols--allergies:before{content:\"\\e0f9\"}.sap-icon-businessSuiteInAppSymbols--rescheduling2:before{content:\"\\e0fa\"}.sap-icon-businessSuiteInAppSymbols--resequencing2:before{content:\"\\e0fb\"}.sap-icon-businessSuiteInAppSymbols--no-time-change:before{content:\"\\e0fc\"}.sap-icon-businessSuiteInAppSymbols--time-change:before{content:\"\\e0fd\"}.sap-icon-businessSuiteInAppSymbols--smart-matcher:before{content:\"\\e0fe\"}.sap-icon-businessSuiteInAppSymbols--legal-section:before{content:\"\\e10a\"}.sap-icon-businessSuiteInAppSymbols--causes:before{content:\"\\e10b\"}.sap-icon-businessSuiteInAppSymbols--effects:before{content:\"\\e10c\"}.sap-icon-businessSuiteInAppSymbols--shared-by-me:before{content:\"\\e10d\"}.sap-icon-businessSuiteInAppSymbols--shared-with-me:before{content:\"\\e10e\"}.sap-icon-businessSuiteInAppSymbols--alert-groups:before{content:\"\\e111\"}.sap-icon-businessSuiteInAppSymbols--function-alert:before{content:\"\\e112\"}.sap-icon-businessSuiteInAppSymbols--function-hierarchy:before{content:\"\\e113\"}.sap-icon-businessSuiteInAppSymbols--rfid:before{content:\"\\e114\"}.sap-icon-businessSuiteInAppSymbols--input:before{content:\"\\e115\"}.sap-icon-businessSuiteInAppSymbols--software-item:before{content:\"\\e116\"}.sap-icon-businessSuiteInAppSymbols--product-view:before{content:\"\\e117\"}.sap-icon-businessSuiteInAppSymbols--software-item-variant:before{content:\"\\e118\"}.sap-icon-businessSuiteInAppSymbols--lighthouse:before{content:\"\\e119\"}.sap-icon-businessSuiteInAppSymbols--demand-unit:before{content:\"\\e11a\"}.sap-icon-businessSuiteInAppSymbols--fma-management:before{content:\"\\e11b\"}.sap-icon-businessSuiteInAppSymbols--fma-validation:before{content:\"\\e11c\"}.sap-icon-businessSuiteInAppSymbols--fma-analytics:before{content:\"\\e11d\"}.sap-icon-businessSuiteInAppSymbols--class:before{content:\"\\e11e\"}.sap-icon-businessSuiteInAppSymbols--overview:before{content:\"\\e11f\"}.sap-icon-businessSuiteInAppSymbols--production:before{content:\"\\e120\"}.sap-icon-businessSuiteInAppSymbols--subclass:before{content:\"\\e121\"}.sap-icon-businessSuiteInAppSymbols--variant-configuration:before{content:\"\\e122\"}.sap-icon-businessSuiteInAppSymbols--sum:before{content:\"\\e123\"}.sap-icon-businessSuiteInAppSymbols--empty-trailer:before{content:\"\\e12f\"}.sap-icon-businessSuiteInAppSymbols--door:before{content:\"\\e130\"}.sap-icon-businessSuiteInAppSymbols--loading-point:before{content:\"\\e131\"}.sap-icon-businessSuiteInAppSymbols--stock-warehouse:before{content:\"\\e132\"}.sap-icon-businessSuiteInAppSymbols--gate:before{content:\"\\e133\"}.sap-icon-businessSuiteInAppSymbols--timeseries-waterfall-chart:before{content:\"\\e134\"}.sap-icon-businessSuiteInAppSymbols--stages-warning:before{content:\"\\e138\"}.sap-icon-businessSuiteInAppSymbols--empty-warning:before{content:\"\\e139\"}.sap-icon-businessSuiteInAppSymbols--move-folder:before{content:\"\\e169\"}.sap-icon-businessSuiteInAppSymbols--remove-folder:before{content:\"\\e16a\"}.sap-icon-businessSuiteInAppSymbols--match-case:before{content:\"\\e16b\"}.sap-icon-businessSuiteInAppSymbols--match-whole-word:before{content:\"\\e16c\"}.sap-icon-businessSuiteInAppSymbols--remove-total:before{content:\"\\e16d\"}.sap-icon-businessSuiteInAppSymbols--after-total:before{content:\"\\e16e\"}.sap-icon-businessSuiteInAppSymbols--before-total:before{content:\"\\e16f\"}.sap-icon-businessSuiteInAppSymbols--workbook-filter:before{content:\"\\e170\"}.sap-icon-businessSuiteInAppSymbols--icon-update-filter:before{content:\"\\e171\"}.sap-icon-businessSuiteInAppSymbols--cell-lock:before{content:\"\\e172\"}.sap-icon-businessSuiteInAppSymbols--max-container:before{content:\"\\e17b\"}.sap-icon-businessSuiteInAppSymbols--max-interval:before{content:\"\\e17c\"}.sap-icon-businessSuiteInAppSymbols--min-interval:before{content:\"\\e17d\"}.sap-icon-businessSuiteInAppSymbols--cross-order:before{content:\"\\e17e\"}.sap-icon-businessSuiteInAppSymbols--empty-order:before{content:\"\\e17f\"}.sap-icon-businessSuiteInAppSymbols--cross-sequence:before{content:\"\\e180\"}.sap-icon-businessSuiteInAppSymbols--empty-sequence:before{content:\"\\e181\"}.sap-icon-businessSuiteInAppSymbols--cross-union:before{content:\"\\e182\"}.sap-icon-businessSuiteInAppSymbols--empty-union:before{content:\"\\e183\"}.sap-icon-businessSuiteInAppSymbols--cross-target:before{content:\"\\e184\"}.sap-icon-businessSuiteInAppSymbols--non-stackable:before{content:\"\\e185\"}.sap-icon-businessSuiteInAppSymbols--back-to-search:before{content:\"\\e186\"}.sap-icon-businessSuiteInAppSymbols--business-objects-folder:before{content:\"\\e187\"}.sap-icon-businessSuiteInAppSymbols--dangerous-goods:before{content:\"\\e18a\"}.sap-icon-businessSuiteInAppSymbols--staging:before{content:\"\\e189\"}.sap-icon-TNT--technicalsystem:before{content:\"\\e000\"}.sap-icon-TNT--systemjava:before{content:\"\\e001\"}.sap-icon-TNT--systemabap:before{content:\"\\e002\"}.sap-icon-TNT--systemrecommendations:before{content:\"\\e003\"}.sap-icon-TNT--system:before{content:\"\\e004\"}.sap-icon-TNT--systemtrex:before{content:\"\\e005\"}.sap-icon-TNT--systemtracks:before{content:\"\\e006\"}.sap-icon-TNT--technicalscenario:before{content:\"\\e007\"}.sap-icon-TNT--technicalinstance:before{content:\"\\e008\"}.sap-icon-TNT--throughput-backlog:before{content:\"\\e009\"}.sap-icon-TNT--batch-processing:before{content:\"\\e00a\"}.sap-icon-TNT--database-consistency:before{content:\"\\e00b\"}.sap-icon-TNT--intermediate-message:before{content:\"\\e00c\"}.sap-icon-TNT--exceptions:before{content:\"\\e00d\"}.sap-icon-TNT--system-HANA:before{content:\"\\e00e\"}.sap-icon-TNT--python:before{content:\"\\e00f\"}.sap-icon-TNT--raise-fault:before{content:\"\\e010\"}.sap-icon-TNT--code1:before{content:\"\\e011\"}.sap-icon-TNT--code2:before{content:\"\\e012\"}.sap-icon-TNT--spike-arrest:before{content:\"\\e013\"}.sap-icon-TNT--verify-API:before{content:\"\\e014\"}.sap-icon-TNT--user:before{content:\"\\e015\"}.sap-icon-TNT--note:before{content:\"\\e016\"}.sap-icon-TNT--throwing-message:before{content:\"\\e017\"}.sap-icon-TNT--catching-message:before{content:\"\\e018\"}.sap-icon-TNT--start-event:before{content:\"\\e019\"}.sap-icon-TNT--end-event:before{content:\"\\e01a\"}.sap-icon-TNT--gateway:before{content:\"\\e01b\"}.sap-icon-TNT--sub-process-marker:before{content:\"\\e01c\"}.sap-icon-TNT--ad-hoc-marker:before{content:\"\\e01d\"}.sap-icon-TNT--manual-task:before{content:\"\\e01e\"}.sap-icon-TNT--send-task:before{content:\"\\e01f\"}.sap-icon-TNT--receive-task:before{content:\"\\e020\"}.sap-icon-TNT--script-task:before{content:\"\\e021\"}.sap-icon-TNT--marquee:before{content:\"\\e022\"}.sap-icon-TNT--data-input-arrow:before{content:\"\\e023\"}.sap-icon-TNT--data-output-arrow:before{content:\"\\e024\"}.sap-icon-TNT--more:before{content:\"\\e025\"}.sap-icon-TNT--pattern:before{content:\"\\e026\"}.sap-icon-TNT--task:before{content:\"\\e027\"}.sap-icon-TNT--arrow:before{content:\"\\e028\"}.sap-icon-TNT--data:before{content:\"\\e029\"}.sap-icon-TNT--data-store:before{content:\"\\e02a\"}.sap-icon-TNT--pool:before{content:\"\\e02b\"}.sap-icon-TNT--swimlane:before{content:\"\\e02c\"}.sap-icon-TNT--select:before{content:\"\\e02d\"}.sap-icon-TNT--cursor:before{content:\"\\e02e\"}.sap-icon-TNT--api:before{content:\"\\e02f\"}.sap-icon-TNT--o-data:before{content:\"\\e030\"}.sap-icon-TNT--javascript:before{content:\"\\e031\"}.sap-icon-TNT--value-mapping:before{content:\"\\e032\"}.sap-icon-TNT--terminate-end-event:before{content:\"\\e033\"}.sap-icon-TNT--parallel-gateway:before{content:\"\\e034\"}.sap-icon-TNT--exclusive-gateway:before{content:\"\\e035\"}.sap-icon-TNT--service-task:before{content:\"\\e036\"}.sap-icon-TNT--workflow-editor:before{content:\"\\e037\"}.sap-icon-TNT--boundary-interrupting:before{content:\"\\e038\"}.sap-icon-TNT--boundary-non-interrupting:before{content:\"\\e039\"}.sap-icon-TNT--block:before{content:\"\\e03a\"}.sap-icon-TNT--constrain-block:before{content:\"\\e03b\"}.sap-icon-TNT--actor:before{content:\"\\e03c\"}.sap-icon-TNT--instance-specification:before{content:\"\\e03d\"}.sap-icon-TNT--value-type:before{content:\"\\e03e\"}.sap-icon-TNT--interface-block:before{content:\"\\e03f\"}.sap-icon-TNT--unit:before{content:\"\\e040\"}.sap-icon-TNT--signal:before{content:\"\\e041\"}.sap-icon-TNT--quantity-kind:before{content:\"\\e042\"}.sap-icon-TNT--item-flow:before{content:\"\\e043\"}.sap-icon-TNT--dependency:before{content:\"\\e044\"}.sap-icon-TNT--generalization:before{content:\"\\e045\"}.sap-icon-TNT--aggregation:before{content:\"\\e046\"}.sap-icon-TNT--composition:before{content:\"\\e047\"}.sap-icon-TNT--association:before{content:\"\\e048\"}.sap-icon-TNT--port:before{content:\"\\e049\"}.sap-icon-TNT--proxy-port:before{content:\"\\e04a\"}.sap-icon-TNT--full-port:before{content:\"\\e04b\"}.sap-icon-TNT--operations:before{content:\"\\e04c\"}.sap-icon-TNT--constrains:before{content:\"\\e04d\"}.sap-icon-TNT--receptions:before{content:\"\\e04e\"}.sap-icon-TNT--references:before{content:\"\\e04f\"}.sap-icon-TNT--parts:before{content:\"\\e050\"}.sap-icon-TNT--flow:before{content:\"\\e051\"}.sap-icon-TNT--values:before{content:\"\\e052\"}.sap-icon-TNT--bill-of-material:before{content:\"\\e053\"}.sap-icon-TNT--document-info-recording:before{content:\"\\e054\"}.sap-icon-TNT--use-case-diagram:before{content:\"\\e055\"}.sap-icon-TNT--bdd-diagram:before{content:\"\\e056\"}.sap-icon-TNT--requirement-diagram:before{content:\"\\e057\"}.sap-icon-TNT--package-diagram:before{content:\"\\e058\"}.sap-icon-TNT--internal-block-diagram:before{content:\"\\e059\"}.sap-icon-TNT--requirement-containment-relationship:before{content:\"\\e05a\"}.sap-icon-TNT--use-case:before{content:\"\\e05b\"}.sap-icon-TNT--use-case-extension-point:before{content:\"\\e05c\"}.sap-icon-TNT--communication-path:before{content:\"\\e05d\"}.sap-icon-TNT--note-connection:before{content:\"\\e05e\"}.sap-icon-TNT--subject:before{content:\"\\e05f\"}.sap-icon-TNT--auto-layout:before{content:\"\\e060\"}.sap-icon-TNT--required-interface:before{content:\"\\e061\"}.sap-icon-TNT--provided-interface:before{content:\"\\e062\"}.sap-icon-TNT--sub-content:before{content:\"\\e063\"}.sap-icon-TNT--connector:before{content:\"\\e064\"}.sap-icon-TNT--local-process-call:before{content:\"\\e065\"}.sap-icon-TNT--aggregator:before{content:\"\\e066\"}.sap-icon-TNT--splitter:before{content:\"\\e067\"}.sap-icon-TNT--converter:before{content:\"\\e068\"}.sap-icon-TNT--content-modifier:before{content:\"\\e069\"}.sap-icon-TNT--message-start-event:before{content:\"\\e06a\"}.sap-icon-TNT--message-end-event:before{content:\"\\e06d\"}.sap-icon-TNT--escalation-end-event:before{content:\"\\e06c\"}.sap-icon-TNT--start-timer-event:before{content:\"\\e06d\"}.sap-icon-TNT--error-start-event:before{content:\"\\e06e\"}.sap-icon-TNT--error-end-event:before{content:\"\\e06f\"}.sap-icon-TNT--content-enricher:before{content:\"\\e070\"}.sap-icon-TNT--realization:before{content:\"\\e071\"}.sap-icon-TNT--interface:before{content:\"\\e072\"}.sap-icon-TNT--usiness-capability:before{content:\"\\e073\"}.sap-icon-TNT--progress-group:before{content:\"\\e074\"}.sap-icon-TNT--value-stream:before{content:\"\\e075\"}.sap-icon-TNT--value-flow:before{content:\"\\e076\"}.sap-icon-TNT--application:before{content:\"\\e077\"}.sap-icon-TNT--etl-job:before{content:\"\\e078\"}.sap-icon-TNT--business-service:before{content:\"\\e079\"}.sap-icon-TNT--application-service:before{content:\"\\e07a\"}.sap-icon-TNT--network-node:before{content:\"\\e07b\"}.sap-icon-TNT--network:before{content:\"\\e07c\"}.sap-icon-TNT--deployment-instance:before{content:\"\\e07d\"}.sap-icon-TNT--intranet:before{content:\"\\e07e\"}.sap-icon-TNT--mobile-network:before{content:\"\\e07f\"}.sap-icon-TNT--private-cloud:before{content:\"\\e080\"}.sap-icon-TNT--antenna:before{content:\"\\e081\"}.sap-icon-TNT--firewall:before{content:\"\\e082\"}.sap-icon-TNT--hub:before{content:\"\\e083\"}.sap-icon-TNT--modem:before{content:\"\\e084\"}.sap-icon-TNT--repeater:before{content:\"\\e085\"}.sap-icon-TNT--router:before{content:\"\\e086\"}.sap-icon-TNT--switch:before{content:\"\\e087\"}.sap-icon-TNT--satellite:before{content:\"\\e088\"}.sap-icon-TNT--system-2:before{content:\"\\e089\"}.sap-icon-TNT--status-activating:before{content:\"\\e08a\"}.sap-icon-TNT--status-suspended:before{content:\"\\e08b\"}.sap-icon-TNT--status-suspending:before{content:\"\\e08c\"}.sap-icon-TNT--status-terminated:before{content:\"\\e08d\"}.sap-icon-TNT--status-terminating:before{content:\"\\e08e\"}.sap-icon-TNT--solution-not-licensed:before{content:\"\\e08f\"}.sap-icon-TNT--clear-all-mapping:before{content:\"\\e090\"}.sap-icon-TNT--map-all-fields:before{content:\"\\e091\"}.sap-icon-TNT--process-package:before{content:\"\\e092\"}.sap-icon-TNT--process-kpis:before{content:\"\\e093\"}.sap-icon-TNT--insights:before{content:\"\\e094\"}.sap-icon-TNT--escalation-boundary-interrupting:before{content:\"\\e095\"}.sap-icon-TNT--escalation-boundary-non-interrupting:before{content:\"\\e096\"}.sap-icon-TNT--escalation-throwing:before{content:\"\\e097\"}.sap-icon-TNT--solution:before{content:\"\\e098\"}.sap-icon-TNT--binary:before{content:\"\\e099\"}.sap-icon-TNT--uuid:before{content:\"\\e09a\"}.sap-icon-TNT--github:before{content:\"\\e09b\"}.sap-icon-TNT--robot:before{content:\"\\e09c\"}.sap-icon-TNT--string:before{content:\"\\e09d\"}.sap-icon-TNT--boolean:before{content:\"\\e09e\"}.sap-icon-TNT--array:before{content:\"\\e09f\"}.sap-icon-TNT--any:before{content:\"\\e101\"}.sap-icon-TNT--integer:before{content:\"\\e102\"}.sap-icon-TNT--float:before{content:\"\\e103\"}.sap-icon-TNT--build-work-zone:before{content:\"\\e104\"}.sap-icon-TNT--build-apps:before{content:\"\\e105\"}.sap-icon-TNT--build-process-automation:before{content:\"\\e106\"}.sap-icon-TNT--indicator:before{content:\"\\e107\"}.sap-icon-TNT--indicator-active:before{content:\"\\e108\"}.sap-icon-TNT--task-optional:before{content:\"\\e109\"}.sap-icon-TNT--task-done:before{content:\"\\e10a\"}.sap-icon-TNT--ai-1:before{content:\"\\e10b\"}.sap-icon-TNT--ai-2:before{content:\"\\e10c\"}.sap-icon-TNT--bound-validation-rule:before{content:\"\\e10d\"}.sap-icon-TNT--business-application-studio:before{content:\"\\e110\"}.sap-icon-TNT--clone-from-gi:before{content:\"\\e111\"}.sap-icon-TNT--business-accelerator:before{content:\"\\e112\"}.sap-icon-TNT--ai-feature-estimator:before{content:\"\\e113\"}.sap-icon-TNT--service-estimator:before{content:\"\\e114\"}.sap-icon-TNT--add-project:before{content:\"\\e115\"}.sap-icon-TNT--add-issue:before{content:\"\\e116\"}[class*=sap-icon].fd-inline-help__trigger{padding:0 .25rem;outline-offset:-.125rem}\n/*! Bundled license information:\n\nfundamental-styles/dist/icon.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { glyph: [{
                type: Input
            }], font: [{
                type: Input
            }], color: [{
                type: Input
            }], background: [{
                type: Input
            }], class: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-label']
            }], ariaHidden: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-hidden']
            }], _navigationItemIcon: [{
                type: HostBinding,
                args: ['class.fd-list__navigation-item-icon']
            }], buildComponentCssClass: [] } });

class IconModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: IconModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: IconModule, imports: [IconComponent], exports: [IconComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: IconModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: IconModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [IconComponent],
                    exports: [IconComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FD_DEFAULT_ICON_FONT_FAMILY, FD_ICON_COMPONENT, FD_ICON_FONT_FAMILY, IconComponent, IconModule, fdBuildIconClass };
//# sourceMappingURL=fundamental-ngx-core-icon.mjs.map
